Class: Aws::PinpointSMSVoiceV2::Types::CarrierLookupResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#carrier ⇒ String

The carrier or service provider that the phone number is currently registered with. In some countries and regions, this value may be the carrier or service provider that the phone number was originally registered with.

Returns:

  • (String)


269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 269

class CarrierLookupResult < Struct.new(
  :e164_phone_number,
  :dialing_country_code,
  :iso_country_code,
  :country,
  :mcc,
  :mnc,
  :carrier,
  :phone_number_type)
  SENSITIVE = []
  include Aws::Structure
end

#country ⇒ String

The name of the country or region for the phone number.

Returns:

  • (String)


269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 269

class CarrierLookupResult < Struct.new(
  :e164_phone_number,
  :dialing_country_code,
  :iso_country_code,
  :country,
  :mcc,
  :mnc,
  :carrier,
  :phone_number_type)
  SENSITIVE = []
  include Aws::Structure
end

#dialing_country_code ⇒ String

The country or region numeric dialing code for the phone number.

Returns:

  • (String)


269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 269

class CarrierLookupResult < Struct.new(
  :e164_phone_number,
  :dialing_country_code,
  :iso_country_code,
  :country,
  :mcc,
  :mnc,
  :carrier,
  :phone_number_type)
  SENSITIVE = []
  include Aws::Structure
end

#e164_phone_number ⇒ String

The phone number in E164 format, sanitized from the original input by removing any formatting characters.

Returns:

  • (String)


269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 269

class CarrierLookupResult < Struct.new(
  :e164_phone_number,
  :dialing_country_code,
  :iso_country_code,
  :country,
  :mcc,
  :mnc,
  :carrier,
  :phone_number_type)
  SENSITIVE = []
  include Aws::Structure
end

#iso_country_code ⇒ String

The two-character country or region code, in ISO 3166-1 alpha-2 format, for the phone number.

Returns:

  • (String)


269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 269

class CarrierLookupResult < Struct.new(
  :e164_phone_number,
  :dialing_country_code,
  :iso_country_code,
  :country,
  :mcc,
  :mnc,
  :carrier,
  :phone_number_type)
  SENSITIVE = []
  include Aws::Structure
end

#mcc ⇒ String

The phone number's mobile country code, for mobile phone number types

Returns:

  • (String)


269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 269

class CarrierLookupResult < Struct.new(
  :e164_phone_number,
  :dialing_country_code,
  :iso_country_code,
  :country,
  :mcc,
  :mnc,
  :carrier,
  :phone_number_type)
  SENSITIVE = []
  include Aws::Structure
end

#mnc ⇒ String

The phone number's mobile network code, for mobile phone number types.

Returns:

  • (String)


269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 269

class CarrierLookupResult < Struct.new(
  :e164_phone_number,
  :dialing_country_code,
  :iso_country_code,
  :country,
  :mcc,
  :mnc,
  :carrier,
  :phone_number_type)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_type ⇒ String

Describes the type of phone number. Valid values are: MOBILE, LANDLINE, OTHER, and INVALID. Avoid sending SMS or voice messages to INVALID phone numbers, as these numbers are unlikely to belong to actual recipients.

Returns:

  • (String)


269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 269

class CarrierLookupResult < Struct.new(
  :e164_phone_number,
  :dialing_country_code,
  :iso_country_code,
  :country,
  :mcc,
  :mnc,
  :carrier,
  :phone_number_type)
  SENSITIVE = []
  include Aws::Structure
end