Class: Aws::PinpointSMSVoiceV2::Types::ConditionalBehavior

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

The set of conditional rules that determine a field's resolved requirement based on the values of other fields in the same registration form. Attached to fields whose FieldRequirement is CONDITIONAL.

Evaluation proceeds top-to-bottom through Rules. The first rule whose conditions all evaluate to true wins and its behavior is returned. If no rule matches, the DefaultBehavior is returned.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_behaviorString

The field behavior that applies when no conditional rule in Rules matches. Valid values are REQUIRED, OPTIONAL, and DISALLOWED.

Returns:

  • (String)


349
350
351
352
353
354
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 349

class ConditionalBehavior < Struct.new(
  :rules,
  :default_behavior)
  SENSITIVE = []
  include Aws::Structure
end

#rulesArray<Types::ConditionalRule>

An ordered list of conditional rules. Rules are evaluated top-to-bottom and the first rule whose conditions all evaluate to true determines the field's behavior. Rules whose conditions do not all match are skipped and evaluation continues to the next rule.

Returns:



349
350
351
352
353
354
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 349

class ConditionalBehavior < Struct.new(
  :rules,
  :default_behavior)
  SENSITIVE = []
  include Aws::Structure
end