Class: Aws::PinpointSMSVoiceV2::Types::ConditionalValidation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Per-rule validation constraints that override the field's default validation when the containing rule matches. All fields are optional; only the constraints that need to differ from the field's default validation are provided.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_valuesArray<String>

The allowed values for a select field when this rule applies. A subset of the field's full option list.

Returns:

  • (Array<String>)


414
415
416
417
418
419
420
421
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 414

class ConditionalValidation < Struct.new(
  :min_length,
  :max_length,
  :pattern,
  :allowed_values)
  SENSITIVE = []
  include Aws::Structure
end

#max_lengthInteger

The maximum length for the field value when this rule applies.

Returns:

  • (Integer)


414
415
416
417
418
419
420
421
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 414

class ConditionalValidation < Struct.new(
  :min_length,
  :max_length,
  :pattern,
  :allowed_values)
  SENSITIVE = []
  include Aws::Structure
end

#min_lengthInteger

The minimum length for the field value when this rule applies.

Returns:

  • (Integer)


414
415
416
417
418
419
420
421
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 414

class ConditionalValidation < Struct.new(
  :min_length,
  :max_length,
  :pattern,
  :allowed_values)
  SENSITIVE = []
  include Aws::Structure
end

#patternString

A regular expression that the field value must match when this rule applies.

Returns:

  • (String)


414
415
416
417
418
419
420
421
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 414

class ConditionalValidation < Struct.new(
  :min_length,
  :max_length,
  :pattern,
  :allowed_values)
  SENSITIVE = []
  include Aws::Structure
end