Class: Aws::PinpointSMSVoiceV2::Types::CountryLaunchStatusInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::CountryLaunchStatusInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Contains per-country launch status details for an RCS agent.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#carrier_status ⇒ Array<Types::CarrierStatusInformation>
An array of CarrierStatusInformation objects containing carrier-level launch status details.
-
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
-
#rcs_platform_id ⇒ String
The RCS platform identifier for this country.
-
#registration_id ⇒ String
The unique identifier of the registration associated with this country launch.
-
#status ⇒ String
The launch status for this country.
Instance Attribute Details
#carrier_status ⇒ Array<Types::CarrierStatusInformation>
An array of CarrierStatusInformation objects containing carrier-level launch status details.
578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 578 class CountryLaunchStatusInformation < Struct.new( :iso_country_code, :status, :rcs_platform_id, :registration_id, :carrier_status) SENSITIVE = [] include Aws::Structure end |
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 578 class CountryLaunchStatusInformation < Struct.new( :iso_country_code, :status, :rcs_platform_id, :registration_id, :carrier_status) SENSITIVE = [] include Aws::Structure end |
#rcs_platform_id ⇒ String
The RCS platform identifier for this country.
578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 578 class CountryLaunchStatusInformation < Struct.new( :iso_country_code, :status, :rcs_platform_id, :registration_id, :carrier_status) SENSITIVE = [] include Aws::Structure end |
#registration_id ⇒ String
The unique identifier of the registration associated with this country launch.
578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 578 class CountryLaunchStatusInformation < Struct.new( :iso_country_code, :status, :rcs_platform_id, :registration_id, :carrier_status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The launch status for this country.
578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 578 class CountryLaunchStatusInformation < Struct.new( :iso_country_code, :status, :rcs_platform_id, :registration_id, :carrier_status) SENSITIVE = [] include Aws::Structure end |