Class: Aws::PinpointSMSVoiceV2::Types::CreateNotifyConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::CreateNotifyConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#default_template_id ⇒ String
The default template identifier to associate with the notify configuration.
-
#deletion_protection_enabled ⇒ Boolean
By default this is set to false.
-
#display_name ⇒ String
The display name to associate with the notify configuration.
-
#enabled_channels ⇒ Array<String>
An array of channels to enable for the notify configuration.
-
#enabled_countries ⇒ Array<String>
An array of two-character ISO country codes, in ISO 3166-1 alpha-2 format, that are enabled for the notify configuration.
-
#pool_id ⇒ String
The identifier of the pool to associate with the notify configuration.
-
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) associated with the notify configuration.
-
#use_case ⇒ String
The use case for the notify configuration.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don't specify a client token, a randomly generated token is used for the request to ensure idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 784 class CreateNotifyConfigurationRequest < Struct.new( :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#default_template_id ⇒ String
The default template identifier to associate with the notify configuration. If specified, this template is used when sending messages without an explicit template identifier.
784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 784 class CreateNotifyConfigurationRequest < Struct.new( :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
By default this is set to false. When set to true the notify configuration can't be deleted. You can change this value using the UpdateNotifyConfiguration action.
784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 784 class CreateNotifyConfigurationRequest < Struct.new( :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name to associate with the notify configuration.
784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 784 class CreateNotifyConfigurationRequest < Struct.new( :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#enabled_channels ⇒ Array<String>
An array of channels to enable for the notify configuration.
Supported values include SMS and VOICE.
784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 784 class CreateNotifyConfigurationRequest < Struct.new( :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#enabled_countries ⇒ Array<String>
An array of two-character ISO country codes, in ISO 3166-1 alpha-2 format, that are enabled for the notify configuration.
784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 784 class CreateNotifyConfigurationRequest < Struct.new( :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The identifier of the pool to associate with the notify configuration.
784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 784 class CreateNotifyConfigurationRequest < Struct.new( :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) associated with the notify configuration.
784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 784 class CreateNotifyConfigurationRequest < Struct.new( :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#use_case ⇒ String
The use case for the notify configuration.
784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 784 class CreateNotifyConfigurationRequest < Struct.new( :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |