Class: Aws::PinpointSMSVoiceV2::Types::CreateOptOutListRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don't specify a client token, a randomly generated token is used for the request to ensure idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


911
912
913
914
915
916
917
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 911

class CreateOptOutListRequest < Struct.new(
  :opt_out_list_name,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_name ⇒ String

The name of the new OptOutList.

Returns:

  • (String)


911
912
913
914
915
916
917
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 911

class CreateOptOutListRequest < Struct.new(
  :opt_out_list_name,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

An array of tags (key and value pairs) to associate with the new OptOutList.

Returns:



911
912
913
914
915
916
917
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 911

class CreateOptOutListRequest < Struct.new(
  :opt_out_list_name,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end