Class: Aws::PinpointSMSVoiceV2::Types::CreatePoolResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestampTime

The time when the pool was created, in UNIX epoch time format.

Returns:

  • (Time)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection_enabledBoolean

When set to true deletion protection is enabled. By default this is set to false.

Returns:

  • (Boolean)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#message_typeString

The type of message for the pool to use.

Returns:

  • (String)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_nameString

The name of the OptOutList associated with the pool.

Returns:

  • (String)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#pool_arnString

The Amazon Resource Name (ARN) for the pool.

Returns:

  • (String)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idString

The unique identifier for the pool.

Returns:

  • (String)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_opt_outs_enabledBoolean

By default this is set to false. When set to false, and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.

Returns:

  • (Boolean)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#shared_routes_enabledBoolean

Indicates whether shared routes are enabled for the pool. Set to false and only origination identities in this pool are used to send messages.

Returns:

  • (Boolean)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the pool.

  • CREATING: The pool is currently being created and isn't yet available for use.

  • ACTIVE: The pool is active and available for use.

  • DELETING: The pool is being deleted.

Returns:

  • (String)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of tags (key and value pairs) associated with the pool.

Returns:



1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_arnString

The Amazon Resource Name (ARN) of the two way channel.

Returns:

  • (String)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_roleString

An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.

Returns:

  • (String)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_enabledBoolean

By default this is set to false. When set to true you can receive incoming text messages from your end recipients.

Returns:

  • (Boolean)


1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1097

class CreatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end