Class: Aws::PinpointSMSVoiceV2::Types::CreateRcsAgentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::CreateRcsAgentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#deletion_protection_enabled ⇒ Boolean
By default this is set to false.
-
#opt_out_list_name ⇒ String
The OptOutList to associate with the RCS agent.
-
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) associated with the RCS agent.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don't specify a client token, a randomly generated token is used for the request to ensure idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
1218 1219 1220 1221 1222 1223 1224 1225 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1218 class CreateRcsAgentRequest < Struct.new( :deletion_protection_enabled, :opt_out_list_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
By default this is set to false. When set to true the RCS agent can't be deleted. You can change this value using the UpdateRcsAgent action.
1218 1219 1220 1221 1222 1223 1224 1225 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1218 class CreateRcsAgentRequest < Struct.new( :deletion_protection_enabled, :opt_out_list_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The OptOutList to associate with the RCS agent. Valid values are either OptOutListName or OptOutListArn.
1218 1219 1220 1221 1222 1223 1224 1225 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1218 class CreateRcsAgentRequest < Struct.new( :deletion_protection_enabled, :opt_out_list_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) associated with the RCS agent.
1218 1219 1220 1221 1222 1223 1224 1225 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1218 class CreateRcsAgentRequest < Struct.new( :deletion_protection_enabled, :opt_out_list_name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |