Class: Aws::PinpointSMSVoiceV2::Types::CreateRegistrationAttachmentResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::CreateRegistrationAttachmentResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_status ⇒ String
The status of the registration attachment.
-
#created_timestamp ⇒ Time
The time when the registration attachment was created, in [UNIX epoch time][1] format.
-
#registration_attachment_arn ⇒ String
The Amazon Resource Name (ARN) for the registration attachment.
-
#registration_attachment_id ⇒ String
The unique identifier for the registration attachment.
-
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) to associate with the registration attachment.
Instance Attribute Details
#attachment_status ⇒ String
The status of the registration attachment.
-
UPLOAD_IN_PROGRESSThe attachment is being uploaded. -
UPLOAD_COMPLETEThe attachment has been uploaded. -
UPLOAD_FAILEDThe attachment failed to uploaded. -
DELETEDThe attachment has been deleted..
1367 1368 1369 1370 1371 1372 1373 1374 1375 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1367 class CreateRegistrationAttachmentResult < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#created_timestamp ⇒ Time
The time when the registration attachment was created, in UNIX epoch time format.
1367 1368 1369 1370 1371 1372 1373 1374 1375 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1367 class CreateRegistrationAttachmentResult < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#registration_attachment_arn ⇒ String
The Amazon Resource Name (ARN) for the registration attachment.
1367 1368 1369 1370 1371 1372 1373 1374 1375 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1367 class CreateRegistrationAttachmentResult < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#registration_attachment_id ⇒ String
The unique identifier for the registration attachment.
1367 1368 1369 1370 1371 1372 1373 1374 1375 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1367 class CreateRegistrationAttachmentResult < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) to associate with the registration attachment.
1367 1368 1369 1370 1371 1372 1373 1374 1375 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1367 class CreateRegistrationAttachmentResult < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |