Class: Aws::PinpointSMSVoiceV2::Types::DeleteConfigurationSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DeleteConfigurationSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_set_name ⇒ String
The name of the configuration set or the configuration set ARN that you want to delete.
Instance Attribute Details
#configuration_set_name ⇒ String
The name of the configuration set or the configuration set ARN that you want to delete. The ConfigurationSetName and ConfigurationSetArn can be found using the DescribeConfigurationSets action.
1778 1779 1780 1781 1782 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1778 class DeleteConfigurationSetRequest < Struct.new( :configuration_set_name) SENSITIVE = [] include Aws::Structure end |