Class: Aws::PinpointSMSVoiceV2::Types::DeleteDefaultMessageTypeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DeleteDefaultMessageTypeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_set_name ⇒ String
The name of the configuration set or the configuration set Amazon Resource Name (ARN) to delete the default message type from.
Instance Attribute Details
#configuration_set_name ⇒ String
The name of the configuration set or the configuration set Amazon Resource Name (ARN) to delete the default message type from. The ConfigurationSetName and ConfigurationSetArn can be found using the DescribeConfigurationSets action.
1842 1843 1844 1845 1846 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1842 class DeleteDefaultMessageTypeRequest < Struct.new( :configuration_set_name) SENSITIVE = [] include Aws::Structure end |