Class: Aws::PinpointSMSVoiceV2::Types::DeleteDefaultSenderIdRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DeleteDefaultSenderIdRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_set_name ⇒ String
The name of the configuration set or the configuration set Amazon Resource Name (ARN) to delete the default sender ID from.
Instance Attribute Details
#configuration_set_name ⇒ String
The name of the configuration set or the configuration set Amazon Resource Name (ARN) to delete the default sender ID from. The ConfigurationSetName and ConfigurationSetArn can be found using the DescribeConfigurationSets action.
1879 1880 1881 1882 1883 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1879 class DeleteDefaultSenderIdRequest < Struct.new( :configuration_set_name) SENSITIVE = [] include Aws::Structure end |