Class: Aws::PinpointSMSVoiceV2::Types::DeleteKeywordRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DeleteKeywordRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#keyword ⇒ String
The keyword to delete.
-
#origination_identity ⇒ String
The origination identity to use such as a PhoneNumberId, PhoneNumberArn, PoolId or PoolArn.
Instance Attribute Details
#keyword ⇒ String
The keyword to delete.
1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1868 class DeleteKeywordRequest < Struct.new( :origination_identity, :keyword) SENSITIVE = [] include Aws::Structure end |
#origination_identity ⇒ String
The origination identity to use such as a PhoneNumberId, PhoneNumberArn, PoolId or PoolArn. You can use DescribePhoneNumbers to find the values for PhoneNumberId and PhoneNumberArn and DescribePools to find the values of PoolId and PoolArn.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1868 class DeleteKeywordRequest < Struct.new( :origination_identity, :keyword) SENSITIVE = [] include Aws::Structure end |