Class: Aws::PinpointSMSVoiceV2::Types::DeletePoolResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DeletePoolResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_timestamp ⇒ Time
The time when the pool was created, in [UNIX epoch time][1] format.
-
#message_type ⇒ String
The message type that was associated with the deleted pool.
-
#opt_out_list_name ⇒ String
The name of the OptOutList that was associated with the deleted pool.
-
#pool_arn ⇒ String
The Amazon Resource Name (ARN) of the pool that was deleted.
-
#pool_id ⇒ String
The PoolId of the pool that was deleted.
-
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false.
-
#shared_routes_enabled ⇒ Boolean
Indicates whether shared routes are enabled for the pool.
-
#status ⇒ String
The current status of the pool.
-
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the TwoWayChannel.
-
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
-
#two_way_enabled ⇒ Boolean
By default this is set to false.
Instance Attribute Details
#created_timestamp ⇒ Time
The time when the pool was created, in UNIX epoch time format.
2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2325 class DeletePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#message_type ⇒ String
The message type that was associated with the deleted pool.
2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2325 class DeletePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The name of the OptOutList that was associated with the deleted pool.
2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2325 class DeletePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#pool_arn ⇒ String
The Amazon Resource Name (ARN) of the pool that was deleted.
2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2325 class DeletePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The PoolId of the pool that was deleted.
2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2325 class DeletePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false. When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.
2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2325 class DeletePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#shared_routes_enabled ⇒ Boolean
Indicates whether shared routes are enabled for the pool.
2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2325 class DeletePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the pool.
-
CREATING: The pool is currently being created and isn't yet available for use.
-
ACTIVE: The pool is active and available for use.
-
DELETING: The pool is being deleted.
2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2325 class DeletePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the TwoWayChannel.
2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2325 class DeletePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2325 class DeletePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_enabled ⇒ Boolean
By default this is set to false. When set to true you can receive incoming text messages from your end recipients.
2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2325 class DeletePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |