Class: Aws::PinpointSMSVoiceV2::Types::DeleteRcsAgentResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DeleteRcsAgentResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_timestamp ⇒ Time
The time when the RCS agent was created, in [UNIX epoch time][1] format.
-
#deletion_protection_enabled ⇒ Boolean
When set to true deletion protection is enabled.
-
#opt_out_list_name ⇒ String
The name of the OptOutList that was associated with the deleted RCS agent.
-
#rcs_agent_arn ⇒ String
The Amazon Resource Name (ARN) of the deleted RCS agent.
-
#rcs_agent_id ⇒ String
The unique identifier for the deleted RCS agent.
-
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false.
-
#status ⇒ String
The current status of the RCS agent.
-
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
-
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
-
#two_way_enabled ⇒ Boolean
By default this is set to false.
-
#two_way_rcs_events_enabled ⇒ Array<String>
The list of RCS event types that were enabled for two-way messaging on the deleted agent.
Instance Attribute Details
#created_timestamp ⇒ Time
The time when the RCS agent was created, in UNIX epoch time format.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2435 class DeleteRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_rcs_events_enabled) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
When set to true deletion protection is enabled. By default this is set to false.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2435 class DeleteRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_rcs_events_enabled) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The name of the OptOutList that was associated with the deleted RCS agent.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2435 class DeleteRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_rcs_events_enabled) SENSITIVE = [] include Aws::Structure end |
#rcs_agent_arn ⇒ String
The Amazon Resource Name (ARN) of the deleted RCS agent.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2435 class DeleteRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_rcs_events_enabled) SENSITIVE = [] include Aws::Structure end |
#rcs_agent_id ⇒ String
The unique identifier for the deleted RCS agent.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2435 class DeleteRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_rcs_events_enabled) SENSITIVE = [] include Aws::Structure end |
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2435 class DeleteRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_rcs_events_enabled) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the RCS agent.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2435 class DeleteRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_rcs_events_enabled) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2435 class DeleteRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_rcs_events_enabled) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2435 class DeleteRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_rcs_events_enabled) SENSITIVE = [] include Aws::Structure end |
#two_way_enabled ⇒ Boolean
By default this is set to false. When set to true you can receive incoming text messages from your end recipients.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2435 class DeleteRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_rcs_events_enabled) SENSITIVE = [] include Aws::Structure end |
#two_way_rcs_events_enabled ⇒ Array<String>
The list of RCS event types that were enabled for two-way messaging on the deleted agent.
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2435 class DeleteRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_rcs_events_enabled) SENSITIVE = [] include Aws::Structure end |