Class: Aws::PinpointSMSVoiceV2::Types::DeleteRegistrationAttachmentResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DeleteRegistrationAttachmentResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_status ⇒ String
The status of the registration attachment.
-
#attachment_upload_error_reason ⇒ String
The error message if the upload failed.
-
#created_timestamp ⇒ Time
The time when the registration attachment was created, in [UNIX epoch time][1] format.
-
#registration_attachment_arn ⇒ String
The Amazon Resource Name (ARN) for the registration attachment.
-
#registration_attachment_id ⇒ String
The unique identifier for the registration attachment.
Instance Attribute Details
#attachment_status ⇒ String
The status of the registration attachment.
-
UPLOAD_IN_PROGRESSThe attachment is being uploaded. -
UPLOAD_COMPLETEThe attachment has been uploaded. -
UPLOAD_FAILEDThe attachment failed to uploaded. -
DELETEDThe attachment has been deleted..
2516 2517 2518 2519 2520 2521 2522 2523 2524 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2516 class DeleteRegistrationAttachmentResult < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#attachment_upload_error_reason ⇒ String
The error message if the upload failed.
2516 2517 2518 2519 2520 2521 2522 2523 2524 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2516 class DeleteRegistrationAttachmentResult < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#created_timestamp ⇒ Time
The time when the registration attachment was created, in UNIX epoch time format.
2516 2517 2518 2519 2520 2521 2522 2523 2524 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2516 class DeleteRegistrationAttachmentResult < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#registration_attachment_arn ⇒ String
The Amazon Resource Name (ARN) for the registration attachment.
2516 2517 2518 2519 2520 2521 2522 2523 2524 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2516 class DeleteRegistrationAttachmentResult < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#registration_attachment_id ⇒ String
The unique identifier for the registration attachment.
2516 2517 2518 2519 2520 2521 2522 2523 2524 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2516 class DeleteRegistrationAttachmentResult < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp) SENSITIVE = [] include Aws::Structure end |