Class: Aws::PinpointSMSVoiceV2::Types::DescribeNotifyConfigurationsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to be used for the next set of paginated results. If this field is empty then there are no more results.

Returns:

  • (String)


3034
3035
3036
3037
3038
3039
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3034

class DescribeNotifyConfigurationsResult < Struct.new(
  :notify_configurations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#notify_configurationsArray<Types::NotifyConfigurationInformation>

An array of NotifyConfigurationInformation objects that contain the results.



3034
3035
3036
3037
3038
3039
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3034

class DescribeNotifyConfigurationsResult < Struct.new(
  :notify_configurations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end