Class: Aws::PinpointSMSVoiceV2::Types::DescribeNotifyTemplatesResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to be used for the next set of paginated results. If this field is empty then there are no more results.

Returns:

  • (String)


3081
3082
3083
3084
3085
3086
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3081

class DescribeNotifyTemplatesResult < Struct.new(
  :notify_templates,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#notify_templatesArray<Types::NotifyTemplateInformation>

An array of NotifyTemplateInformation objects that contain the results.



3081
3082
3083
3084
3085
3086
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3081

class DescribeNotifyTemplatesResult < Struct.new(
  :notify_templates,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end