Class: Aws::PinpointSMSVoiceV2::Types::DescribeOptOutListsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

The maximum number of results to return per each request.

Returns:

  • (Integer)


3212
3213
3214
3215
3216
3217
3218
3219
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3212

class DescribeOptOutListsRequest < Struct.new(
  :opt_out_list_names,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.

Returns:

  • (String)


3212
3213
3214
3215
3216
3217
3218
3219
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3212

class DescribeOptOutListsRequest < Struct.new(
  :opt_out_list_names,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_names ⇒ Array<String>

The OptOutLists to show the details of. This is an array of strings that can be either the OptOutListName or OptOutListArn.

If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).

Returns:

  • (Array<String>)


3212
3213
3214
3215
3216
3217
3218
3219
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3212

class DescribeOptOutListsRequest < Struct.new(
  :opt_out_list_names,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

Use SELF to filter the list of Opt-Out List to ones your account owns or use SHARED to filter on Opt-Out List shared with your account. The Owner and OptOutListNames parameters can't be used at the same time.

Returns:

  • (String)


3212
3213
3214
3215
3216
3217
3218
3219
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3212

class DescribeOptOutListsRequest < Struct.new(
  :opt_out_list_names,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end