Class: Aws::PinpointSMSVoiceV2::Types::DescribeOptedOutNumbersResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DescribeOptedOutNumbersResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#opt_out_list_arn ⇒ String
The Amazon Resource Name (ARN) of the OptOutList.
-
#opt_out_list_name ⇒ String
The name of the OptOutList.
-
#opted_out_numbers ⇒ Array<Types::OptedOutNumberInformation>
An array of OptedOutNumbersInformation objects that provide information about the requested OptedOutNumbers.
Instance Attribute Details
#next_token ⇒ String
The token to be used for the next set of paginated results. If this field is empty then there are no more results.
3301 3302 3303 3304 3305 3306 3307 3308 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3301 class DescribeOptedOutNumbersResult < Struct.new( :opt_out_list_arn, :opt_out_list_name, :opted_out_numbers, :next_token) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_arn ⇒ String
The Amazon Resource Name (ARN) of the OptOutList.
3301 3302 3303 3304 3305 3306 3307 3308 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3301 class DescribeOptedOutNumbersResult < Struct.new( :opt_out_list_arn, :opt_out_list_name, :opted_out_numbers, :next_token) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The name of the OptOutList.
3301 3302 3303 3304 3305 3306 3307 3308 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3301 class DescribeOptedOutNumbersResult < Struct.new( :opt_out_list_arn, :opt_out_list_name, :opted_out_numbers, :next_token) SENSITIVE = [] include Aws::Structure end |
#opted_out_numbers ⇒ Array<Types::OptedOutNumberInformation>
An array of OptedOutNumbersInformation objects that provide information about the requested OptedOutNumbers.
3301 3302 3303 3304 3305 3306 3307 3308 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3301 class DescribeOptedOutNumbersResult < Struct.new( :opt_out_list_arn, :opt_out_list_name, :opted_out_numbers, :next_token) SENSITIVE = [] include Aws::Structure end |