Class: Aws::PinpointSMSVoiceV2::Types::DescribePhoneNumbersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::PhoneNumberFilter>

An array of PhoneNumberFilter objects to filter the results.

Returns:



3341
3342
3343
3344
3345
3346
3347
3348
3349
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3341

class DescribePhoneNumbersRequest < Struct.new(
  :phone_number_ids,
  :filters,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per each request.

Returns:

  • (Integer)


3341
3342
3343
3344
3345
3346
3347
3348
3349
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3341

class DescribePhoneNumbersRequest < Struct.new(
  :phone_number_ids,
  :filters,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.

Returns:

  • (String)


3341
3342
3343
3344
3345
3346
3347
3348
3349
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3341

class DescribePhoneNumbersRequest < Struct.new(
  :phone_number_ids,
  :filters,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

Use SELF to filter the list of phone numbers to ones your account owns or use SHARED to filter on phone numbers shared with your account. The Owner and PhoneNumberIds parameters can't be used at the same time.

Returns:

  • (String)


3341
3342
3343
3344
3345
3346
3347
3348
3349
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3341

class DescribePhoneNumbersRequest < Struct.new(
  :phone_number_ids,
  :filters,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_idsArray<String>

The unique identifier of phone numbers to find information about. This is an array of strings that can be either the PhoneNumberId or PhoneNumberArn.

If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).

Returns:

  • (Array<String>)


3341
3342
3343
3344
3345
3346
3347
3348
3349
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3341

class DescribePhoneNumbersRequest < Struct.new(
  :phone_number_ids,
  :filters,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end