Class: Aws::PinpointSMSVoiceV2::Types::DescribePoolsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DescribePoolsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::PoolFilter>
An array of PoolFilter objects to filter the results.
-
#max_results ⇒ Integer
The maximum number of results to return per each request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#owner ⇒ String
Use
SELFto filter the list of Pools to ones your account owns or useSHAREDto filter on Pools shared with your account. -
#pool_ids ⇒ Array<String>
The unique identifier of pools to find.
Instance Attribute Details
#filters ⇒ Array<Types::PoolFilter>
An array of PoolFilter objects to filter the results.
3399 3400 3401 3402 3403 3404 3405 3406 3407 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3399 class DescribePoolsRequest < Struct.new( :pool_ids, :filters, :next_token, :max_results, :owner) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per each request.
3399 3400 3401 3402 3403 3404 3405 3406 3407 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3399 class DescribePoolsRequest < Struct.new( :pool_ids, :filters, :next_token, :max_results, :owner) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.
3399 3400 3401 3402 3403 3404 3405 3406 3407 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3399 class DescribePoolsRequest < Struct.new( :pool_ids, :filters, :next_token, :max_results, :owner) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
Use SELF to filter the list of Pools to ones your account owns or
use SHARED to filter on Pools shared with your account. The
Owner and PoolIds parameters can't be used at the same time.
3399 3400 3401 3402 3403 3404 3405 3406 3407 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3399 class DescribePoolsRequest < Struct.new( :pool_ids, :filters, :next_token, :max_results, :owner) SENSITIVE = [] include Aws::Structure end |
#pool_ids ⇒ Array<String>
The unique identifier of pools to find. This is an array of strings that can be either the PoolId or PoolArn.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
3399 3400 3401 3402 3403 3404 3405 3406 3407 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3399 class DescribePoolsRequest < Struct.new( :pool_ids, :filters, :next_token, :max_results, :owner) SENSITIVE = [] include Aws::Structure end |