Class: Aws::PinpointSMSVoiceV2::Types::DescribeProtectConfigurationsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.

Returns:

  • (String)


3371
3372
3373
3374
3375
3376
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3371

class DescribeProtectConfigurationsResult < Struct.new(
  :protect_configurations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#protect_configurationsArray<Types::ProtectConfigurationInformation>

An array of ProtectConfigurationInformation objects that contain the details for the request.



3371
3372
3373
3374
3375
3376
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3371

class DescribeProtectConfigurationsResult < Struct.new(
  :protect_configurations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end