Class: Aws::PinpointSMSVoiceV2::Types::DescribeRcsAgentCountryLaunchStatusResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#country_launch_statusArray<Types::CountryLaunchStatusInformation>

An array of CountryLaunchStatusInformation objects that contain the per-country launch status details.



3531
3532
3533
3534
3535
3536
3537
3538
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3531

class DescribeRcsAgentCountryLaunchStatusResult < Struct.new(
  :rcs_agent_id,
  :rcs_agent_arn,
  :country_launch_status,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results. If this field is empty then there are no more results.

Returns:

  • (String)


3531
3532
3533
3534
3535
3536
3537
3538
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3531

class DescribeRcsAgentCountryLaunchStatusResult < Struct.new(
  :rcs_agent_id,
  :rcs_agent_arn,
  :country_launch_status,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#rcs_agent_arnString

The Amazon Resource Name (ARN) of the RCS agent.

Returns:

  • (String)


3531
3532
3533
3534
3535
3536
3537
3538
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3531

class DescribeRcsAgentCountryLaunchStatusResult < Struct.new(
  :rcs_agent_id,
  :rcs_agent_arn,
  :country_launch_status,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#rcs_agent_idString

The unique identifier for the RCS agent.

Returns:

  • (String)


3531
3532
3533
3534
3535
3536
3537
3538
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3531

class DescribeRcsAgentCountryLaunchStatusResult < Struct.new(
  :rcs_agent_id,
  :rcs_agent_arn,
  :country_launch_status,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end