Class: Aws::PinpointSMSVoiceV2::Types::DescribeRcsAgentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::RcsAgentFilter>

An array of RcsAgentFilter objects to filter the results.

Returns:



3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3567

class DescribeRcsAgentsRequest < Struct.new(
  :rcs_agent_ids,
  :owner,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per each request.

Returns:

  • (Integer)


3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3567

class DescribeRcsAgentsRequest < Struct.new(
  :rcs_agent_ids,
  :owner,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.

Returns:

  • (String)


3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3567

class DescribeRcsAgentsRequest < Struct.new(
  :rcs_agent_ids,
  :owner,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

Use SELF to filter the list of RCS agents to ones your account owns or use SHARED to filter on RCS agents shared with your account. The Owner and RcsAgentIds parameters can't be used at the same time.

Returns:

  • (String)


3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3567

class DescribeRcsAgentsRequest < Struct.new(
  :rcs_agent_ids,
  :owner,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#rcs_agent_idsArray<String>

An array of unique identifiers for the RCS agents. This is an array of strings that can be either the RcsAgentId or RcsAgentArn.

Returns:

  • (Array<String>)


3567
3568
3569
3570
3571
3572
3573
3574
3575
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3567

class DescribeRcsAgentsRequest < Struct.new(
  :rcs_agent_ids,
  :owner,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end