Class: Aws::PinpointSMSVoiceV2::Types::DescribeRcsAgentsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DescribeRcsAgentsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#rcs_agents ⇒ Array<Types::RcsAgentInformation>
An array of RcsAgentInformation objects that contain the details for the requested RCS agents.
Instance Attribute Details
#next_token ⇒ String
The token to be used for the next set of paginated results. If this field is empty then there are no more results.
3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3443 class DescribeRcsAgentsResult < Struct.new( :rcs_agents, :next_token) SENSITIVE = [] include Aws::Structure end |
#rcs_agents ⇒ Array<Types::RcsAgentInformation>
An array of RcsAgentInformation objects that contain the details for the requested RCS agents.
3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3443 class DescribeRcsAgentsResult < Struct.new( :rcs_agents, :next_token) SENSITIVE = [] include Aws::Structure end |