Class: Aws::PinpointSMSVoiceV2::Types::DescribeRegistrationAttachmentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::RegistrationAttachmentFilter>

An array of RegistrationAttachmentFilter objects to filter the results.



3617
3618
3619
3620
3621
3622
3623
3624
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3617

class DescribeRegistrationAttachmentsRequest < Struct.new(
  :registration_attachment_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per each request.

Returns:

  • (Integer)


3617
3618
3619
3620
3621
3622
3623
3624
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3617

class DescribeRegistrationAttachmentsRequest < Struct.new(
  :registration_attachment_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.

Returns:

  • (String)


3617
3618
3619
3620
3621
3622
3623
3624
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3617

class DescribeRegistrationAttachmentsRequest < Struct.new(
  :registration_attachment_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#registration_attachment_idsArray<String>

The unique identifier of registration attachments to find. This is an array of RegistrationAttachmentId.

Returns:

  • (Array<String>)


3617
3618
3619
3620
3621
3622
3623
3624
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3617

class DescribeRegistrationAttachmentsRequest < Struct.new(
  :registration_attachment_ids,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end