Class: Aws::PinpointSMSVoiceV2::Types::DescribeRegistrationFieldValuesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_paths ⇒ Array<String>

An array of paths to the registration form field.

Returns:

  • (Array<String>)


3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3731

class DescribeRegistrationFieldValuesRequest < Struct.new(
  :registration_id,
  :version_number,
  :section_path,
  :field_paths,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return per each request.

Returns:

  • (Integer)


3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3731

class DescribeRegistrationFieldValuesRequest < Struct.new(
  :registration_id,
  :version_number,
  :section_path,
  :field_paths,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.

Returns:

  • (String)


3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3731

class DescribeRegistrationFieldValuesRequest < Struct.new(
  :registration_id,
  :version_number,
  :section_path,
  :field_paths,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#registration_id ⇒ String

The unique identifier for the registration.

Returns:

  • (String)


3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3731

class DescribeRegistrationFieldValuesRequest < Struct.new(
  :registration_id,
  :version_number,
  :section_path,
  :field_paths,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#section_path ⇒ String

The path to the section of the registration.

Returns:

  • (String)


3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3731

class DescribeRegistrationFieldValuesRequest < Struct.new(
  :registration_id,
  :version_number,
  :section_path,
  :field_paths,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#version_number ⇒ Integer

The version number of the registration.

Returns:

  • (Integer)


3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3731

class DescribeRegistrationFieldValuesRequest < Struct.new(
  :registration_id,
  :version_number,
  :section_path,
  :field_paths,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end