Class: Aws::PinpointSMSVoiceV2::Types::DescribeSenderIdsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DescribeSenderIdsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::SenderIdFilter>
An array of SenderIdFilter objects to filter the results.
-
#max_results ⇒ Integer
The maximum number of results to return per each request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#owner ⇒ String
Use
SELFto filter the list of Sender Ids to ones your account owns or useSHAREDto filter on Sender Ids shared with your account. -
#sender_ids ⇒ Array<Types::SenderIdAndCountry>
An array of SenderIdAndCountry objects to search for.
Instance Attribute Details
#filters ⇒ Array<Types::SenderIdFilter>
An array of SenderIdFilter objects to filter the results.
4013 4014 4015 4016 4017 4018 4019 4020 4021 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4013 class DescribeSenderIdsRequest < Struct.new( :sender_ids, :filters, :next_token, :max_results, :owner) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per each request.
4013 4014 4015 4016 4017 4018 4019 4020 4021 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4013 class DescribeSenderIdsRequest < Struct.new( :sender_ids, :filters, :next_token, :max_results, :owner) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.
4013 4014 4015 4016 4017 4018 4019 4020 4021 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4013 class DescribeSenderIdsRequest < Struct.new( :sender_ids, :filters, :next_token, :max_results, :owner) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
Use SELF to filter the list of Sender Ids to ones your account
owns or use SHARED to filter on Sender Ids shared with your
account. The Owner and SenderIds parameters can't be used at
the same time.
4013 4014 4015 4016 4017 4018 4019 4020 4021 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4013 class DescribeSenderIdsRequest < Struct.new( :sender_ids, :filters, :next_token, :max_results, :owner) SENSITIVE = [] include Aws::Structure end |
#sender_ids ⇒ Array<Types::SenderIdAndCountry>
An array of SenderIdAndCountry objects to search for.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
4013 4014 4015 4016 4017 4018 4019 4020 4021 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4013 class DescribeSenderIdsRequest < Struct.new( :sender_ids, :filters, :next_token, :max_results, :owner) SENSITIVE = [] include Aws::Structure end |