Class: Aws::PinpointSMSVoiceV2::Types::EventDestination

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Contains information about an event destination.

Event destinations are associated with configuration sets, which enable you to publish message sending events to CloudWatch, Firehose, or Amazon SNS.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_watch_logs_destinationTypes::CloudWatchLogsDestination

An object that contains information about an event destination that sends logging events to Amazon CloudWatch logs.



4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4267

class EventDestination < Struct.new(
  :event_destination_name,
  :enabled,
  :matching_event_types,
  :cloud_watch_logs_destination,
  :kinesis_firehose_destination,
  :sns_destination)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

When set to true events will be logged.

Returns:

  • (Boolean)


4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4267

class EventDestination < Struct.new(
  :event_destination_name,
  :enabled,
  :matching_event_types,
  :cloud_watch_logs_destination,
  :kinesis_firehose_destination,
  :sns_destination)
  SENSITIVE = []
  include Aws::Structure
end

#event_destination_nameString

The name of the EventDestination.

Returns:

  • (String)


4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4267

class EventDestination < Struct.new(
  :event_destination_name,
  :enabled,
  :matching_event_types,
  :cloud_watch_logs_destination,
  :kinesis_firehose_destination,
  :sns_destination)
  SENSITIVE = []
  include Aws::Structure
end

#kinesis_firehose_destinationTypes::KinesisFirehoseDestination

An object that contains information about an event destination for logging to Amazon Data Firehose.



4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4267

class EventDestination < Struct.new(
  :event_destination_name,
  :enabled,
  :matching_event_types,
  :cloud_watch_logs_destination,
  :kinesis_firehose_destination,
  :sns_destination)
  SENSITIVE = []
  include Aws::Structure
end

#matching_event_typesArray<String>

An array of event types that determine which events to log.

The TEXT_SENT event type is not supported.

Returns:

  • (Array<String>)


4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4267

class EventDestination < Struct.new(
  :event_destination_name,
  :enabled,
  :matching_event_types,
  :cloud_watch_logs_destination,
  :kinesis_firehose_destination,
  :sns_destination)
  SENSITIVE = []
  include Aws::Structure
end

#sns_destinationTypes::SnsDestination

An object that contains information about an event destination that sends logging events to Amazon SNS.



4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4267

class EventDestination < Struct.new(
  :event_destination_name,
  :enabled,
  :matching_event_types,
  :cloud_watch_logs_destination,
  :kinesis_firehose_destination,
  :sns_destination)
  SENSITIVE = []
  include Aws::Structure
end