Class: Aws::PinpointSMSVoiceV2::Types::GetProtectConfigurationCountryRuleSetResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#country_rule_setHash<String,Types::ProtectConfigurationCountryRuleSetInformation>

A map of ProtectConfigurationCountryRuleSetInformation objects that contain the details for the requested NumberCapability. The Key is the two-letter ISO country code. For a list of supported ISO country codes, see Supported countries and regions (SMS channel) in the End User Messaging SMS User Guide.



4323
4324
4325
4326
4327
4328
4329
4330
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4323

class GetProtectConfigurationCountryRuleSetResult < Struct.new(
  :protect_configuration_arn,
  :protect_configuration_id,
  :number_capability,
  :country_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#number_capabilityString

The capability type associated with the returned ProtectConfigurationCountryRuleSetInformation objects.

Returns:

  • (String)


4323
4324
4325
4326
4327
4328
4329
4330
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4323

class GetProtectConfigurationCountryRuleSetResult < Struct.new(
  :protect_configuration_arn,
  :protect_configuration_id,
  :number_capability,
  :country_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#protect_configuration_arnString

The Amazon Resource Name (ARN) of the protect configuration.

Returns:

  • (String)


4323
4324
4325
4326
4327
4328
4329
4330
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4323

class GetProtectConfigurationCountryRuleSetResult < Struct.new(
  :protect_configuration_arn,
  :protect_configuration_id,
  :number_capability,
  :country_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#protect_configuration_idString

The unique identifier for the protect configuration.

Returns:

  • (String)


4323
4324
4325
4326
4327
4328
4329
4330
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4323

class GetProtectConfigurationCountryRuleSetResult < Struct.new(
  :protect_configuration_arn,
  :protect_configuration_id,
  :number_capability,
  :country_rule_set)
  SENSITIVE = []
  include Aws::Structure
end