Class: Aws::PinpointSMSVoiceV2::Types::ListNotifyCountriesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::ListNotifyCountriesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#notify_countries ⇒ Array<Types::NotifyCountryInformation>
An array of NotifyCountryInformation objects that contain the results.
Instance Attribute Details
#next_token ⇒ String
The token to be used for the next set of paginated results. If this field is empty then there are no more results.
4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4713 class ListNotifyCountriesResult < Struct.new( :notify_countries, :next_token) SENSITIVE = [] include Aws::Structure end |
#notify_countries ⇒ Array<Types::NotifyCountryInformation>
An array of NotifyCountryInformation objects that contain the results.
4713 4714 4715 4716 4717 4718 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4713 class ListNotifyCountriesResult < Struct.new( :notify_countries, :next_token) SENSITIVE = [] include Aws::Structure end |