Class: Aws::PinpointSMSVoiceV2::Types::ListPoolOriginationIdentitiesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filters ⇒ Array<Types::PoolOriginationIdentitiesFilter>

An array of PoolOriginationIdentitiesFilter objects to filter the results..



4744
4745
4746
4747
4748
4749
4750
4751
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4744

class ListPoolOriginationIdentitiesRequest < Struct.new(
  :pool_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return per each request.

Returns:

  • (Integer)


4744
4745
4746
4747
4748
4749
4750
4751
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4744

class ListPoolOriginationIdentitiesRequest < Struct.new(
  :pool_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.

Returns:

  • (String)


4744
4745
4746
4747
4748
4749
4750
4751
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4744

class ListPoolOriginationIdentitiesRequest < Struct.new(
  :pool_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#pool_id ⇒ String

The unique identifier for the pool. This value can be either the PoolId or PoolArn.

If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).

Returns:

  • (String)


4744
4745
4746
4747
4748
4749
4750
4751
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4744

class ListPoolOriginationIdentitiesRequest < Struct.new(
  :pool_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end