Class: Aws::PinpointSMSVoiceV2::Types::ListPoolOriginationIdentitiesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::ListPoolOriginationIdentitiesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#origination_identities ⇒ Array<Types::OriginationIdentityMetadata>
An array of any OriginationIdentityMetadata objects.
-
#pool_arn ⇒ String
The Amazon Resource Name (ARN) for the pool.
-
#pool_id ⇒ String
The unique PoolId of the pool.
Instance Attribute Details
#next_token ⇒ String
The token to be used for the next set of paginated results. If this field is empty then there are no more results.
4772 4773 4774 4775 4776 4777 4778 4779 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4772 class ListPoolOriginationIdentitiesResult < Struct.new( :pool_arn, :pool_id, :origination_identities, :next_token) SENSITIVE = [] include Aws::Structure end |
#origination_identities ⇒ Array<Types::OriginationIdentityMetadata>
An array of any OriginationIdentityMetadata objects.
4772 4773 4774 4775 4776 4777 4778 4779 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4772 class ListPoolOriginationIdentitiesResult < Struct.new( :pool_arn, :pool_id, :origination_identities, :next_token) SENSITIVE = [] include Aws::Structure end |
#pool_arn ⇒ String
The Amazon Resource Name (ARN) for the pool.
4772 4773 4774 4775 4776 4777 4778 4779 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4772 class ListPoolOriginationIdentitiesResult < Struct.new( :pool_arn, :pool_id, :origination_identities, :next_token) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The unique PoolId of the pool.
4772 4773 4774 4775 4776 4777 4778 4779 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4772 class ListPoolOriginationIdentitiesResult < Struct.new( :pool_arn, :pool_id, :origination_identities, :next_token) SENSITIVE = [] include Aws::Structure end |