Class: Aws::PinpointSMSVoiceV2::Types::ListProtectConfigurationRuleSetNumberOverridesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filters ⇒ Array<Types::ProtectConfigurationRuleSetNumberOverrideFilterItem>

An array of ProtectConfigurationRuleSetNumberOverrideFilterItem objects to filter the results.



4801
4802
4803
4804
4805
4806
4807
4808
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4801

class ListProtectConfigurationRuleSetNumberOverridesRequest < Struct.new(
  :protect_configuration_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return per each request.

Returns:

  • (Integer)


4801
4802
4803
4804
4805
4806
4807
4808
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4801

class ListProtectConfigurationRuleSetNumberOverridesRequest < Struct.new(
  :protect_configuration_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.

Returns:

  • (String)


4801
4802
4803
4804
4805
4806
4807
4808
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4801

class ListProtectConfigurationRuleSetNumberOverridesRequest < Struct.new(
  :protect_configuration_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#protect_configuration_id ⇒ String

The unique identifier for the protect configuration.

Returns:

  • (String)


4801
4802
4803
4804
4805
4806
4807
4808
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4801

class ListProtectConfigurationRuleSetNumberOverridesRequest < Struct.new(
  :protect_configuration_id,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end