Class: Aws::PinpointSMSVoiceV2::Types::ListProtectConfigurationRuleSetNumberOverridesResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.

Returns:

  • (String)


4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4829

class ListProtectConfigurationRuleSetNumberOverridesResult < Struct.new(
  :protect_configuration_arn,
  :protect_configuration_id,
  :rule_set_number_overrides,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#protect_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of the protect configuration.

Returns:

  • (String)


4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4829

class ListProtectConfigurationRuleSetNumberOverridesResult < Struct.new(
  :protect_configuration_arn,
  :protect_configuration_id,
  :rule_set_number_overrides,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#protect_configuration_id ⇒ String

The unique identifier for the protect configuration.

Returns:

  • (String)


4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4829

class ListProtectConfigurationRuleSetNumberOverridesResult < Struct.new(
  :protect_configuration_arn,
  :protect_configuration_id,
  :rule_set_number_overrides,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#rule_set_number_overrides ⇒ Array<Types::ProtectConfigurationRuleSetNumberOverride>

An array of RuleSetNumberOverrides objects.



4829
4830
4831
4832
4833
4834
4835
4836
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4829

class ListProtectConfigurationRuleSetNumberOverridesResult < Struct.new(
  :protect_configuration_arn,
  :protect_configuration_id,
  :rule_set_number_overrides,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end