Class: Aws::PinpointSMSVoiceV2::Types::ListRegistrationAssociationsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.

Returns:

  • (String)


4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4891

class ListRegistrationAssociationsResult < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_associations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#registration_arn ⇒ String

The Amazon Resource Name (ARN) for the registration.

Returns:

  • (String)


4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4891

class ListRegistrationAssociationsResult < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_associations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#registration_associations ⇒ Array<Types::RegistrationAssociationMetadata>

An array of RegistrationAssociationMetadata objects.



4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4891

class ListRegistrationAssociationsResult < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_associations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#registration_id ⇒ String

The unique identifier for the registration.

Returns:

  • (String)


4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4891

class ListRegistrationAssociationsResult < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_associations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#registration_type ⇒ String

The type of registration form. The list of RegistrationTypes can be found using the DescribeRegistrationTypeDefinitions action.

Returns:

  • (String)


4891
4892
4893
4894
4895
4896
4897
4898
4899
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4891

class ListRegistrationAssociationsResult < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_associations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end