Class: Aws::PinpointSMSVoiceV2::Types::NotifyCountryInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

The information for a country that supports notify messaging.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#country_name ⇒ String

The name of the country.

Returns:

  • (String)


5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5097

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end

#customer_owned_identity_required ⇒ Boolean

Whether a customer-owned identity is required to send notify messages to this country.

Returns:

  • (Boolean)


5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5097

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end

#iso_country_code ⇒ String

The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.

Returns:

  • (String)


5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5097

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end

#supported_channels ⇒ Array<String>

An array of supported channels for the country. Supported values include SMS and VOICE.

Returns:

  • (Array<String>)


5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5097

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end

#supported_tiers ⇒ Array<String>

An array of supported tiers for the country.

Returns:

  • (Array<String>)


5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5097

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end

#supported_use_cases ⇒ Array<String>

An array of supported use cases for the country.

Returns:

  • (Array<String>)


5097
5098
5099
5100
5101
5102
5103
5104
5105
5106
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5097

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end