Class: Aws::PinpointSMSVoiceV2::Types::NumberPreferenceItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::NumberPreferenceItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
A single number preference — specifies a pattern type and filter value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Array<String>
The digit pattern values to match against available phone numbers, using the specified preference type.
-
#preference_type ⇒ Array<String>
The type of match to apply to the filter values.
Instance Attribute Details
#filter ⇒ Array<String>
The digit pattern values to match against available phone numbers, using the specified preference type.
5226 5227 5228 5229 5230 5231 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5226 class NumberPreferenceItem < Struct.new( :preference_type, :filter) SENSITIVE = [] include Aws::Structure end |
#preference_type ⇒ Array<String>
The type of match to apply to the filter values.
-
StartsWith: Returns numbers that begin with the filter value. -
EndsWith: Returns numbers that end with the filter value. -
Contains: Returns numbers that contain the filter value. -
ExactMatch: Returns the number that exactly matches the filter value.
5226 5227 5228 5229 5230 5231 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5226 class NumberPreferenceItem < Struct.new( :preference_type, :filter) SENSITIVE = [] include Aws::Structure end |