Class: Aws::PinpointSMSVoiceV2::Types::PoolInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

The information for a pool in an Amazon Web Services account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestamp ⇒ Time

The time when the pool was created, in UNIX epoch time format.

Returns:

  • (Time)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection_enabled ⇒ Boolean

When set to true the pool can't be deleted.

Returns:

  • (Boolean)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#message_type ⇒ String

The type of message. Valid values are TRANSACTIONAL for messages that are critical or time-sensitive and PROMOTIONAL for messages that aren't critical or time-sensitive.

Returns:

  • (String)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_name ⇒ String

The name of the OptOutList associated with the pool.

Returns:

  • (String)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#pool_arn ⇒ String

The Amazon Resource Name (ARN) for the pool.

Returns:

  • (String)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#pool_id ⇒ String

The unique identifier for the pool.

Returns:

  • (String)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_opt_outs_enabled ⇒ Boolean

When set to false, an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests. For more information see Self-managed opt-outs

Returns:

  • (Boolean)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#shared_routes_enabled ⇒ Boolean

Allows you to enable shared routes on your pool.

By default, this is set to False. If you set this value to True, your messages are sent using phone numbers or sender IDs (depending on the country) that are shared with other users. In some countries, such as the United States, senders aren't allowed to use shared routes and must use a dedicated phone number or short code.

Returns:

  • (Boolean)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the pool.

Returns:

  • (String)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_arn ⇒ String

The Amazon Resource Name (ARN) of the two way channel.

Returns:

  • (String)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_role ⇒ String

An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.

Returns:

  • (String)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_enabled ⇒ Boolean

When set to true you can receive incoming text messages from your end recipients using the TwoWayChannelArn.

Returns:

  • (Boolean)


5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5598

class PoolInformation < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end