Class: Aws::PinpointSMSVoiceV2::Types::ProtectConfigurationRuleSetNumberOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::ProtectConfigurationRuleSetNumberOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Provides details on phone number rule overrides for a protect configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action for the rule to perform of either blocking or allowing messages to the destination phone number.
-
#created_timestamp ⇒ Time
The time when the rule was created, in [UNIX epoch time][1] format.
-
#destination_phone_number ⇒ String
The destination phone number in E.164 format.
-
#expiration_timestamp ⇒ Time
The time the rule will expire at.
-
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
Instance Attribute Details
#action ⇒ String
The action for the rule to perform of either blocking or allowing messages to the destination phone number.
5475 5476 5477 5478 5479 5480 5481 5482 5483 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5475 class ProtectConfigurationRuleSetNumberOverride < Struct.new( :destination_phone_number, :created_timestamp, :action, :iso_country_code, :expiration_timestamp) SENSITIVE = [] include Aws::Structure end |
#created_timestamp ⇒ Time
The time when the rule was created, in UNIX epoch time format.
5475 5476 5477 5478 5479 5480 5481 5482 5483 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5475 class ProtectConfigurationRuleSetNumberOverride < Struct.new( :destination_phone_number, :created_timestamp, :action, :iso_country_code, :expiration_timestamp) SENSITIVE = [] include Aws::Structure end |
#destination_phone_number ⇒ String
The destination phone number in E.164 format.
5475 5476 5477 5478 5479 5480 5481 5482 5483 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5475 class ProtectConfigurationRuleSetNumberOverride < Struct.new( :destination_phone_number, :created_timestamp, :action, :iso_country_code, :expiration_timestamp) SENSITIVE = [] include Aws::Structure end |
#expiration_timestamp ⇒ Time
The time the rule will expire at. If ExpirationTimestamp is not
set then the rule will not expire.
5475 5476 5477 5478 5479 5480 5481 5482 5483 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5475 class ProtectConfigurationRuleSetNumberOverride < Struct.new( :destination_phone_number, :created_timestamp, :action, :iso_country_code, :expiration_timestamp) SENSITIVE = [] include Aws::Structure end |
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
5475 5476 5477 5478 5479 5480 5481 5482 5483 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5475 class ProtectConfigurationRuleSetNumberOverride < Struct.new( :destination_phone_number, :created_timestamp, :action, :iso_country_code, :expiration_timestamp) SENSITIVE = [] include Aws::Structure end |