Class: Aws::PinpointSMSVoiceV2::Types::PutKeywordRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#keyword ⇒ String

The new keyword to add.

Returns:

  • (String)


5804
5805
5806
5807
5808
5809
5810
5811
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5804

class PutKeywordRequest < Struct.new(
  :origination_identity,
  :keyword,
  :keyword_message,
  :keyword_action)
  SENSITIVE = []
  include Aws::Structure
end

#keyword_action ⇒ String

The action to perform for the new keyword when it is received.

  • AUTOMATIC_RESPONSE: A message is sent to the recipient.

  • OPT_OUT: Keeps the recipient from receiving future messages.

  • OPT_IN: The recipient wants to receive future messages.

Returns:

  • (String)


5804
5805
5806
5807
5808
5809
5810
5811
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5804

class PutKeywordRequest < Struct.new(
  :origination_identity,
  :keyword,
  :keyword_message,
  :keyword_action)
  SENSITIVE = []
  include Aws::Structure
end

#keyword_message ⇒ String

The message associated with the keyword.

Returns:

  • (String)


5804
5805
5806
5807
5808
5809
5810
5811
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5804

class PutKeywordRequest < Struct.new(
  :origination_identity,
  :keyword,
  :keyword_message,
  :keyword_action)
  SENSITIVE = []
  include Aws::Structure
end

#origination_identity ⇒ String

The origination identity to use such as a PhoneNumberId, PhoneNumberArn, SenderId or SenderIdArn. You can use DescribePhoneNumbers get the values for PhoneNumberId and PhoneNumberArn while DescribeSenderIds can be used to get the values for SenderId and SenderIdArn.

If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).

Returns:

  • (String)


5804
5805
5806
5807
5808
5809
5810
5811
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5804

class PutKeywordRequest < Struct.new(
  :origination_identity,
  :keyword,
  :keyword_message,
  :keyword_action)
  SENSITIVE = []
  include Aws::Structure
end