Class: Aws::PinpointSMSVoiceV2::Types::PutOptedOutNumberResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::PutOptedOutNumberResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_user_opted_out ⇒ Boolean
This is true if it was the end user who requested their phone number be removed.
-
#opt_out_list_arn ⇒ String
The OptOutListArn that the phone number was removed from.
-
#opt_out_list_name ⇒ String
The OptOutListName that the phone number was removed from.
-
#opted_out_number ⇒ String
The phone number that was added to the OptOutList.
-
#opted_out_timestamp ⇒ Time
The time that the phone number was added to the OptOutList, in [UNIX epoch time][1] format.
Instance Attribute Details
#end_user_opted_out ⇒ Boolean
This is true if it was the end user who requested their phone number be removed.
5659 5660 5661 5662 5663 5664 5665 5666 5667 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5659 class PutOptedOutNumberResult < Struct.new( :opt_out_list_arn, :opt_out_list_name, :opted_out_number, :opted_out_timestamp, :end_user_opted_out) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_arn ⇒ String
The OptOutListArn that the phone number was removed from.
5659 5660 5661 5662 5663 5664 5665 5666 5667 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5659 class PutOptedOutNumberResult < Struct.new( :opt_out_list_arn, :opt_out_list_name, :opted_out_number, :opted_out_timestamp, :end_user_opted_out) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The OptOutListName that the phone number was removed from.
5659 5660 5661 5662 5663 5664 5665 5666 5667 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5659 class PutOptedOutNumberResult < Struct.new( :opt_out_list_arn, :opt_out_list_name, :opted_out_number, :opted_out_timestamp, :end_user_opted_out) SENSITIVE = [] include Aws::Structure end |
#opted_out_number ⇒ String
The phone number that was added to the OptOutList.
5659 5660 5661 5662 5663 5664 5665 5666 5667 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5659 class PutOptedOutNumberResult < Struct.new( :opt_out_list_arn, :opt_out_list_name, :opted_out_number, :opted_out_timestamp, :end_user_opted_out) SENSITIVE = [] include Aws::Structure end |
#opted_out_timestamp ⇒ Time
The time that the phone number was added to the OptOutList, in UNIX epoch time format.
5659 5660 5661 5662 5663 5664 5665 5666 5667 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5659 class PutOptedOutNumberResult < Struct.new( :opt_out_list_arn, :opt_out_list_name, :opted_out_number, :opted_out_timestamp, :end_user_opted_out) SENSITIVE = [] include Aws::Structure end |