Class: Aws::PinpointSMSVoiceV2::Types::RcsCardContent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

The content of a rich card, including title, description, media, and card-level suggested actions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description text of the card. Maximum 2000 characters.

Returns:

  • (String)


6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6019

class RcsCardContent < Struct.new(
  :title,
  :description,
  :media,
  :suggestions)
  SENSITIVE = []
  include Aws::Structure
end

#mediaTypes::RcsCardMedia

The media content of the card, including the file URL, optional thumbnail, and display height.

Returns:



6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6019

class RcsCardContent < Struct.new(
  :title,
  :description,
  :media,
  :suggestions)
  SENSITIVE = []
  include Aws::Structure
end

#suggestionsArray<Types::RcsSuggestedAction>

Card-level suggested actions. Maximum 4 suggestions per card.

Returns:



6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6019

class RcsCardContent < Struct.new(
  :title,
  :description,
  :media,
  :suggestions)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the card. Maximum 200 characters.

Returns:

  • (String)


6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6019

class RcsCardContent < Struct.new(
  :title,
  :description,
  :media,
  :suggestions)
  SENSITIVE = []
  include Aws::Structure
end