Class: Aws::PinpointSMSVoiceV2::Types::RcsCardMedia

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

The media content of a rich card, including the file URL, optional thumbnail, and display height.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#file_urlString

The S3 URI of the media file for the card, in the format s3://bucket-name/key. Maximum 2000 characters.

Returns:

  • (String)


6048
6049
6050
6051
6052
6053
6054
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6048

class RcsCardMedia < Struct.new(
  :file_url,
  :thumbnail_url,
  :height)
  SENSITIVE = []
  include Aws::Structure
end

#heightString

The display height of the media in the card. Valid values are SHORT, MEDIUM, and TALL.

Returns:

  • (String)


6048
6049
6050
6051
6052
6053
6054
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6048

class RcsCardMedia < Struct.new(
  :file_url,
  :thumbnail_url,
  :height)
  SENSITIVE = []
  include Aws::Structure
end

#thumbnail_urlString

The S3 URI of an optional thumbnail image for the card media. Maximum 2000 characters.

Returns:

  • (String)


6048
6049
6050
6051
6052
6053
6054
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6048

class RcsCardMedia < Struct.new(
  :file_url,
  :thumbnail_url,
  :height)
  SENSITIVE = []
  include Aws::Structure
end