Class: Aws::PinpointSMSVoiceV2::Types::RcsCarouselCardMedia

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

The media content of a carousel card. Display height is restricted to SHORT or MEDIUM (TALL is not supported in carousels).

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#file_urlString

The S3 URI of the media file for the carousel card. Maximum 2000 characters.

Returns:

  • (String)


6129
6130
6131
6132
6133
6134
6135
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6129

class RcsCarouselCardMedia < Struct.new(
  :file_url,
  :thumbnail_url,
  :height)
  SENSITIVE = []
  include Aws::Structure
end

#heightString

The display height of the media in the carousel card. Valid values are SHORT and MEDIUM.

Returns:

  • (String)


6129
6130
6131
6132
6133
6134
6135
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6129

class RcsCarouselCardMedia < Struct.new(
  :file_url,
  :thumbnail_url,
  :height)
  SENSITIVE = []
  include Aws::Structure
end

#thumbnail_urlString

The S3 URI of an optional thumbnail image for the carousel card media. Maximum 2000 characters.

Returns:

  • (String)


6129
6130
6131
6132
6133
6134
6135
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6129

class RcsCarouselCardMedia < Struct.new(
  :file_url,
  :thumbnail_url,
  :height)
  SENSITIVE = []
  include Aws::Structure
end