Class: Aws::PinpointSMSVoiceV2::Types::RcsContent

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Note:

RcsContent is a union - when making an API calls you must set exactly one of the members.

The message body of an RCS message. Exactly one content type must be specified.

Defined Under Namespace

Classes: Carousel, FileMessage, RichCard, TextMessage, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

A carousel of 2 to 10 scrollable cards, each with media, title, description, and suggested actions.

Returns:



6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6296

class RcsContent < Struct.new(
  :text_message,
  :file_message,
  :rich_card,
  :carousel,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class TextMessage < RcsContent; end
  class FileMessage < RcsContent; end
  class RichCard < RcsContent; end
  class Carousel < RcsContent; end
  class Unknown < RcsContent; end
end

#file_messageTypes::RcsFileMessage

A file message containing a media file (image, video, audio, or PDF) with an optional thumbnail.



6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6296

class RcsContent < Struct.new(
  :text_message,
  :file_message,
  :rich_card,
  :carousel,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class TextMessage < RcsContent; end
  class FileMessage < RcsContent; end
  class RichCard < RcsContent; end
  class Carousel < RcsContent; end
  class Unknown < RcsContent; end
end

#rich_cardTypes::RcsStandaloneCard

A standalone rich card with media, title, description, and suggested actions.



6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6296

class RcsContent < Struct.new(
  :text_message,
  :file_message,
  :rich_card,
  :carousel,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class TextMessage < RcsContent; end
  class FileMessage < RcsContent; end
  class RichCard < RcsContent; end
  class Carousel < RcsContent; end
  class Unknown < RcsContent; end
end

#text_messageTypes::RcsTextMessage

A plain text RCS message.



6296
6297
6298
6299
6300
6301
6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6296

class RcsContent < Struct.new(
  :text_message,
  :file_message,
  :rich_card,
  :carousel,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class TextMessage < RcsContent; end
  class FileMessage < RcsContent; end
  class RichCard < RcsContent; end
  class Carousel < RcsContent; end
  class Unknown < RcsContent; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



6296
6297
6298
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6296

def unknown
  @unknown
end