Class: Aws::PinpointSMSVoiceV2::Types::RcsCreateCalendarEventAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

A suggested action that creates a calendar event on the recipient's device.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

An optional description for the calendar event. Maximum 500 characters.

Returns:

  • (String)


6211
6212
6213
6214
6215
6216
6217
6218
6219
6220
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6211

class RcsCreateCalendarEventAction < Struct.new(
  :text,
  :postback_data,
  :title,
  :start_time,
  :end_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The end time of the calendar event in ISO 8601 format.

Returns:

  • (Time)


6211
6212
6213
6214
6215
6216
6217
6218
6219
6220
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6211

class RcsCreateCalendarEventAction < Struct.new(
  :text,
  :postback_data,
  :title,
  :start_time,
  :end_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#postback_dataString

The postback data sent to your webhook when the user taps this action. Maximum 2048 characters.

Returns:

  • (String)


6211
6212
6213
6214
6215
6216
6217
6218
6219
6220
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6211

class RcsCreateCalendarEventAction < Struct.new(
  :text,
  :postback_data,
  :title,
  :start_time,
  :end_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The start time of the calendar event in ISO 8601 format.

Returns:

  • (Time)


6211
6212
6213
6214
6215
6216
6217
6218
6219
6220
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6211

class RcsCreateCalendarEventAction < Struct.new(
  :text,
  :postback_data,
  :title,
  :start_time,
  :end_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#textString

The display text of the action. Maximum 25 characters.

Returns:

  • (String)


6211
6212
6213
6214
6215
6216
6217
6218
6219
6220
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6211

class RcsCreateCalendarEventAction < Struct.new(
  :text,
  :postback_data,
  :title,
  :start_time,
  :end_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the calendar event. Maximum 100 characters.

Returns:

  • (String)


6211
6212
6213
6214
6215
6216
6217
6218
6219
6220
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6211

class RcsCreateCalendarEventAction < Struct.new(
  :text,
  :postback_data,
  :title,
  :start_time,
  :end_time,
  :description)
  SENSITIVE = []
  include Aws::Structure
end