Class: Aws::PinpointSMSVoiceV2::Types::RcsFileMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

A file message containing a media file (image, video, audio, or PDF) with an optional thumbnail.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#file_urlString

The S3 URI of the media file to send, in the format s3://bucket-name/key. The service downloads the file from your S3 bucket, rehosts it, and generates a presigned URL for the aggregator. Maximum 2000 characters.

Returns:

  • (String)


6303
6304
6305
6306
6307
6308
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6303

class RcsFileMessage < Struct.new(
  :file_url,
  :thumbnail_url)
  SENSITIVE = []
  include Aws::Structure
end

#thumbnail_urlString

The S3 URI of an optional thumbnail image for the media file, in the format s3://bucket-name/key. Maximum 2000 characters.

Returns:

  • (String)


6303
6304
6305
6306
6307
6308
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6303

class RcsFileMessage < Struct.new(
  :file_url,
  :thumbnail_url)
  SENSITIVE = []
  include Aws::Structure
end