Class: Aws::PinpointSMSVoiceV2::Types::RcsOpenUrlAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RcsOpenUrlAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
A suggested action that opens a URL in the recipient's browser or an in-app webview.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application ⇒ String
How to open the URL.
-
#postback_data ⇒ String
The postback data sent to your webhook when the user taps this action.
-
#text ⇒ String
The display text of the action.
-
#url ⇒ String
The URL to open.
-
#webview_view_mode ⇒ String
The display mode of the webview.
Instance Attribute Details
#application ⇒ String
How to open the URL. BROWSER opens in the device's default browser. WEBVIEW opens in an in-app webview.
6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6361 class RcsOpenUrlAction < Struct.new( :text, :postback_data, :url, :application, :webview_view_mode) SENSITIVE = [] include Aws::Structure end |
#postback_data ⇒ String
The postback data sent to your webhook when the user taps this action. Maximum 2048 characters.
6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6361 class RcsOpenUrlAction < Struct.new( :text, :postback_data, :url, :application, :webview_view_mode) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
The display text of the action. Maximum 25 characters.
6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6361 class RcsOpenUrlAction < Struct.new( :text, :postback_data, :url, :application, :webview_view_mode) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL to open. Must start with https://. Maximum 2048 characters.
6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6361 class RcsOpenUrlAction < Struct.new( :text, :postback_data, :url, :application, :webview_view_mode) SENSITIVE = [] include Aws::Structure end |
#webview_view_mode ⇒ String
The display mode of the webview. Valid values are FULL, HALF, and TALL. Only applicable when Application is WEBVIEW.
6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6361 class RcsOpenUrlAction < Struct.new( :text, :postback_data, :url, :application, :webview_view_mode) SENSITIVE = [] include Aws::Structure end |