Class: Aws::PinpointSMSVoiceV2::Types::RcsReplyAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RcsReplyAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
A suggested reply action that sends predefined text and postback data when tapped by the recipient.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#postback_data ⇒ String
The postback data sent to your webhook when the user taps this reply.
-
#text ⇒ String
The display text of the suggested reply.
Instance Attribute Details
#postback_data ⇒ String
The postback data sent to your webhook when the user taps this reply. Maximum 2048 characters.
6518 6519 6520 6521 6522 6523 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6518 class RcsReplyAction < Struct.new( :text, :postback_data) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
The display text of the suggested reply. Maximum 25 characters.
6518 6519 6520 6521 6522 6523 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6518 class RcsReplyAction < Struct.new( :text, :postback_data) SENSITIVE = [] include Aws::Structure end |