Class: Aws::PinpointSMSVoiceV2::Types::RcsRequestLocationAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RcsRequestLocationAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
A suggested action that requests the recipient's current location.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#postback_data ⇒ String
The postback data sent to your webhook when the user taps this action.
-
#text ⇒ String
The display text of the action.
Instance Attribute Details
#postback_data ⇒ String
The postback data sent to your webhook when the user taps this action. Maximum 2048 characters.
6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6405 class RcsRequestLocationAction < Struct.new( :text, :postback_data) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
The display text of the action. Maximum 25 characters.
6405 6406 6407 6408 6409 6410 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6405 class RcsRequestLocationAction < Struct.new( :text, :postback_data) SENSITIVE = [] include Aws::Structure end |