Class: Aws::PinpointSMSVoiceV2::Types::RcsShowLocationAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

A suggested action that shows a location on a map when tapped by the recipient.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#label ⇒ String

An optional label for the location pin. Maximum 100 characters.

Returns:

  • (String)


6712
6713
6714
6715
6716
6717
6718
6719
6720
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6712

class RcsShowLocationAction < Struct.new(
  :text,
  :postback_data,
  :latitude,
  :longitude,
  :label)
  SENSITIVE = []
  include Aws::Structure
end

#latitude ⇒ Float

The latitude of the location. Valid values are -90 to 90.

Returns:

  • (Float)


6712
6713
6714
6715
6716
6717
6718
6719
6720
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6712

class RcsShowLocationAction < Struct.new(
  :text,
  :postback_data,
  :latitude,
  :longitude,
  :label)
  SENSITIVE = []
  include Aws::Structure
end

#longitude ⇒ Float

The longitude of the location. Valid values are -180 to 180.

Returns:

  • (Float)


6712
6713
6714
6715
6716
6717
6718
6719
6720
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6712

class RcsShowLocationAction < Struct.new(
  :text,
  :postback_data,
  :latitude,
  :longitude,
  :label)
  SENSITIVE = []
  include Aws::Structure
end

#postback_data ⇒ String

The postback data sent to your webhook when the user taps this action. Maximum 2048 characters.

Returns:

  • (String)


6712
6713
6714
6715
6716
6717
6718
6719
6720
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6712

class RcsShowLocationAction < Struct.new(
  :text,
  :postback_data,
  :latitude,
  :longitude,
  :label)
  SENSITIVE = []
  include Aws::Structure
end

#text ⇒ String

The display text of the action. Maximum 25 characters.

Returns:

  • (String)


6712
6713
6714
6715
6716
6717
6718
6719
6720
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6712

class RcsShowLocationAction < Struct.new(
  :text,
  :postback_data,
  :latitude,
  :longitude,
  :label)
  SENSITIVE = []
  include Aws::Structure
end