Class: Aws::PinpointSMSVoiceV2::Types::RcsStandaloneCard

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

A standalone rich card with media, title, description, and suggested actions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#card_contentTypes::RcsCardContent

The content of the rich card, including title, description, media, and card-level suggested actions.



6469
6470
6471
6472
6473
6474
6475
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6469

class RcsStandaloneCard < Struct.new(
  :card_orientation,
  :thumbnail_image_alignment,
  :card_content)
  SENSITIVE = []
  include Aws::Structure
end

#card_orientationString

The orientation of the rich card. Valid values are HORIZONTAL and VERTICAL.

Returns:

  • (String)


6469
6470
6471
6472
6473
6474
6475
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6469

class RcsStandaloneCard < Struct.new(
  :card_orientation,
  :thumbnail_image_alignment,
  :card_content)
  SENSITIVE = []
  include Aws::Structure
end

#thumbnail_image_alignmentString

The alignment of the thumbnail image in a horizontal card. Valid values are LEFT and RIGHT. Only applicable when CardOrientation is HORIZONTAL.

Returns:

  • (String)


6469
6470
6471
6472
6473
6474
6475
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6469

class RcsStandaloneCard < Struct.new(
  :card_orientation,
  :thumbnail_image_alignment,
  :card_content)
  SENSITIVE = []
  include Aws::Structure
end