Class: Aws::PinpointSMSVoiceV2::Types::RegistrationAttachmentsInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RegistrationAttachmentsInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Provides information on the specified registration attachments.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_status ⇒ String
The status of the registration attachment.
-
#attachment_upload_error_reason ⇒ String
A description of why the upload didn't successfully complete.
-
#attachment_url ⇒ String
The URL to the document that's associated with the registration attachment.
-
#created_timestamp ⇒ Time
The time when the registration attachment was created, in [UNIX epoch time][1] format.
-
#registration_attachment_arn ⇒ String
The Amazon Resource Name (ARN) for the registration attachment.
-
#registration_attachment_id ⇒ String
The unique identifier for the registration attachment.
Instance Attribute Details
#attachment_status ⇒ String
The status of the registration attachment.
-
UPLOAD_IN_PROGRESSThe attachment is being uploaded. -
UPLOAD_COMPLETEThe attachment has been uploaded. -
UPLOAD_FAILEDThe attachment failed to uploaded. -
DELETEDThe attachment has been deleted..
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6668 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |
#attachment_upload_error_reason ⇒ String
A description of why the upload didn't successfully complete.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6668 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |
#attachment_url ⇒ String
The URL to the document that's associated with the registration attachment.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6668 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |
#created_timestamp ⇒ Time
The time when the registration attachment was created, in UNIX epoch time format.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6668 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |
#registration_attachment_arn ⇒ String
The Amazon Resource Name (ARN) for the registration attachment.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6668 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |
#registration_attachment_id ⇒ String
The unique identifier for the registration attachment.
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6668 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |