Class: Aws::PinpointSMSVoiceV2::Types::RegistrationFieldDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RegistrationFieldDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Provides a description of the specified field.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conditional_behavior ⇒ Types::ConditionalBehavior
The conditional behavior rules for this field.
-
#display_hints ⇒ Types::RegistrationFieldDisplayHints
An array of RegistrationFieldDisplayHints objects for the field.
-
#field_path ⇒ String
The path to the registration form field.
-
#field_requirement ⇒ String
Specifies if the field for the registration form is required, conditional or optional.
-
#field_type ⇒ String
The type of field.
-
#section_path ⇒ String
The section path of the field.
-
#select_validation ⇒ Types::SelectValidation
The validation rules for a select field.
-
#text_validation ⇒ Types::TextValidation
The validation rules for a text field.
Instance Attribute Details
#conditional_behavior ⇒ Types::ConditionalBehavior
The conditional behavior rules for this field. Only present when FieldRequirement is CONDITIONAL. Rules are evaluated in order and the first matching rule determines the field's resolved requirement. If no rule matches, the DefaultBehavior applies.
6887 6888 6889 6890 6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6887 class RegistrationFieldDefinition < Struct.new( :section_path, :field_path, :field_type, :field_requirement, :select_validation, :text_validation, :display_hints, :conditional_behavior) SENSITIVE = [] include Aws::Structure end |
#display_hints ⇒ Types::RegistrationFieldDisplayHints
An array of RegistrationFieldDisplayHints objects for the field.
6887 6888 6889 6890 6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6887 class RegistrationFieldDefinition < Struct.new( :section_path, :field_path, :field_type, :field_requirement, :select_validation, :text_validation, :display_hints, :conditional_behavior) SENSITIVE = [] include Aws::Structure end |
#field_path ⇒ String
The path to the registration form field. You can use DescribeRegistrationFieldDefinitions for a list of FieldPaths.
6887 6888 6889 6890 6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6887 class RegistrationFieldDefinition < Struct.new( :section_path, :field_path, :field_type, :field_requirement, :select_validation, :text_validation, :display_hints, :conditional_behavior) SENSITIVE = [] include Aws::Structure end |
#field_requirement ⇒ String
Specifies if the field for the registration form is required, conditional or optional.
6887 6888 6889 6890 6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6887 class RegistrationFieldDefinition < Struct.new( :section_path, :field_path, :field_type, :field_requirement, :select_validation, :text_validation, :display_hints, :conditional_behavior) SENSITIVE = [] include Aws::Structure end |
#field_type ⇒ String
The type of field.
6887 6888 6889 6890 6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6887 class RegistrationFieldDefinition < Struct.new( :section_path, :field_path, :field_type, :field_requirement, :select_validation, :text_validation, :display_hints, :conditional_behavior) SENSITIVE = [] include Aws::Structure end |
#section_path ⇒ String
The section path of the field.
6887 6888 6889 6890 6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6887 class RegistrationFieldDefinition < Struct.new( :section_path, :field_path, :field_type, :field_requirement, :select_validation, :text_validation, :display_hints, :conditional_behavior) SENSITIVE = [] include Aws::Structure end |
#select_validation ⇒ Types::SelectValidation
The validation rules for a select field.
6887 6888 6889 6890 6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6887 class RegistrationFieldDefinition < Struct.new( :section_path, :field_path, :field_type, :field_requirement, :select_validation, :text_validation, :display_hints, :conditional_behavior) SENSITIVE = [] include Aws::Structure end |
#text_validation ⇒ Types::TextValidation
The validation rules for a text field.
6887 6888 6889 6890 6891 6892 6893 6894 6895 6896 6897 6898 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6887 class RegistrationFieldDefinition < Struct.new( :section_path, :field_path, :field_type, :field_requirement, :select_validation, :text_validation, :display_hints, :conditional_behavior) SENSITIVE = [] include Aws::Structure end |