Class: Aws::PinpointSMSVoiceV2::Types::RegistrationFieldDisplayHints

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Provides help information on the registration field.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

The link to the document the display hint is associated with.

Returns:

  • (String)


7077
7078
7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7077

class RegistrationFieldDisplayHints < Struct.new(
  :title,
  :short_description,
  :long_description,
  :documentation_title,
  :documentation_link,
  :select_option_descriptions,
  :text_validation_description,
  :example_text_value)
  SENSITIVE = []
  include Aws::Structure
end

#documentation_title ⇒ String

The title of the document the display hint is associated with.

Returns:

  • (String)


7077
7078
7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7077

class RegistrationFieldDisplayHints < Struct.new(
  :title,
  :short_description,
  :long_description,
  :documentation_title,
  :documentation_link,
  :select_option_descriptions,
  :text_validation_description,
  :example_text_value)
  SENSITIVE = []
  include Aws::Structure
end

#example_text_value ⇒ String

Example text of what the value of a field should contain.

Returns:

  • (String)


7077
7078
7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7077

class RegistrationFieldDisplayHints < Struct.new(
  :title,
  :short_description,
  :long_description,
  :documentation_title,
  :documentation_link,
  :select_option_descriptions,
  :text_validation_description,
  :example_text_value)
  SENSITIVE = []
  include Aws::Structure
end

#long_description ⇒ String

A full description of the display hint.

Returns:

  • (String)


7077
7078
7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7077

class RegistrationFieldDisplayHints < Struct.new(
  :title,
  :short_description,
  :long_description,
  :documentation_title,
  :documentation_link,
  :select_option_descriptions,
  :text_validation_description,
  :example_text_value)
  SENSITIVE = []
  include Aws::Structure
end

#select_option_descriptions ⇒ Array<Types::SelectOptionDescription>

An array of SelectOptionDescription objects.

Returns:



7077
7078
7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7077

class RegistrationFieldDisplayHints < Struct.new(
  :title,
  :short_description,
  :long_description,
  :documentation_title,
  :documentation_link,
  :select_option_descriptions,
  :text_validation_description,
  :example_text_value)
  SENSITIVE = []
  include Aws::Structure
end

#short_description ⇒ String

A short description of the display hint.

Returns:

  • (String)


7077
7078
7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7077

class RegistrationFieldDisplayHints < Struct.new(
  :title,
  :short_description,
  :long_description,
  :documentation_title,
  :documentation_link,
  :select_option_descriptions,
  :text_validation_description,
  :example_text_value)
  SENSITIVE = []
  include Aws::Structure
end

#text_validation_description ⇒ String

The validation rules for the text field.

Returns:

  • (String)


7077
7078
7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7077

class RegistrationFieldDisplayHints < Struct.new(
  :title,
  :short_description,
  :long_description,
  :documentation_title,
  :documentation_link,
  :select_option_descriptions,
  :text_validation_description,
  :example_text_value)
  SENSITIVE = []
  include Aws::Structure
end

#title ⇒ String

The title of the display hint.

Returns:

  • (String)


7077
7078
7079
7080
7081
7082
7083
7084
7085
7086
7087
7088
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7077

class RegistrationFieldDisplayHints < Struct.new(
  :title,
  :short_description,
  :long_description,
  :documentation_title,
  :documentation_link,
  :select_option_descriptions,
  :text_validation_description,
  :example_text_value)
  SENSITIVE = []
  include Aws::Structure
end