Class: Aws::PinpointSMSVoiceV2::Types::RegistrationFieldValueInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Provides the values of the specified field.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#denied_reason ⇒ String

A description of why the registration was denied.

Returns:

  • (String)


7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7121

class RegistrationFieldValueInformation < Struct.new(
  :field_path,
  :select_choices,
  :text_value,
  :registration_attachment_id,
  :denied_reason,
  :feedback)
  SENSITIVE = []
  include Aws::Structure
end

#feedback ⇒ String

Generative AI feedback information provided for this specific field during the registration review process. This may include validation errors, suggestions for improvement, or additional requirements.

Returns:

  • (String)


7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7121

class RegistrationFieldValueInformation < Struct.new(
  :field_path,
  :select_choices,
  :text_value,
  :registration_attachment_id,
  :denied_reason,
  :feedback)
  SENSITIVE = []
  include Aws::Structure
end

#field_path ⇒ String

The path to the registration form field. You can use DescribeRegistrationFieldDefinitions for a list of FieldPaths.

Returns:

  • (String)


7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7121

class RegistrationFieldValueInformation < Struct.new(
  :field_path,
  :select_choices,
  :text_value,
  :registration_attachment_id,
  :denied_reason,
  :feedback)
  SENSITIVE = []
  include Aws::Structure
end

#registration_attachment_id ⇒ String

The unique identifier for the registration attachment.

Returns:

  • (String)


7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7121

class RegistrationFieldValueInformation < Struct.new(
  :field_path,
  :select_choices,
  :text_value,
  :registration_attachment_id,
  :denied_reason,
  :feedback)
  SENSITIVE = []
  include Aws::Structure
end

#select_choices ⇒ Array<String>

An array of values for the form field.

Returns:

  • (Array<String>)


7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7121

class RegistrationFieldValueInformation < Struct.new(
  :field_path,
  :select_choices,
  :text_value,
  :registration_attachment_id,
  :denied_reason,
  :feedback)
  SENSITIVE = []
  include Aws::Structure
end

#text_value ⇒ String

The text data for a free form field.

Returns:

  • (String)


7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7121

class RegistrationFieldValueInformation < Struct.new(
  :field_path,
  :select_choices,
  :text_value,
  :registration_attachment_id,
  :denied_reason,
  :feedback)
  SENSITIVE = []
  include Aws::Structure
end