Class: Aws::PinpointSMSVoiceV2::Types::RegistrationInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Provides information about the requested registration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_attributes ⇒ Hash<String,String>

Metadata about a given registration which is specific to that registration type.

Returns:

  • (Hash<String,String>)


7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7224

class RegistrationInformation < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_status,
  :current_version_number,
  :approved_version_number,
  :latest_denied_version_number,
  :additional_attributes,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#approved_version_number ⇒ Integer

The version number of the registration that was approved.

Returns:

  • (Integer)


7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7224

class RegistrationInformation < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_status,
  :current_version_number,
  :approved_version_number,
  :latest_denied_version_number,
  :additional_attributes,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#created_timestamp ⇒ Time

The time when the registration was created, in UNIX epoch time format.

Returns:

  • (Time)


7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7224

class RegistrationInformation < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_status,
  :current_version_number,
  :approved_version_number,
  :latest_denied_version_number,
  :additional_attributes,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#current_version_number ⇒ Integer

The current version number of the registration.

Returns:

  • (Integer)


7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7224

class RegistrationInformation < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_status,
  :current_version_number,
  :approved_version_number,
  :latest_denied_version_number,
  :additional_attributes,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#latest_denied_version_number ⇒ Integer

The latest version number of the registration that was denied.

Returns:

  • (Integer)


7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7224

class RegistrationInformation < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_status,
  :current_version_number,
  :approved_version_number,
  :latest_denied_version_number,
  :additional_attributes,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#registration_arn ⇒ String

The Amazon Resource Name (ARN) for the registration.

Returns:

  • (String)


7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7224

class RegistrationInformation < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_status,
  :current_version_number,
  :approved_version_number,
  :latest_denied_version_number,
  :additional_attributes,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#registration_id ⇒ String

The unique identifier for the registration.

Returns:

  • (String)


7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7224

class RegistrationInformation < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_status,
  :current_version_number,
  :approved_version_number,
  :latest_denied_version_number,
  :additional_attributes,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#registration_status ⇒ String

The status of the registration.

  • CLOSED: The phone number or sender ID has been deleted and you must also delete the registration for the number.

  • CREATED: Your registration is created but not submitted.

  • COMPLETE: Your registration has been approved and your origination identity has been created.

  • DELETED: The registration has been deleted.

  • PROVISIONING: Your registration has been approved and your origination identity is being created.

  • REQUIRES_AUTHENTICATION: You need to complete email authentication.

  • REQUIRES_UPDATES: You must fix your registration and resubmit it.

  • REVIEWING: Your registration has been accepted and is being reviewed.

  • SUBMITTED: Your registration has been submitted and is awaiting review.

Returns:

  • (String)


7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7224

class RegistrationInformation < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_status,
  :current_version_number,
  :approved_version_number,
  :latest_denied_version_number,
  :additional_attributes,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#registration_type ⇒ String

The type of registration form. The list of RegistrationTypes can be found using the DescribeRegistrationTypeDefinitions action.

Returns:

  • (String)


7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7224

class RegistrationInformation < Struct.new(
  :registration_arn,
  :registration_id,
  :registration_type,
  :registration_status,
  :current_version_number,
  :approved_version_number,
  :latest_denied_version_number,
  :additional_attributes,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end