Class: Aws::PinpointSMSVoiceV2::Types::ReleasePhoneNumberResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestamp ⇒ Time

The time when the phone number was created, in UNIX epoch time format.

Returns:

  • (Time)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#iso_country_code ⇒ String

The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#message_type ⇒ String

The message type that was associated with the phone number.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#monthly_leasing_price ⇒ String

The monthly price of the phone number, in US dollars.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#number_capabilities ⇒ Array<String>

Specifies if the number could be used for text messages, voice, or both.

Returns:

  • (Array<String>)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#number_type ⇒ String

The type of number that was released.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_name ⇒ String

The name of the OptOutList that was associated with the phone number.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number ⇒ String

The phone number that was released.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_arn ⇒ String

The PhoneNumberArn of the phone number that was released.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_id ⇒ String

The PhoneNumberId of the phone number that was released.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#registration_id ⇒ String

The unique identifier for the registration.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_opt_outs_enabled ⇒ Boolean

By default this is set to false. When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.

Returns:

  • (Boolean)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the request.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_arn ⇒ String

The Amazon Resource Name (ARN) of the TwoWayChannel.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_role ⇒ String

An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.

Returns:

  • (String)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_enabled ⇒ Boolean

By default this is set to false. When set to true you can receive incoming text messages from your end recipients.

Returns:

  • (Boolean)


7660
7661
7662
7663
7664
7665
7666
7667
7668
7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7660

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end