Class: Aws::PinpointSMSVoiceV2::Types::RequestPhoneNumberRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RequestPhoneNumberRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#deletion_protection_enabled ⇒ Boolean
By default this is set to false.
-
#international_sending_enabled ⇒ Boolean
By default this is set to false.
-
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
-
#message_type ⇒ String
The type of message.
-
#number_capabilities ⇒ Array<String>
Indicates if the phone number will be used for text messages, voice messages, or both.
-
#number_type ⇒ String
The type of phone number to request.
-
#opt_out_list_name ⇒ String
The name of the OptOutList to associate with the phone number.
-
#pool_id ⇒ String
The pool to associated with the phone number.
-
#registration_id ⇒ String
Use this field to attach your phone number for an external registration process.
-
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) to associate with the requested phone number.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don't specify a client token, a randomly generated token is used for the request to ensure idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7674 class RequestPhoneNumberRequest < Struct.new( :iso_country_code, :message_type, :number_capabilities, :number_type, :opt_out_list_name, :pool_id, :registration_id, :international_sending_enabled, :deletion_protection_enabled, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
By default this is set to false. When set to true the phone number can't be deleted.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7674 class RequestPhoneNumberRequest < Struct.new( :iso_country_code, :message_type, :number_capabilities, :number_type, :opt_out_list_name, :pool_id, :registration_id, :international_sending_enabled, :deletion_protection_enabled, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#international_sending_enabled ⇒ Boolean
By default this is set to false. When set to true the international sending of phone number is Enabled.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7674 class RequestPhoneNumberRequest < Struct.new( :iso_country_code, :message_type, :number_capabilities, :number_type, :opt_out_list_name, :pool_id, :registration_id, :international_sending_enabled, :deletion_protection_enabled, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7674 class RequestPhoneNumberRequest < Struct.new( :iso_country_code, :message_type, :number_capabilities, :number_type, :opt_out_list_name, :pool_id, :registration_id, :international_sending_enabled, :deletion_protection_enabled, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#message_type ⇒ String
The type of message. Valid values are TRANSACTIONAL for messages
that are critical or time-sensitive and PROMOTIONAL for messages
that aren't critical or time-sensitive.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7674 class RequestPhoneNumberRequest < Struct.new( :iso_country_code, :message_type, :number_capabilities, :number_type, :opt_out_list_name, :pool_id, :registration_id, :international_sending_enabled, :deletion_protection_enabled, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#number_capabilities ⇒ Array<String>
Indicates if the phone number will be used for text messages, voice messages, or both.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7674 class RequestPhoneNumberRequest < Struct.new( :iso_country_code, :message_type, :number_capabilities, :number_type, :opt_out_list_name, :pool_id, :registration_id, :international_sending_enabled, :deletion_protection_enabled, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#number_type ⇒ String
The type of phone number to request.
When you request a SIMULATOR phone number, you must set
MessageType as TRANSACTIONAL.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7674 class RequestPhoneNumberRequest < Struct.new( :iso_country_code, :message_type, :number_capabilities, :number_type, :opt_out_list_name, :pool_id, :registration_id, :international_sending_enabled, :deletion_protection_enabled, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The name of the OptOutList to associate with the phone number. You can use the OptOutListName or OptOutListArn.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7674 class RequestPhoneNumberRequest < Struct.new( :iso_country_code, :message_type, :number_capabilities, :number_type, :opt_out_list_name, :pool_id, :registration_id, :international_sending_enabled, :deletion_protection_enabled, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The pool to associated with the phone number. You can use the PoolId or PoolArn.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7674 class RequestPhoneNumberRequest < Struct.new( :iso_country_code, :message_type, :number_capabilities, :number_type, :opt_out_list_name, :pool_id, :registration_id, :international_sending_enabled, :deletion_protection_enabled, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#registration_id ⇒ String
Use this field to attach your phone number for an external registration process.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7674 class RequestPhoneNumberRequest < Struct.new( :iso_country_code, :message_type, :number_capabilities, :number_type, :opt_out_list_name, :pool_id, :registration_id, :international_sending_enabled, :deletion_protection_enabled, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) to associate with the requested phone number.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 7688 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7674 class RequestPhoneNumberRequest < Struct.new( :iso_country_code, :message_type, :number_capabilities, :number_type, :opt_out_list_name, :pool_id, :registration_id, :international_sending_enabled, :deletion_protection_enabled, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |