Class: Aws::PinpointSMSVoiceV2::Types::SendMediaMessageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::SendMediaMessageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_set_name ⇒ String
The name of the configuration set to use.
-
#context ⇒ Hash<String,String>
You can specify custom data in this field.
-
#destination_phone_number ⇒ String
The destination phone number in E.164 format.
-
#dry_run ⇒ Boolean
When set to true, the message is checked and validated, but isn't sent to the end recipient.
-
#max_price ⇒ String
The maximum amount that you want to spend, in US dollars, per each MMS message.
-
#media_urls ⇒ Array<String>
An array of URLs to each media file to send.
-
#message_body ⇒ String
The text body of the message.
-
#message_feedback_enabled ⇒ Boolean
Set to true to enable message feedback for the message.
-
#origination_identity ⇒ String
The origination identity of the message.
-
#protect_configuration_id ⇒ String
The unique identifier of the protect configuration to use.
-
#time_to_live ⇒ Integer
How long the media message is valid for.
Instance Attribute Details
#configuration_set_name ⇒ String
The name of the configuration set to use. This can be either the ConfigurationSetName or ConfigurationSetArn.
7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7993 class SendMediaMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :media_urls, :configuration_set_name, :max_price, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#context ⇒ Hash<String,String>
You can specify custom data in this field. If you do, that data is logged to the event destination.
7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7993 class SendMediaMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :media_urls, :configuration_set_name, :max_price, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#destination_phone_number ⇒ String
The destination phone number in E.164 format.
7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7993 class SendMediaMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :media_urls, :configuration_set_name, :max_price, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
When set to true, the message is checked and validated, but isn't sent to the end recipient.
7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7993 class SendMediaMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :media_urls, :configuration_set_name, :max_price, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#max_price ⇒ String
The maximum amount that you want to spend, in US dollars, per each MMS message.
7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7993 class SendMediaMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :media_urls, :configuration_set_name, :max_price, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#media_urls ⇒ Array<String>
An array of URLs to each media file to send.
The media files have to be stored in an S3 bucket. Supported media file formats are listed in MMS file types, size and character limits. For more information on creating an S3 bucket and managing objects, see Creating a bucket, Uploading objects in the Amazon S3 User Guide, and Setting up an Amazon S3 bucket for MMS files in the Amazon Web Services End User Messaging SMS User Guide.
7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7993 class SendMediaMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :media_urls, :configuration_set_name, :max_price, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#message_body ⇒ String
The text body of the message.
7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7993 class SendMediaMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :media_urls, :configuration_set_name, :max_price, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#message_feedback_enabled ⇒ Boolean
Set to true to enable message feedback for the message. When a user receives the message you need to update the message status using PutMessageFeedback.
7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7993 class SendMediaMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :media_urls, :configuration_set_name, :max_price, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#origination_identity ⇒ String
The origination identity of the message. This can be either the PhoneNumber, PhoneNumberId, PhoneNumberArn, SenderId, SenderIdArn, PoolId, or PoolArn.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7993 class SendMediaMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :media_urls, :configuration_set_name, :max_price, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#protect_configuration_id ⇒ String
The unique identifier of the protect configuration to use.
7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7993 class SendMediaMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :media_urls, :configuration_set_name, :max_price, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#time_to_live ⇒ Integer
How long the media message is valid for. By default this is 72 hours.
7993 7994 7995 7996 7997 7998 7999 8000 8001 8002 8003 8004 8005 8006 8007 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7993 class SendMediaMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :media_urls, :configuration_set_name, :max_price, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |