Class: Aws::PinpointSMSVoiceV2::Types::SendNotifyTextMessageResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message_idString

The unique identifier for the message.

Returns:

  • (String)


8099
8100
8101
8102
8103
8104
8105
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8099

class SendNotifyTextMessageResult < Struct.new(
  :message_id,
  :template_id,
  :resolved_message_body)
  SENSITIVE = []
  include Aws::Structure
end

#resolved_message_bodyString

The message body after template variable substitution has been applied.

Returns:

  • (String)


8099
8100
8101
8102
8103
8104
8105
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8099

class SendNotifyTextMessageResult < Struct.new(
  :message_id,
  :template_id,
  :resolved_message_body)
  SENSITIVE = []
  include Aws::Structure
end

#template_idString

The unique identifier of the template used for the message.

Returns:

  • (String)


8099
8100
8101
8102
8103
8104
8105
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8099

class SendNotifyTextMessageResult < Struct.new(
  :message_id,
  :template_id,
  :resolved_message_body)
  SENSITIVE = []
  include Aws::Structure
end