Class: Aws::PinpointSMSVoiceV2::Types::SendRcsMessageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_set_nameString

The name of the configuration set to use. This can be either the ConfigurationSetName or ConfigurationSetArn.

Returns:

  • (String)


8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#contextHash<String,String>

You can specify custom data in this field. If you do, that data is logged to the event destination.

Returns:

  • (Hash<String,String>)


8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#destination_phone_numberString

The destination phone number in E.164 format.

Returns:

  • (String)


8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

When set to true, the message is checked and validated, but isn't sent to the end recipient.

Returns:

  • (Boolean)


8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#fallback_configurationTypes::RcsFallbackConfiguration

Configuration for SMS or MMS fallback when RCS delivery fails. If provided, the service sends a fallback message via the specified channel when the RCS message fails or the TimeToLive expires.



8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#max_priceString

The maximum amount that you want to spend, in US dollars, per each RCS message.

Returns:

  • (String)


8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#message_feedback_enabledBoolean

Set to true to enable message feedback for the message. When a user receives the message you need to update the message status using PutMessageFeedback.

Returns:

  • (Boolean)


8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#message_traffic_typeString

The traffic type of the RCS message. Valid values are AUTHENTICATION, TRANSACTION, PROMOTION, SERVICE_REQUEST, and ACKNOWLEDGEMENT. This field is reserved for future use.

Returns:

  • (String)


8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#origination_identityString

The origination identity of the message. This can be either the RcsAgentId, RcsAgentArn, PoolId, or PoolArn.

Returns:

  • (String)


8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#protect_configuration_idString

The unique identifier of the protect configuration to use.

Returns:

  • (String)


8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#rcs_message_contentTypes::RcsMessageContent

The content of the RCS message. Contains the message content (text, file, rich card, or carousel) and optional message-level suggested actions.



8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#time_to_liveInteger

The duration in seconds that the RCS message is valid for delivery. If the message cannot be delivered within this duration, it is considered expired. Valid values are 1 to 172800 (48 hours). If a FallbackConfiguration is provided, the fallback is triggered when the duration expires without delivery confirmation.

Returns:

  • (Integer)


8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
8279
8280
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8265

class SendRcsMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :rcs_message_content,
  :time_to_live,
  :message_traffic_type,
  :fallback_configuration,
  :protect_configuration_id,
  :configuration_set_name,
  :max_price,
  :dry_run,
  :context,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end