Class: Aws::PinpointSMSVoiceV2::Types::SendTextMessageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_set_nameString

The name of the configuration set to use. This can be either the ConfigurationSetName or ConfigurationSetArn.

Returns:

  • (String)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#contextHash<String,String>

You can specify custom data in this field. If you do, that data is logged to the event destination.

Returns:

  • (Hash<String,String>)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#destination_country_parametersHash<String,String>

This field is used for any country-specific registration requirements. Currently, this setting is only used when you send messages to recipients in India using a sender ID. For more information see Special requirements for sending SMS messages to recipients in India.

  • IN_ENTITY_ID The entity ID or Principal Entity (PE) ID that you received after completing the sender ID registration process.

  • IN_TEMPLATE_ID The template ID that you received after completing the sender ID registration process.

    Make sure that the Template ID that you specify matches your message template exactly. If your message doesn't match the template that you provided during the registration process, the mobile carriers might reject your message.

Returns:

  • (Hash<String,String>)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#destination_phone_numberString

The destination phone number in E.164 format.

Returns:

  • (String)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

When set to true, the message is checked and validated, but isn't sent to the end recipient. You are not charged for using DryRun.

The Message Parts per Second (MPS) limit when using DryRun is five. If your origination identity has a lower MPS limit then the lower MPS limit is used. For more information about MPS limits, see Message Parts per Second (MPS) limits in the End User Messaging SMS User Guide..

Returns:

  • (Boolean)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#keywordString

When you register a short code in the US, you must specify a program name. If you don’t have a US short code, omit this attribute.

Returns:

  • (String)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#max_priceString

The maximum amount that you want to spend, in US dollars, per each text message. If the calculated amount to send the text message is greater than MaxPrice, the message is not sent and an error is returned.

Returns:

  • (String)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#message_bodyString

The body of the text message.

Returns:

  • (String)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#message_feedback_enabledBoolean

Set to true to enable message feedback for the message. When a user receives the message you need to update the message status using PutMessageFeedback.

Returns:

  • (Boolean)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#message_typeString

The type of message. Valid values are for messages that are critical or time-sensitive and PROMOTIONAL for messages that aren't critical or time-sensitive.

Returns:

  • (String)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#origination_identityString

The origination identity of the message. This can be either the PhoneNumber, PhoneNumberId, PhoneNumberArn, RcsAgentId, RcsAgentArn, SenderId, SenderIdArn, PoolId, or PoolArn.

If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).

Returns:

  • (String)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#protect_configuration_idString

The unique identifier for the protect configuration.

Returns:

  • (String)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#time_to_liveInteger

How long the text message is valid for, in seconds. By default this is 72 hours. If the messages isn't handed off before the TTL expires we stop attempting to hand off the message and return TTL_EXPIRED event.

Returns:

  • (Integer)


8396
8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8396

class SendTextMessageRequest < Struct.new(
  :destination_phone_number,
  :origination_identity,
  :message_body,
  :message_type,
  :keyword,
  :configuration_set_name,
  :max_price,
  :time_to_live,
  :context,
  :destination_country_parameters,
  :dry_run,
  :protect_configuration_id,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end