Class: Aws::PinpointSMSVoiceV2::Types::SendVoiceMessageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::SendVoiceMessageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_set_name ⇒ String
The name of the configuration set to use.
-
#context ⇒ Hash<String,String>
You can specify custom data in this field.
-
#destination_phone_number ⇒ String
The destination phone number in E.164 format.
-
#dry_run ⇒ Boolean
When set to true, the message is checked and validated, but isn't sent to the end recipient.
-
#max_price_per_minute ⇒ String
The maximum amount to spend per voice message, in US dollars.
-
#message_body ⇒ String
The text to convert to a voice message.
-
#message_body_text_type ⇒ String
Specifies if the MessageBody field contains text or [speech synthesis markup language (SSML)][1].
-
#message_feedback_enabled ⇒ Boolean
Set to true to enable message feedback for the message.
-
#origination_identity ⇒ String
The origination identity to use for the voice call.
-
#protect_configuration_id ⇒ String
The unique identifier for the protect configuration.
-
#time_to_live ⇒ Integer
How long the voice message is valid for.
-
#voice_id ⇒ String
The voice for the [Amazon Polly][1] service to use.
Instance Attribute Details
#configuration_set_name ⇒ String
The name of the configuration set to use. This can be either the ConfigurationSetName or ConfigurationSetArn.
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#context ⇒ Hash<String,String>
You can specify custom data in this field. If you do, that data is logged to the event destination.
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#destination_phone_number ⇒ String
The destination phone number in E.164 format.
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
When set to true, the message is checked and validated, but isn't sent to the end recipient.
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#max_price_per_minute ⇒ String
The maximum amount to spend per voice message, in US dollars.
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#message_body ⇒ String
The text to convert to a voice message.
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#message_body_text_type ⇒ String
Specifies if the MessageBody field contains text or speech synthesis markup language (SSML).
-
TEXT: This is the default value. When used the maximum character limit is 3000.
-
SSML: When used the maximum character limit is 6000 including SSML tagging.
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#message_feedback_enabled ⇒ Boolean
Set to true to enable message feedback for the message. When a user receives the message you need to update the message status using PutMessageFeedback.
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#origination_identity ⇒ String
The origination identity to use for the voice call. This can be the PhoneNumber, PhoneNumberId, PhoneNumberArn, PoolId, or PoolArn.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#protect_configuration_id ⇒ String
The unique identifier for the protect configuration.
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#time_to_live ⇒ Integer
How long the voice message is valid for. By default this is 72 hours.
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#voice_id ⇒ String
The voice for the Amazon Polly service to use. By default this is set to "MATTHEW".
8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8643 class SendVoiceMessageRequest < Struct.new( :destination_phone_number, :origination_identity, :message_body, :message_body_text_type, :voice_id, :configuration_set_name, :max_price_per_minute, :time_to_live, :context, :dry_run, :protect_configuration_id, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |