Class: Aws::PinpointSMSVoiceV2::Types::SenderIdInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::SenderIdInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
The information for all SenderIds in an Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deletion_protection_enabled ⇒ Boolean
By default this is set to false.
-
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
-
#message_types ⇒ Array<String>
The type of message.
-
#messaging_limits ⇒ Types::MessagingLimits
The messaging limits that apply to the sender ID, including the per-capability send rates.
-
#monthly_leasing_price ⇒ String
The monthly leasing price, in US dollars.
-
#registered ⇒ Boolean
True if the sender ID is registered.
-
#registration_id ⇒ String
The unique identifier for the registration.
-
#sender_id ⇒ String
The alphanumeric sender ID in a specific country that you'd like to describe.
-
#sender_id_arn ⇒ String
The Amazon Resource Name (ARN) associated with the SenderId.
Instance Attribute Details
#deletion_protection_enabled ⇒ Boolean
By default this is set to false. When set to true the sender ID can't be deleted.
8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8912 class SenderIdInformation < Struct.new( :sender_id_arn, :sender_id, :iso_country_code, :message_types, :monthly_leasing_price, :deletion_protection_enabled, :registered, :registration_id, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8912 class SenderIdInformation < Struct.new( :sender_id_arn, :sender_id, :iso_country_code, :message_types, :monthly_leasing_price, :deletion_protection_enabled, :registered, :registration_id, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#message_types ⇒ Array<String>
The type of message. Valid values are TRANSACTIONAL for messages that are critical or time-sensitive and PROMOTIONAL for messages that aren't critical or time-sensitive.
8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8912 class SenderIdInformation < Struct.new( :sender_id_arn, :sender_id, :iso_country_code, :message_types, :monthly_leasing_price, :deletion_protection_enabled, :registered, :registration_id, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#messaging_limits ⇒ Types::MessagingLimits
The messaging limits that apply to the sender ID, including the per-capability send rates.
8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8912 class SenderIdInformation < Struct.new( :sender_id_arn, :sender_id, :iso_country_code, :message_types, :monthly_leasing_price, :deletion_protection_enabled, :registered, :registration_id, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#monthly_leasing_price ⇒ String
The monthly leasing price, in US dollars.
8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8912 class SenderIdInformation < Struct.new( :sender_id_arn, :sender_id, :iso_country_code, :message_types, :monthly_leasing_price, :deletion_protection_enabled, :registered, :registration_id, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#registered ⇒ Boolean
True if the sender ID is registered.
8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8912 class SenderIdInformation < Struct.new( :sender_id_arn, :sender_id, :iso_country_code, :message_types, :monthly_leasing_price, :deletion_protection_enabled, :registered, :registration_id, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#registration_id ⇒ String
The unique identifier for the registration.
8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8912 class SenderIdInformation < Struct.new( :sender_id_arn, :sender_id, :iso_country_code, :message_types, :monthly_leasing_price, :deletion_protection_enabled, :registered, :registration_id, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#sender_id ⇒ String
The alphanumeric sender ID in a specific country that you'd like to describe.
8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8912 class SenderIdInformation < Struct.new( :sender_id_arn, :sender_id, :iso_country_code, :message_types, :monthly_leasing_price, :deletion_protection_enabled, :registered, :registration_id, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#sender_id_arn ⇒ String
The Amazon Resource Name (ARN) associated with the SenderId.
8912 8913 8914 8915 8916 8917 8918 8919 8920 8921 8922 8923 8924 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8912 class SenderIdInformation < Struct.new( :sender_id_arn, :sender_id, :iso_country_code, :message_types, :monthly_leasing_price, :deletion_protection_enabled, :registered, :registration_id, :messaging_limits) SENSITIVE = [] include Aws::Structure end |