Class: Aws::PinpointSMSVoiceV2::Types::SetDefaultMessageTypeResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_set_arn ⇒ String

The Amazon Resource Name (ARN) of the updated configuration set.

Returns:

  • (String)


9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9048

class SetDefaultMessageTypeResult < Struct.new(
  :configuration_set_arn,
  :configuration_set_name,
  :message_type)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_set_name ⇒ String

The name of the configuration set that was updated.

Returns:

  • (String)


9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9048

class SetDefaultMessageTypeResult < Struct.new(
  :configuration_set_arn,
  :configuration_set_name,
  :message_type)
  SENSITIVE = []
  include Aws::Structure
end

#message_type ⇒ String

The new default message type of the configuration set.

Returns:

  • (String)


9048
9049
9050
9051
9052
9053
9054
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9048

class SetDefaultMessageTypeResult < Struct.new(
  :configuration_set_arn,
  :configuration_set_name,
  :message_type)
  SENSITIVE = []
  include Aws::Structure
end