Class: Aws::PinpointSMSVoiceV2::Types::SetDefaultSenderIdRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_set_nameString

The configuration set to updated with a new default SenderId. This field can be the ConsigurationSetName or ConfigurationSetArn.

Returns:

  • (String)


8776
8777
8778
8779
8780
8781
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8776

class SetDefaultSenderIdRequest < Struct.new(
  :configuration_set_name,
  :sender_id)
  SENSITIVE = []
  include Aws::Structure
end

#sender_idString

The current sender ID for the configuration set. When sending a text message to a destination country which supports SenderIds, the default sender ID on the configuration set specified on SendTextMessage will be used if no dedicated origination phone numbers or registered SenderIds are available in your account, instead of a generic sender ID, such as 'NOTICE'.

Returns:

  • (String)


8776
8777
8778
8779
8780
8781
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8776

class SetDefaultSenderIdRequest < Struct.new(
  :configuration_set_name,
  :sender_id)
  SENSITIVE = []
  include Aws::Structure
end