Class: Aws::PinpointSMSVoiceV2::Types::TextValidation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Validation rules for a text field.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_length ⇒ Integer

The maximum number of characters for the text field.

Returns:

  • (Integer)


9558
9559
9560
9561
9562
9563
9564
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9558

class TextValidation < Struct.new(
  :min_length,
  :max_length,
  :pattern)
  SENSITIVE = []
  include Aws::Structure
end

#min_length ⇒ Integer

The minimum number of characters for the text field.

Returns:

  • (Integer)


9558
9559
9560
9561
9562
9563
9564
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9558

class TextValidation < Struct.new(
  :min_length,
  :max_length,
  :pattern)
  SENSITIVE = []
  include Aws::Structure
end

#pattern ⇒ String

The regular expression used to validate the text field.

Returns:

  • (String)


9558
9559
9560
9561
9562
9563
9564
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9558

class TextValidation < Struct.new(
  :min_length,
  :max_length,
  :pattern)
  SENSITIVE = []
  include Aws::Structure
end