Class: Aws::PinpointSMSVoiceV2::Types::UpdateNotifyConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::UpdateNotifyConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_template_id ⇒ String
The default template identifier to associate with the notify configuration.
-
#deletion_protection_enabled ⇒ Boolean
When set to true the notify configuration can't be deleted.
-
#enabled_channels ⇒ Array<String>
An array of channels to enable for the notify configuration.
-
#enabled_countries ⇒ Array<String>
An array of two-character ISO country codes, in ISO 3166-1 alpha-2 format, that are enabled for the notify configuration.
-
#notify_configuration_id ⇒ String
The identifier of the notify configuration to update.
-
#pool_id ⇒ String
The pool identifier or Amazon Resource Name (ARN) to associate with the notify configuration.
Instance Attribute Details
#default_template_id ⇒ String
The default template identifier to associate with the notify
configuration. If specified, this template is used when sending
messages without an explicit template identifier. Pass the special
value UNSET_DEFAULT_TEMPLATE to clear the current default template
from the notify configuration.
9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9417 class UpdateNotifyConfigurationRequest < Struct.new( :notify_configuration_id, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
When set to true the notify configuration can't be deleted.
9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9417 class UpdateNotifyConfigurationRequest < Struct.new( :notify_configuration_id, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#enabled_channels ⇒ Array<String>
An array of channels to enable for the notify configuration.
Supported values include SMS and VOICE.
9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9417 class UpdateNotifyConfigurationRequest < Struct.new( :notify_configuration_id, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#enabled_countries ⇒ Array<String>
An array of two-character ISO country codes, in ISO 3166-1 alpha-2 format, that are enabled for the notify configuration.
9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9417 class UpdateNotifyConfigurationRequest < Struct.new( :notify_configuration_id, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#notify_configuration_id ⇒ String
The identifier of the notify configuration to update. The NotifyConfigurationId can be found using the DescribeNotifyConfigurations operation.
9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9417 class UpdateNotifyConfigurationRequest < Struct.new( :notify_configuration_id, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The pool identifier or Amazon Resource Name (ARN) to associate with
the notify configuration. Pass the special value
UNSET_DEFAULT_POOL_FOR_NOTIFY to clear the current default pool
from the notify configuration.
9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9417 class UpdateNotifyConfigurationRequest < Struct.new( :notify_configuration_id, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |