Class: Aws::PinpointSMSVoiceV2::Types::UpdatePhoneNumberRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deletion_protection_enabled ⇒ Boolean

By default this is set to false. When set to true the phone number can't be deleted.

Returns:

  • (Boolean)


9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
9869
9870
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9859

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#international_sending_enabled ⇒ Boolean

By default this is set to false. When set to true the international sending of phone number is Enabled.

Returns:

  • (Boolean)


9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
9869
9870
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9859

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_name ⇒ String

The OptOutList to add the phone number to. You can use either the opt out list name or the opt out list ARN.

Returns:

  • (String)


9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
9869
9870
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9859

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_id ⇒ String

The unique identifier of the phone number. Valid values for this field can be either the PhoneNumberId or PhoneNumberArn.

If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).

Returns:

  • (String)


9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
9869
9870
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9859

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_opt_outs_enabled ⇒ Boolean

By default this is set to false. When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.

Returns:

  • (Boolean)


9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
9869
9870
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9859

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_arn ⇒ String

The Amazon Resource Name (ARN) of the two way channel.

Returns:

  • (String)


9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
9869
9870
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9859

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_role ⇒ String

An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.

Returns:

  • (String)


9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
9869
9870
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9859

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_enabled ⇒ Boolean

By default this is set to false. When set to true you can receive incoming text messages from your end recipients.

Returns:

  • (Boolean)


9859
9860
9861
9862
9863
9864
9865
9866
9867
9868
9869
9870
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9859

class UpdatePhoneNumberRequest < Struct.new(
  :phone_number_id,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled)
  SENSITIVE = []
  include Aws::Structure
end