Class: Aws::PinpointSMSVoiceV2::Types::UpdatePhoneNumberResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::UpdatePhoneNumberResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_timestamp ⇒ Time
The time when the phone number was created, in [UNIX epoch time][1] format.
-
#deletion_protection_enabled ⇒ Boolean
When set to true the phone number can't be deleted.
-
#international_sending_enabled ⇒ Boolean
When set to true the international sending of phone number is Enabled.
-
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
-
#message_type ⇒ String
The type of message.
-
#monthly_leasing_price ⇒ String
The monthly leasing price of the phone number, in US dollars.
-
#number_capabilities ⇒ Array<String>
Specifies if the number could be used for text messages, voice or both.
-
#number_type ⇒ String
The type of number that was requested.
-
#opt_out_list_name ⇒ String
The name of the OptOutList associated with the phone number.
-
#phone_number ⇒ String
The phone number that was updated.
-
#phone_number_arn ⇒ String
The Amazon Resource Name (ARN) of the updated phone number.
-
#phone_number_id ⇒ String
The unique identifier of the phone number.
-
#registration_id ⇒ String
The unique identifier for the registration.
-
#self_managed_opt_outs_enabled ⇒ Boolean
This is true if self managed opt-out are enabled.
-
#status ⇒ String
The current status of the request.
-
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
-
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
-
#two_way_enabled ⇒ Boolean
By default this is set to false.
Instance Attribute Details
#created_timestamp ⇒ Time
The time when the phone number was created, in UNIX epoch time format.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
When set to true the phone number can't be deleted.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#international_sending_enabled ⇒ Boolean
When set to true the international sending of phone number is Enabled.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#message_type ⇒ String
The type of message. Valid values are TRANSACTIONAL for messages that are critical or time-sensitive and PROMOTIONAL for messages that aren't critical or time-sensitive.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#monthly_leasing_price ⇒ String
The monthly leasing price of the phone number, in US dollars.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#number_capabilities ⇒ Array<String>
Specifies if the number could be used for text messages, voice or both.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#number_type ⇒ String
The type of number that was requested.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The name of the OptOutList associated with the phone number.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#phone_number ⇒ String
The phone number that was updated.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#phone_number_arn ⇒ String
The Amazon Resource Name (ARN) of the updated phone number.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#phone_number_id ⇒ String
The unique identifier of the phone number.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#registration_id ⇒ String
The unique identifier for the registration.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#self_managed_opt_outs_enabled ⇒ Boolean
This is true if self managed opt-out are enabled.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the request.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_enabled ⇒ Boolean
By default this is set to false. When set to true you can receive incoming text messages from your end recipients.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9662 class UpdatePhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :registration_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |