Class: Aws::PinpointSMSVoiceV2::Types::UpdatePoolResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestamp ⇒ Time

The time when the pool was created, in UNIX epoch time format.

Returns:

  • (Time)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection_enabled ⇒ Boolean

When set to true the pool can't be deleted.

Returns:

  • (Boolean)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#message_type ⇒ String

The type of message for the pool to use.

Returns:

  • (String)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_name ⇒ String

The name of the OptOutList associated with the pool.

Returns:

  • (String)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#pool_arn ⇒ String

The ARN of the pool.

Returns:

  • (String)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#pool_id ⇒ String

The unique identifier of the pool.

Returns:

  • (String)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_opt_outs_enabled ⇒ Boolean

When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.

Returns:

  • (Boolean)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#shared_routes_enabled ⇒ Boolean

Indicates whether shared routes are enabled for the pool.

Returns:

  • (Boolean)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the pool update request.

Returns:

  • (String)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_arn ⇒ String

The Amazon Resource Name (ARN) of the two way channel.

Returns:

  • (String)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_role ⇒ String

An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.

Returns:

  • (String)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_enabled ⇒ Boolean

By default this is set to false. When set to true you can receive incoming text messages from your end recipients.

Returns:

  • (Boolean)


10105
10106
10107
10108
10109
10110
10111
10112
10113
10114
10115
10116
10117
10118
10119
10120
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10105

class UpdatePoolResult < Struct.new(
  :pool_arn,
  :pool_id,
  :status,
  :message_type,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :shared_routes_enabled,
  :deletion_protection_enabled,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end