Class: Aws::PinpointSMSVoiceV2::Types::UpdateProtectConfigurationCountryRuleSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#country_rule_set_updatesHash<String,Types::ProtectConfigurationCountryRuleSetInformation>

A map of ProtectConfigurationCountryRuleSetInformation objects that contain the details for the requested NumberCapability. The Key is the two-letter ISO country code. For a list of supported ISO country codes, see Supported countries and regions (SMS channel) in the End User Messaging SMS User Guide.

For example, to set the United States as allowed and Canada as blocked, the CountryRuleSetUpdates would be formatted as: "CountryRuleSetUpdates": { "US" : { "ProtectStatus": "ALLOW" } "CA" \: { "ProtectStatus": "BLOCK" } }



9994
9995
9996
9997
9998
9999
10000
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9994

class UpdateProtectConfigurationCountryRuleSetRequest < Struct.new(
  :protect_configuration_id,
  :number_capability,
  :country_rule_set_updates)
  SENSITIVE = []
  include Aws::Structure
end

#number_capabilityString

The number capability to apply the CountryRuleSetUpdates updates to.

Returns:

  • (String)


9994
9995
9996
9997
9998
9999
10000
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9994

class UpdateProtectConfigurationCountryRuleSetRequest < Struct.new(
  :protect_configuration_id,
  :number_capability,
  :country_rule_set_updates)
  SENSITIVE = []
  include Aws::Structure
end

#protect_configuration_idString

The unique identifier for the protect configuration.

Returns:

  • (String)


9994
9995
9996
9997
9998
9999
10000
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9994

class UpdateProtectConfigurationCountryRuleSetRequest < Struct.new(
  :protect_configuration_id,
  :number_capability,
  :country_rule_set_updates)
  SENSITIVE = []
  include Aws::Structure
end