Class: Aws::PinpointSMSVoiceV2::Types::VerifiedDestinationNumberInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Provides information about the requested verified destintion phone number.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestamp ⇒ Time

The time when the destination phone number was created, in UNIX epoch time format.

Returns:

  • (Time)


10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10591

class VerifiedDestinationNumberInformation < Struct.new(
  :verified_destination_number_arn,
  :verified_destination_number_id,
  :destination_phone_number,
  :status,
  :rcs_agent_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#destination_phone_number ⇒ String

The verified destination phone number, in E.164 format.

Returns:

  • (String)


10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10591

class VerifiedDestinationNumberInformation < Struct.new(
  :verified_destination_number_arn,
  :verified_destination_number_id,
  :destination_phone_number,
  :status,
  :rcs_agent_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#rcs_agent_id ⇒ String

The unique identifier of the RCS agent associated with the verified destination number.

Returns:

  • (String)


10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10591

class VerifiedDestinationNumberInformation < Struct.new(
  :verified_destination_number_arn,
  :verified_destination_number_id,
  :destination_phone_number,
  :status,
  :rcs_agent_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the verified destination phone number.

  • PENDING: The phone number hasn't been verified yet.

  • VERIFIED: The phone number is verified and can receive messages.

Returns:

  • (String)


10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10591

class VerifiedDestinationNumberInformation < Struct.new(
  :verified_destination_number_arn,
  :verified_destination_number_id,
  :destination_phone_number,
  :status,
  :rcs_agent_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#verified_destination_number_arn ⇒ String

The Amazon Resource Name (ARN) for the verified destination phone number.

Returns:

  • (String)


10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10591

class VerifiedDestinationNumberInformation < Struct.new(
  :verified_destination_number_arn,
  :verified_destination_number_id,
  :destination_phone_number,
  :status,
  :rcs_agent_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#verified_destination_number_id ⇒ String

The unique identifier for the verified destination phone number.

Returns:

  • (String)


10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10591

class VerifiedDestinationNumberInformation < Struct.new(
  :verified_destination_number_arn,
  :verified_destination_number_id,
  :destination_phone_number,
  :status,
  :rcs_agent_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end