Class: Aws::PinpointSMSVoiceV2::Types::VerifyDestinationNumberResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestamp ⇒ Time

The time when the destination phone number was created, in UNIX epoch time format.

Returns:

  • (Time)


10648
10649
10650
10651
10652
10653
10654
10655
10656
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10648

class VerifyDestinationNumberResult < Struct.new(
  :verified_destination_number_arn,
  :verified_destination_number_id,
  :destination_phone_number,
  :status,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#destination_phone_number ⇒ String

The phone number in E.164 format.

Returns:

  • (String)


10648
10649
10650
10651
10652
10653
10654
10655
10656
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10648

class VerifyDestinationNumberResult < Struct.new(
  :verified_destination_number_arn,
  :verified_destination_number_id,
  :destination_phone_number,
  :status,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status for being able to send messages to the phone number.

Returns:

  • (String)


10648
10649
10650
10651
10652
10653
10654
10655
10656
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10648

class VerifyDestinationNumberResult < Struct.new(
  :verified_destination_number_arn,
  :verified_destination_number_id,
  :destination_phone_number,
  :status,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#verified_destination_number_arn ⇒ String

The Amazon Resource Name (ARN) for the verified destination phone number.

Returns:

  • (String)


10648
10649
10650
10651
10652
10653
10654
10655
10656
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10648

class VerifyDestinationNumberResult < Struct.new(
  :verified_destination_number_arn,
  :verified_destination_number_id,
  :destination_phone_number,
  :status,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#verified_destination_number_id ⇒ String

The unique identifier for the verified destination phone number.

Returns:

  • (String)


10648
10649
10650
10651
10652
10653
10654
10655
10656
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10648

class VerifyDestinationNumberResult < Struct.new(
  :verified_destination_number_arn,
  :verified_destination_number_id,
  :destination_phone_number,
  :status,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end