Class: Aws::PinpointSMSVoiceV2::Types::ConditionalValidation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::ConditionalValidation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Per-rule validation constraints that override the field's default validation when the containing rule matches. All fields are optional; only the constraints that need to differ from the field's default validation are provided.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_values ⇒ Array<String>
The allowed values for a select field when this rule applies.
-
#max_length ⇒ Integer
The maximum length for the field value when this rule applies.
-
#min_length ⇒ Integer
The minimum length for the field value when this rule applies.
-
#pattern ⇒ String
A regular expression that the field value must match when this rule applies.
Instance Attribute Details
#allowed_values ⇒ Array<String>
The allowed values for a select field when this rule applies. A subset of the field's full option list.
414 415 416 417 418 419 420 421 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 414 class ConditionalValidation < Struct.new( :min_length, :max_length, :pattern, :allowed_values) SENSITIVE = [] include Aws::Structure end |
#max_length ⇒ Integer
The maximum length for the field value when this rule applies.
414 415 416 417 418 419 420 421 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 414 class ConditionalValidation < Struct.new( :min_length, :max_length, :pattern, :allowed_values) SENSITIVE = [] include Aws::Structure end |
#min_length ⇒ Integer
The minimum length for the field value when this rule applies.
414 415 416 417 418 419 420 421 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 414 class ConditionalValidation < Struct.new( :min_length, :max_length, :pattern, :allowed_values) SENSITIVE = [] include Aws::Structure end |
#pattern ⇒ String
A regular expression that the field value must match when this rule applies.
414 415 416 417 418 419 420 421 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 414 class ConditionalValidation < Struct.new( :min_length, :max_length, :pattern, :allowed_values) SENSITIVE = [] include Aws::Structure end |