Class: Aws::PinpointSMSVoiceV2::Types::CreateRcsAgentResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::CreateRcsAgentResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_timestamp ⇒ Time
The time when the RCS agent was created, in [UNIX epoch time][1] format.
-
#deletion_protection_enabled ⇒ Boolean
When set to true deletion protection is enabled.
-
#opt_out_list_name ⇒ String
The name of the OptOutList associated with the RCS agent.
-
#rcs_agent_arn ⇒ String
The Amazon Resource Name (ARN) of the newly created RCS agent.
-
#rcs_agent_id ⇒ String
The unique identifier for the RCS agent.
-
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false.
-
#status ⇒ String
The current status of the RCS agent.
-
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) associated with the RCS agent.
-
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
-
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
-
#two_way_enabled ⇒ Boolean
By default this is set to false.
-
#two_way_media_s3_bucket_name ⇒ String
The name of the S3 bucket where inbound RCS media files are stored.
-
#two_way_media_s3_key_prefix ⇒ String
The key prefix used for inbound RCS media objects in the S3 bucket.
-
#two_way_media_s3_role ⇒ String
The ARN of the IAM role used to write inbound RCS media files to the S3 bucket.
-
#two_way_rcs_events_enabled ⇒ Array<String>
The list of RCS event types enabled for two-way messaging on the agent.
Instance Attribute Details
#created_timestamp ⇒ Time
The time when the RCS agent was created, in UNIX epoch time format.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
When set to true deletion protection is enabled. By default this is set to false.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The name of the OptOutList associated with the RCS agent.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#rcs_agent_arn ⇒ String
The Amazon Resource Name (ARN) of the newly created RCS agent.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#rcs_agent_id ⇒ String
The unique identifier for the RCS agent.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the RCS agent.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) associated with the RCS agent.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#two_way_enabled ⇒ Boolean
By default this is set to false. When set to true you can receive incoming text messages from your end recipients.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#two_way_media_s3_bucket_name ⇒ String
The name of the S3 bucket where inbound RCS media files are stored.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#two_way_media_s3_key_prefix ⇒ String
The key prefix used for inbound RCS media objects in the S3 bucket.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#two_way_media_s3_role ⇒ String
The ARN of the IAM role used to write inbound RCS media files to the
S3 bucket. The role must have s3:PutObject permission on the
bucket and a trust policy allowing sms-voice.amazonaws.com to
assume it.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |
#two_way_rcs_events_enabled ⇒ Array<String>
The list of RCS event types enabled for two-way messaging on the agent.
1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1206 class CreateRcsAgentResult < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :deletion_protection_enabled, :opt_out_list_name, :created_timestamp, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :tags) SENSITIVE = [] include Aws::Structure end |