Class: Aws::PinpointSMSVoiceV2::Types::CreateVerifiedDestinationNumberRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::CreateVerifiedDestinationNumberRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#destination_phone_number ⇒ String
The verified destination phone number, in E.164 format.
-
#rcs_agent_id ⇒ String
The unique identifier of the RCS agent to associate with the verified destination number.
-
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) to associate with the destination number.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don't specify a client token, a randomly generated token is used for the request to ensure idempotency.
A suitable default value is auto-generated. You should normally not need to pass this option.
1585 1586 1587 1588 1589 1590 1591 1592 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1585 class CreateVerifiedDestinationNumberRequest < Struct.new( :destination_phone_number, :rcs_agent_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#destination_phone_number ⇒ String
The verified destination phone number, in E.164 format.
1585 1586 1587 1588 1589 1590 1591 1592 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1585 class CreateVerifiedDestinationNumberRequest < Struct.new( :destination_phone_number, :rcs_agent_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#rcs_agent_id ⇒ String
The unique identifier of the RCS agent to associate with the verified destination number. You can use either the RcsAgentId or RcsAgentArn.
1585 1586 1587 1588 1589 1590 1591 1592 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1585 class CreateVerifiedDestinationNumberRequest < Struct.new( :destination_phone_number, :rcs_agent_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of tags (key and value pairs) to associate with the destination number.
1585 1586 1587 1588 1589 1590 1591 1592 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1585 class CreateVerifiedDestinationNumberRequest < Struct.new( :destination_phone_number, :rcs_agent_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |