Class: Aws::PinpointSMSVoiceV2::Types::DeleteConfigurationSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DeleteConfigurationSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_set_name ⇒ String
The name of the configuration set or the configuration set ARN that you want to delete.
Instance Attribute Details
#configuration_set_name ⇒ String
The name of the configuration set or the configuration set ARN that you want to delete. The ConfigurationSetName and ConfigurationSetArn can be found using the DescribeConfigurationSets action.
1680 1681 1682 1683 1684 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1680 class DeleteConfigurationSetRequest < Struct.new( :configuration_set_name) SENSITIVE = [] include Aws::Structure end |