Class: Aws::PinpointSMSVoiceV2::Types::DeleteEventDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DeleteEventDestinationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_set_name ⇒ String
The name of the configuration set or the configuration set's Amazon Resource Name (ARN) to remove the event destination from.
-
#event_destination_name ⇒ String
The name of the event destination to delete.
Instance Attribute Details
#configuration_set_name ⇒ String
The name of the configuration set or the configuration set's Amazon Resource Name (ARN) to remove the event destination from. The ConfigurateSetName and ConfigurationSetArn can be found using the DescribeConfigurationSets action.
1822 1823 1824 1825 1826 1827 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1822 class DeleteEventDestinationRequest < Struct.new( :configuration_set_name, :event_destination_name) SENSITIVE = [] include Aws::Structure end |
#event_destination_name ⇒ String
The name of the event destination to delete.
1822 1823 1824 1825 1826 1827 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 1822 class DeleteEventDestinationRequest < Struct.new( :configuration_set_name, :event_destination_name) SENSITIVE = [] include Aws::Structure end |