Class: Aws::PinpointSMSVoiceV2::Types::DescribeKeywordsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::KeywordFilter>

An array of keyword filters to filter the results.

Returns:



2344
2345
2346
2347
2348
2349
2350
2351
2352
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2344

class DescribeKeywordsRequest < Struct.new(
  :origination_identity,
  :keywords,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#keywordsArray<String>

An array of keywords to search for.

Returns:

  • (Array<String>)


2344
2345
2346
2347
2348
2349
2350
2351
2352
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2344

class DescribeKeywordsRequest < Struct.new(
  :origination_identity,
  :keywords,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per each request.

Returns:

  • (Integer)


2344
2345
2346
2347
2348
2349
2350
2351
2352
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2344

class DescribeKeywordsRequest < Struct.new(
  :origination_identity,
  :keywords,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results. You don’t need to supply a value for this field in the initial request.

Returns:

  • (String)


2344
2345
2346
2347
2348
2349
2350
2351
2352
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2344

class DescribeKeywordsRequest < Struct.new(
  :origination_identity,
  :keywords,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#origination_identityString

The origination identity to use such as a PhoneNumberId, PhoneNumberArn, SenderId or SenderIdArn. You can use DescribePhoneNumbers to find the values for PhoneNumberId and PhoneNumberArn while DescribeSenderIds can be used to get the values for SenderId and SenderIdArn.

If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).

Returns:

  • (String)


2344
2345
2346
2347
2348
2349
2350
2351
2352
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2344

class DescribeKeywordsRequest < Struct.new(
  :origination_identity,
  :keywords,
  :filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end