Class: Aws::PinpointSMSVoiceV2::Types::DescribeKeywordsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DescribeKeywordsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::KeywordFilter>
An array of keyword filters to filter the results.
-
#keywords ⇒ Array<String>
An array of keywords to search for.
-
#max_results ⇒ Integer
The maximum number of results to return per each request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#origination_identity ⇒ String
The origination identity to use such as a PhoneNumberId, PhoneNumberArn, SenderId or SenderIdArn.
Instance Attribute Details
#filters ⇒ Array<Types::KeywordFilter>
An array of keyword filters to filter the results.
2344 2345 2346 2347 2348 2349 2350 2351 2352 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2344 class DescribeKeywordsRequest < Struct.new( :origination_identity, :keywords, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#keywords ⇒ Array<String>
An array of keywords to search for.
2344 2345 2346 2347 2348 2349 2350 2351 2352 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2344 class DescribeKeywordsRequest < Struct.new( :origination_identity, :keywords, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per each request.
2344 2345 2346 2347 2348 2349 2350 2351 2352 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2344 class DescribeKeywordsRequest < Struct.new( :origination_identity, :keywords, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results. You don’t need to supply a value for this field in the initial request.
2344 2345 2346 2347 2348 2349 2350 2351 2352 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2344 class DescribeKeywordsRequest < Struct.new( :origination_identity, :keywords, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#origination_identity ⇒ String
The origination identity to use such as a PhoneNumberId, PhoneNumberArn, SenderId or SenderIdArn. You can use DescribePhoneNumbers to find the values for PhoneNumberId and PhoneNumberArn while DescribeSenderIds can be used to get the values for SenderId and SenderIdArn.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
2344 2345 2346 2347 2348 2349 2350 2351 2352 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2344 class DescribeKeywordsRequest < Struct.new( :origination_identity, :keywords, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |