Class: Aws::PinpointSMSVoiceV2::Types::DescribeKeywordsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DescribeKeywordsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#keywords ⇒ Array<Types::KeywordInformation>
An array of KeywordInformation objects that contain the results.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#origination_identity ⇒ String
The PhoneNumberId or PoolId that is associated with the OriginationIdentity.
-
#origination_identity_arn ⇒ String
The PhoneNumberArn or PoolArn that is associated with the OriginationIdentity.
Instance Attribute Details
#keywords ⇒ Array<Types::KeywordInformation>
An array of KeywordInformation objects that contain the results.
2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2375 class DescribeKeywordsResult < Struct.new( :origination_identity_arn, :origination_identity, :keywords, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results. If this field is empty then there are no more results.
2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2375 class DescribeKeywordsResult < Struct.new( :origination_identity_arn, :origination_identity, :keywords, :next_token) SENSITIVE = [] include Aws::Structure end |
#origination_identity ⇒ String
The PhoneNumberId or PoolId that is associated with the OriginationIdentity.
2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2375 class DescribeKeywordsResult < Struct.new( :origination_identity_arn, :origination_identity, :keywords, :next_token) SENSITIVE = [] include Aws::Structure end |
#origination_identity_arn ⇒ String
The PhoneNumberArn or PoolArn that is associated with the OriginationIdentity.
2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2375 class DescribeKeywordsResult < Struct.new( :origination_identity_arn, :origination_identity, :keywords, :next_token) SENSITIVE = [] include Aws::Structure end |