Class: Aws::PinpointSMSVoiceV2::Types::DescribeNotifyConfigurationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DescribeNotifyConfigurationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#notify_configurations ⇒ Array<Types::NotifyConfigurationInformation>
An array of NotifyConfigurationInformation objects that contain the results.
Instance Attribute Details
#next_token ⇒ String
The token to be used for the next set of paginated results. If this field is empty then there are no more results.
2986 2987 2988 2989 2990 2991 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2986 class DescribeNotifyConfigurationsResult < Struct.new( :notify_configurations, :next_token) SENSITIVE = [] include Aws::Structure end |
#notify_configurations ⇒ Array<Types::NotifyConfigurationInformation>
An array of NotifyConfigurationInformation objects that contain the results.
2986 2987 2988 2989 2990 2991 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 2986 class DescribeNotifyConfigurationsResult < Struct.new( :notify_configurations, :next_token) SENSITIVE = [] include Aws::Structure end |