Class: Aws::PinpointSMSVoiceV2::Types::DescribeOptedOutNumbersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DescribeOptedOutNumbersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::OptedOutFilter>
An array of OptedOutFilter objects to filter the results on.
-
#max_results ⇒ Integer
The maximum number of results to return per each request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#opt_out_list_name ⇒ String
The OptOutListName or OptOutListArn of the OptOutList.
-
#opted_out_numbers ⇒ Array<String>
An array of phone numbers to search for in the OptOutList.
Instance Attribute Details
#filters ⇒ Array<Types::OptedOutFilter>
An array of OptedOutFilter objects to filter the results on.
3173 3174 3175 3176 3177 3178 3179 3180 3181 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3173 class DescribeOptedOutNumbersRequest < Struct.new( :opt_out_list_name, :opted_out_numbers, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per each request.
3173 3174 3175 3176 3177 3178 3179 3180 3181 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3173 class DescribeOptedOutNumbersRequest < Struct.new( :opt_out_list_name, :opted_out_numbers, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.
3173 3174 3175 3176 3177 3178 3179 3180 3181 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3173 class DescribeOptedOutNumbersRequest < Struct.new( :opt_out_list_name, :opted_out_numbers, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The OptOutListName or OptOutListArn of the OptOutList. You can use DescribeOptOutLists to find the values for OptOutListName and OptOutListArn.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
3173 3174 3175 3176 3177 3178 3179 3180 3181 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3173 class DescribeOptedOutNumbersRequest < Struct.new( :opt_out_list_name, :opted_out_numbers, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#opted_out_numbers ⇒ Array<String>
An array of phone numbers to search for in the OptOutList.
If you specify an opted out number that isn't valid, an exception is returned.
3173 3174 3175 3176 3177 3178 3179 3180 3181 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3173 class DescribeOptedOutNumbersRequest < Struct.new( :opt_out_list_name, :opted_out_numbers, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |