Class: Aws::PinpointSMSVoiceV2::Types::DescribeRcsAgentCountryLaunchStatusResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::DescribeRcsAgentCountryLaunchStatusResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#country_launch_status ⇒ Array<Types::CountryLaunchStatusInformation>
An array of CountryLaunchStatusInformation objects that contain the per-country launch status details.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#rcs_agent_arn ⇒ String
The Amazon Resource Name (ARN) of the RCS agent.
-
#rcs_agent_id ⇒ String
The unique identifier for the RCS agent.
Instance Attribute Details
#country_launch_status ⇒ Array<Types::CountryLaunchStatusInformation>
An array of CountryLaunchStatusInformation objects that contain the per-country launch status details.
3433 3434 3435 3436 3437 3438 3439 3440 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3433 class DescribeRcsAgentCountryLaunchStatusResult < Struct.new( :rcs_agent_id, :rcs_agent_arn, :country_launch_status, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results. If this field is empty then there are no more results.
3433 3434 3435 3436 3437 3438 3439 3440 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3433 class DescribeRcsAgentCountryLaunchStatusResult < Struct.new( :rcs_agent_id, :rcs_agent_arn, :country_launch_status, :next_token) SENSITIVE = [] include Aws::Structure end |
#rcs_agent_arn ⇒ String
The Amazon Resource Name (ARN) of the RCS agent.
3433 3434 3435 3436 3437 3438 3439 3440 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3433 class DescribeRcsAgentCountryLaunchStatusResult < Struct.new( :rcs_agent_id, :rcs_agent_arn, :country_launch_status, :next_token) SENSITIVE = [] include Aws::Structure end |
#rcs_agent_id ⇒ String
The unique identifier for the RCS agent.
3433 3434 3435 3436 3437 3438 3439 3440 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3433 class DescribeRcsAgentCountryLaunchStatusResult < Struct.new( :rcs_agent_id, :rcs_agent_arn, :country_launch_status, :next_token) SENSITIVE = [] include Aws::Structure end |