Class: Aws::PinpointSMSVoiceV2::Types::DescribeSenderIdsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::SenderIdFilter>

An array of SenderIdFilter objects to filter the results.

Returns:



3915
3916
3917
3918
3919
3920
3921
3922
3923
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3915

class DescribeSenderIdsRequest < Struct.new(
  :sender_ids,
  :filters,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return per each request.

Returns:

  • (Integer)


3915
3916
3917
3918
3919
3920
3921
3922
3923
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3915

class DescribeSenderIdsRequest < Struct.new(
  :sender_ids,
  :filters,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.

Returns:

  • (String)


3915
3916
3917
3918
3919
3920
3921
3922
3923
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3915

class DescribeSenderIdsRequest < Struct.new(
  :sender_ids,
  :filters,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

Use SELF to filter the list of Sender Ids to ones your account owns or use SHARED to filter on Sender Ids shared with your account. The Owner and SenderIds parameters can't be used at the same time.

Returns:

  • (String)


3915
3916
3917
3918
3919
3920
3921
3922
3923
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3915

class DescribeSenderIdsRequest < Struct.new(
  :sender_ids,
  :filters,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end

#sender_idsArray<Types::SenderIdAndCountry>

An array of SenderIdAndCountry objects to search for.

If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).

Returns:



3915
3916
3917
3918
3919
3920
3921
3922
3923
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 3915

class DescribeSenderIdsRequest < Struct.new(
  :sender_ids,
  :filters,
  :next_token,
  :max_results,
  :owner)
  SENSITIVE = []
  include Aws::Structure
end