Class: Aws::PinpointSMSVoiceV2::Types::ListNotifyCountriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::ListNotifyCountriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channels ⇒ Array<String>
An array of channels to filter the results by.
-
#max_results ⇒ Integer
The maximum number of results to return per each request.
-
#next_token ⇒ String
The token to be used for the next set of paginated results.
-
#tier ⇒ String
The tier to filter the results by.
-
#use_cases ⇒ Array<String>
An array of use cases to filter the results by.
Instance Attribute Details
#channels ⇒ Array<String>
An array of channels to filter the results by.
4691 4692 4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4691 class ListNotifyCountriesRequest < Struct.new( :channels, :use_cases, :tier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per each request.
4691 4692 4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4691 class ListNotifyCountriesRequest < Struct.new( :channels, :use_cases, :tier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.
4691 4692 4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4691 class ListNotifyCountriesRequest < Struct.new( :channels, :use_cases, :tier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
The tier to filter the results by.
4691 4692 4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4691 class ListNotifyCountriesRequest < Struct.new( :channels, :use_cases, :tier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#use_cases ⇒ Array<String>
An array of use cases to filter the results by.
4691 4692 4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4691 class ListNotifyCountriesRequest < Struct.new( :channels, :use_cases, :tier, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |