Class: Aws::PinpointSMSVoiceV2::Types::NotifyConfigurationInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::NotifyConfigurationInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
The information for a notify configuration in an Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_timestamp ⇒ Time
The time when the notify configuration was created, in [UNIX epoch time][1] format.
-
#default_template_id ⇒ String
The default template identifier associated with the notify configuration.
-
#deletion_protection_enabled ⇒ Boolean
When set to true deletion protection is enabled.
-
#display_name ⇒ String
The display name associated with the notify configuration.
-
#enabled_channels ⇒ Array<String>
An array of channels enabled for the notify configuration.
-
#enabled_countries ⇒ Array<String>
An array of two-character ISO country codes, in ISO 3166-1 alpha-2 format, that are enabled for the notify configuration.
-
#notify_configuration_arn ⇒ String
The Amazon Resource Name (ARN) for the notify configuration.
-
#notify_configuration_id ⇒ String
The unique identifier for the notify configuration.
-
#pool_id ⇒ String
The identifier of the pool associated with the notify configuration.
-
#rejection_reason ⇒ String
The reason the notify configuration was rejected, if applicable.
-
#status ⇒ String
The current status of the notify configuration.
-
#tier ⇒ String
The tier of the notify configuration.
-
#tier_upgrade_status ⇒ String
The tier upgrade status of the notify configuration.
-
#use_case ⇒ String
The use case for the notify configuration.
Instance Attribute Details
#created_timestamp ⇒ Time
The time when the notify configuration was created, in UNIX epoch time format.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#default_template_id ⇒ String
The default template identifier associated with the notify configuration.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
When set to true deletion protection is enabled. By default this is set to false.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The display name associated with the notify configuration.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#enabled_channels ⇒ Array<String>
An array of channels enabled for the notify configuration. Supported
values include SMS and VOICE.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#enabled_countries ⇒ Array<String>
An array of two-character ISO country codes, in ISO 3166-1 alpha-2 format, that are enabled for the notify configuration.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#notify_configuration_arn ⇒ String
The Amazon Resource Name (ARN) for the notify configuration.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#notify_configuration_id ⇒ String
The unique identifier for the notify configuration.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The identifier of the pool associated with the notify configuration.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#rejection_reason ⇒ String
The reason the notify configuration was rejected, if applicable.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the notify configuration.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#tier ⇒ String
The tier of the notify configuration.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#tier_upgrade_status ⇒ String
The tier upgrade status of the notify configuration.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#use_case ⇒ String
The use case for the notify configuration.
4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4949 class NotifyConfigurationInformation < Struct.new( :notify_configuration_arn, :notify_configuration_id, :display_name, :use_case, :default_template_id, :pool_id, :enabled_countries, :enabled_channels, :tier, :tier_upgrade_status, :status, :rejection_reason, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |