Class: Aws::PinpointSMSVoiceV2::Types::NotifyCountryInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::NotifyCountryInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
The information for a country that supports notify messaging.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#country_name ⇒ String
The name of the country.
-
#customer_owned_identity_required ⇒ Boolean
Whether a customer-owned identity is required to send notify messages to this country.
-
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
-
#supported_channels ⇒ Array<String>
An array of supported channels for the country.
-
#supported_tiers ⇒ Array<String>
An array of supported tiers for the country.
-
#supported_use_cases ⇒ Array<String>
An array of supported use cases for the country.
Instance Attribute Details
#country_name ⇒ String
The name of the country.
4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4866 class NotifyCountryInformation < Struct.new( :iso_country_code, :country_name, :supported_channels, :supported_use_cases, :supported_tiers, :customer_owned_identity_required) SENSITIVE = [] include Aws::Structure end |
#customer_owned_identity_required ⇒ Boolean
Whether a customer-owned identity is required to send notify messages to this country.
4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4866 class NotifyCountryInformation < Struct.new( :iso_country_code, :country_name, :supported_channels, :supported_use_cases, :supported_tiers, :customer_owned_identity_required) SENSITIVE = [] include Aws::Structure end |
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4866 class NotifyCountryInformation < Struct.new( :iso_country_code, :country_name, :supported_channels, :supported_use_cases, :supported_tiers, :customer_owned_identity_required) SENSITIVE = [] include Aws::Structure end |
#supported_channels ⇒ Array<String>
An array of supported channels for the country. Supported values
include SMS and VOICE.
4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4866 class NotifyCountryInformation < Struct.new( :iso_country_code, :country_name, :supported_channels, :supported_use_cases, :supported_tiers, :customer_owned_identity_required) SENSITIVE = [] include Aws::Structure end |
#supported_tiers ⇒ Array<String>
An array of supported tiers for the country.
4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4866 class NotifyCountryInformation < Struct.new( :iso_country_code, :country_name, :supported_channels, :supported_use_cases, :supported_tiers, :customer_owned_identity_required) SENSITIVE = [] include Aws::Structure end |
#supported_use_cases ⇒ Array<String>
An array of supported use cases for the country.
4866 4867 4868 4869 4870 4871 4872 4873 4874 4875 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4866 class NotifyCountryInformation < Struct.new( :iso_country_code, :country_name, :supported_channels, :supported_use_cases, :supported_tiers, :customer_owned_identity_required) SENSITIVE = [] include Aws::Structure end |