Class: Aws::PinpointSMSVoiceV2::Types::NotifyCountryInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

The information for a country that supports notify messaging.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#country_nameString

The name of the country.

Returns:

  • (String)


4818
4819
4820
4821
4822
4823
4824
4825
4826
4827
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4818

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end

#customer_owned_identity_requiredBoolean

Whether a customer-owned identity is required to send notify messages to this country.

Returns:

  • (Boolean)


4818
4819
4820
4821
4822
4823
4824
4825
4826
4827
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4818

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end

#iso_country_codeString

The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.

Returns:

  • (String)


4818
4819
4820
4821
4822
4823
4824
4825
4826
4827
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4818

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end

#supported_channelsArray<String>

An array of supported channels for the country. Supported values include ‘SMS` and `VOICE`.

Returns:

  • (Array<String>)


4818
4819
4820
4821
4822
4823
4824
4825
4826
4827
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4818

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end

#supported_tiersArray<String>

An array of supported tiers for the country.

Returns:

  • (Array<String>)


4818
4819
4820
4821
4822
4823
4824
4825
4826
4827
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4818

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end

#supported_use_casesArray<String>

An array of supported use cases for the country.

Returns:

  • (Array<String>)


4818
4819
4820
4821
4822
4823
4824
4825
4826
4827
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4818

class NotifyCountryInformation < Struct.new(
  :iso_country_code,
  :country_name,
  :supported_channels,
  :supported_use_cases,
  :supported_tiers,
  :customer_owned_identity_required)
  SENSITIVE = []
  include Aws::Structure
end