Class: Aws::PinpointSMSVoiceV2::Types::NotifyTemplateInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

The information for a system-managed notify template in an Amazon Web Services account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channelsArray<String>

The channels for the template. Supported values are SMS and VOICE.

Returns:

  • (Array<String>)


4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#contentString

The content of the template.

Returns:

  • (String)


4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#created_timestampTime

The time when the notify template was created, in UNIX epoch time format.

Returns:

  • (Time)


4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#language_codeString

The language code for the template.

Returns:

  • (String)


4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the template.

Returns:

  • (String)


4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#supported_countriesArray<String>

An array of supported country codes for the template.

Returns:

  • (Array<String>)


4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#supported_voice_idsArray<String>

An array of supported voice IDs for voice templates.

Returns:

  • (Array<String>)


4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#template_idString

The unique identifier for the template.

Returns:

  • (String)


4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#template_typeString

The type of the template.

Returns:

  • (String)


4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#tier_accessArray<String>

The tier access level for the template.

Returns:

  • (Array<String>)


4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#variablesHash<String,Types::TemplateVariableMetadata>

An array of template variable metadata for the template.

Returns:



4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The version of the template.

Returns:

  • (Integer)


4955
4956
4957
4958
4959
4960
4961
4962
4963
4964
4965
4966
4967
4968
4969
4970
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 4955

class NotifyTemplateInformation < Struct.new(
  :template_id,
  :version,
  :template_type,
  :channels,
  :tier_access,
  :status,
  :supported_countries,
  :language_code,
  :content,
  :variables,
  :supported_voice_ids,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end