Class: Aws::PinpointSMSVoiceV2::Types::NotifyTemplateInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::NotifyTemplateInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
The information for a system-managed notify template in an Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channels ⇒ Array<String>
The channels for the template.
-
#content ⇒ String
The content of the template.
-
#created_timestamp ⇒ Time
The time when the notify template was created, in [UNIX epoch time][1] format.
-
#language_code ⇒ String
The language code for the template.
-
#status ⇒ String
The current status of the template.
-
#supported_countries ⇒ Array<String>
An array of supported country codes for the template.
-
#supported_voice_ids ⇒ Array<String>
An array of supported voice IDs for voice templates.
-
#template_id ⇒ String
The unique identifier for the template.
-
#template_type ⇒ String
The type of the template.
-
#tier_access ⇒ Array<String>
The tier access level for the template.
-
#variables ⇒ Hash<String,Types::TemplateVariableMetadata>
An array of template variable metadata for the template.
-
#version ⇒ Integer
The version of the template.
Instance Attribute Details
#channels ⇒ Array<String>
The channels for the template. Supported values are SMS and
VOICE.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#content ⇒ String
The content of the template.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#created_timestamp ⇒ Time
The time when the notify template was created, in UNIX epoch time format.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The language code for the template.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the template.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#supported_countries ⇒ Array<String>
An array of supported country codes for the template.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#supported_voice_ids ⇒ Array<String>
An array of supported voice IDs for voice templates.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#template_id ⇒ String
The unique identifier for the template.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#template_type ⇒ String
The type of the template.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#tier_access ⇒ Array<String>
The tier access level for the template.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#variables ⇒ Hash<String,Types::TemplateVariableMetadata>
An array of template variable metadata for the template.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version of the template.
5186 5187 5188 5189 5190 5191 5192 5193 5194 5195 5196 5197 5198 5199 5200 5201 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5186 class NotifyTemplateInformation < Struct.new( :template_id, :version, :template_type, :channels, :tier_access, :status, :supported_countries, :language_code, :content, :variables, :supported_voice_ids, :created_timestamp) SENSITIVE = [] include Aws::Structure end |