Class: Aws::PinpointSMSVoiceV2::Types::PhoneNumberInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

The information for a phone number, in E.164 format, in an Amazon Web Services account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestampTime

The time when the phone number was created, in [UNIX epoch time] format.

[1]: www.epochconverter.com/

Returns:

  • (Time)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection_enabledBoolean

When set to true the phone number can’t be deleted.

Returns:

  • (Boolean)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#international_sending_enabledBoolean

When set to true the international sending of phone number is Enabled.

Returns:

  • (Boolean)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#iso_country_codeString

The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#message_typeString

The type of message. Valid values are TRANSACTIONAL for messages that are critical or time-sensitive and PROMOTIONAL for messages that aren’t critical or time-sensitive.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#monthly_leasing_priceString

The price, in US dollars, to lease the phone number.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#number_capabilitiesArray<String>

Describes if the origination identity can be used for text messages, voice calls or both.

Returns:

  • (Array<String>)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#number_typeString

The type of phone number.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_nameString

The name of the OptOutList associated with the phone number.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_numberString

The phone number in E.164 format.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_arnString

The Amazon Resource Name (ARN) associated with the phone number.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_idString

The unique identifier for the phone number.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idString

The unique identifier of the pool associated with the phone number.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#registration_idString

The unique identifier for the registration.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_opt_outs_enabledBoolean

When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you’re responsible for responding to HELP and STOP requests. You’re also responsible for tracking and honoring opt-out request. For more information see [Self-managed opt-outs]

[1]: docs.aws.amazon.com/pinpoint/latest/userguide/settings-sms-managing.html#settings-account-sms-self-managed-opt-out

Returns:

  • (Boolean)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the phone number.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_arnString

The Amazon Resource Name (ARN) of the two way channel.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_roleString

An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.

Returns:

  • (String)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_enabledBoolean

By default this is set to false. When set to true you can receive incoming text messages from your end recipients using the TwoWayChannelArn.

Returns:

  • (Boolean)


5163
5164
5165
5166
5167
5168
5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
5181
5182
5183
5184
5185
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5163

class PhoneNumberInformation < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end