Class: Aws::PinpointSMSVoiceV2::Types::ProtectConfigurationInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::ProtectConfigurationInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Provides information on the specified protect configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_default ⇒ Boolean
This is true if the protect configuration is set as your account default protect configuration.
-
#created_timestamp ⇒ Time
The time when the protect configuration was created, in [UNIX epoch time][1] format.
-
#deletion_protection_enabled ⇒ Boolean
The status of deletion protection for the protect configuration.
-
#protect_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the protect configuration.
-
#protect_configuration_id ⇒ String
The unique identifier for the protect configuration.
Instance Attribute Details
#account_default ⇒ Boolean
This is true if the protect configuration is set as your account default protect configuration.
5433 5434 5435 5436 5437 5438 5439 5440 5441 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5433 class ProtectConfigurationInformation < Struct.new( :protect_configuration_arn, :protect_configuration_id, :created_timestamp, :account_default, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#created_timestamp ⇒ Time
The time when the protect configuration was created, in UNIX epoch time format.
5433 5434 5435 5436 5437 5438 5439 5440 5441 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5433 class ProtectConfigurationInformation < Struct.new( :protect_configuration_arn, :protect_configuration_id, :created_timestamp, :account_default, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
The status of deletion protection for the protect configuration. When set to true deletion protection is enabled. By default this is set to false.
5433 5434 5435 5436 5437 5438 5439 5440 5441 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5433 class ProtectConfigurationInformation < Struct.new( :protect_configuration_arn, :protect_configuration_id, :created_timestamp, :account_default, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#protect_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the protect configuration.
5433 5434 5435 5436 5437 5438 5439 5440 5441 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5433 class ProtectConfigurationInformation < Struct.new( :protect_configuration_arn, :protect_configuration_id, :created_timestamp, :account_default, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#protect_configuration_id ⇒ String
The unique identifier for the protect configuration.
5433 5434 5435 5436 5437 5438 5439 5440 5441 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5433 class ProtectConfigurationInformation < Struct.new( :protect_configuration_arn, :protect_configuration_id, :created_timestamp, :account_default, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |