Class: Aws::PinpointSMSVoiceV2::Types::RcsAgentInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

The information for an RCS agent in an Amazon Web Services account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestampTime

The time when the RCS agent was created, in UNIX epoch time format.

Returns:

  • (Time)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection_enabledBoolean

When set to true the RCS agent can't be deleted.

Returns:

  • (Boolean)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_nameString

The name of the OptOutList associated with the RCS agent.

Returns:

  • (String)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idString

The unique identifier of the pool associated with the RCS agent.

Returns:

  • (String)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#rcs_agent_arnString

The Amazon Resource Name (ARN) of the RCS agent.

Returns:

  • (String)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#rcs_agent_idString

The unique identifier for the RCS agent.

Returns:

  • (String)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_opt_outs_enabledBoolean

When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.

Returns:

  • (Boolean)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the RCS agent.

Returns:

  • (String)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#testing_agentTypes::TestingAgentInformation

The testing agent information associated with the RCS agent.



5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_arnString

The Amazon Resource Name (ARN) of the two way channel.

Returns:

  • (String)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_roleString

An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.

Returns:

  • (String)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_enabledBoolean

When set to true you can receive incoming text messages from your end recipients using the TwoWayChannelArn.

Returns:

  • (Boolean)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_media_s3_bucket_nameString

The name of the S3 bucket where inbound RCS media files are stored.

Returns:

  • (String)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_media_s3_key_prefixString

The key prefix used for inbound RCS media objects in the S3 bucket.

Returns:

  • (String)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_media_s3_roleString

The ARN of the IAM role used to write inbound RCS media files to the S3 bucket.

Returns:

  • (String)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_rcs_events_enabledArray<String>

The list of RCS event types enabled for two-way messaging on the agent.

Returns:

  • (Array<String>)


5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
5986
5987
5988
5989
5990
5991
5992
5993
5994
5995
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5976

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end