Class: Aws::PinpointSMSVoiceV2::Types::RcsAgentInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

The information for an RCS agent in an Amazon Web Services account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestampTime

The time when the RCS agent was created, in [UNIX epoch time] format.

[1]: www.epochconverter.com/

Returns:

  • (Time)


5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection_enabledBoolean

When set to true the RCS agent can’t be deleted.

Returns:

  • (Boolean)


5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_nameString

The name of the OptOutList associated with the RCS agent.

Returns:

  • (String)


5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idString

The unique identifier of the pool associated with the RCS agent.

Returns:

  • (String)


5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#rcs_agent_arnString

The Amazon Resource Name (ARN) of the RCS agent.

Returns:

  • (String)


5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#rcs_agent_idString

The unique identifier for the RCS agent.

Returns:

  • (String)


5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_opt_outs_enabledBoolean

When set to true you’re responsible for responding to HELP and STOP requests. You’re also responsible for tracking and honoring opt-out requests.

Returns:

  • (Boolean)


5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the RCS agent.

Returns:

  • (String)


5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#testing_agentTypes::TestingAgentInformation

The testing agent information associated with the RCS agent.



5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_arnString

The Amazon Resource Name (ARN) of the two way channel.

Returns:

  • (String)


5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_roleString

An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.

Returns:

  • (String)


5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_enabledBoolean

When set to true you can receive incoming text messages from your end recipients using the TwoWayChannelArn.

Returns:

  • (Boolean)


5910
5911
5912
5913
5914
5915
5916
5917
5918
5919
5920
5921
5922
5923
5924
5925
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 5910

class RcsAgentInformation < Struct.new(
  :rcs_agent_arn,
  :rcs_agent_id,
  :status,
  :created_timestamp,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :pool_id,
  :testing_agent)
  SENSITIVE = []
  include Aws::Structure
end