Class: Aws::PinpointSMSVoiceV2::Types::RcsAgentInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RcsAgentInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
The information for an RCS agent in an Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_timestamp ⇒ Time
The time when the RCS agent was created, in [UNIX epoch time][1] format.
-
#deletion_protection_enabled ⇒ Boolean
When set to true the RCS agent can't be deleted.
-
#messaging_limits ⇒ Types::MessagingLimits
The messaging limits that apply to the RCS agent, including the per-capability send rates.
-
#opt_out_list_name ⇒ String
The name of the OptOutList associated with the RCS agent.
-
#pool_id ⇒ String
The unique identifier of the pool associated with the RCS agent.
-
#rcs_agent_arn ⇒ String
The Amazon Resource Name (ARN) of the RCS agent.
-
#rcs_agent_id ⇒ String
The unique identifier for the RCS agent.
-
#self_managed_opt_outs_enabled ⇒ Boolean
When set to true you're responsible for responding to HELP and STOP requests.
-
#status ⇒ String
The current status of the RCS agent.
-
#testing_agent ⇒ Types::TestingAgentInformation
The testing agent information associated with the RCS agent.
-
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
-
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
-
#two_way_enabled ⇒ Boolean
When set to true you can receive incoming text messages from your end recipients using the TwoWayChannelArn.
-
#two_way_media_s3_bucket_name ⇒ String
The name of the S3 bucket where inbound RCS media files are stored.
-
#two_way_media_s3_key_prefix ⇒ String
The key prefix used for inbound RCS media objects in the S3 bucket.
-
#two_way_media_s3_role ⇒ String
The ARN of the IAM role used to write inbound RCS media files to the S3 bucket.
-
#two_way_rcs_events_enabled ⇒ Array<String>
The list of RCS event types enabled for two-way messaging on the agent.
Instance Attribute Details
#created_timestamp ⇒ Time
The time when the RCS agent was created, in UNIX epoch time format.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
When set to true the RCS agent can't be deleted.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#messaging_limits ⇒ Types::MessagingLimits
The messaging limits that apply to the RCS agent, including the per-capability send rates.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The name of the OptOutList associated with the RCS agent.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The unique identifier of the pool associated with the RCS agent.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#rcs_agent_arn ⇒ String
The Amazon Resource Name (ARN) of the RCS agent.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#rcs_agent_id ⇒ String
The unique identifier for the RCS agent.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#self_managed_opt_outs_enabled ⇒ Boolean
When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the RCS agent.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#testing_agent ⇒ Types::TestingAgentInformation
The testing agent information associated with the RCS agent.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#two_way_enabled ⇒ Boolean
When set to true you can receive incoming text messages from your end recipients using the TwoWayChannelArn.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#two_way_media_s3_bucket_name ⇒ String
The name of the S3 bucket where inbound RCS media files are stored.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#two_way_media_s3_key_prefix ⇒ String
The key prefix used for inbound RCS media objects in the S3 bucket.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#two_way_media_s3_role ⇒ String
The ARN of the IAM role used to write inbound RCS media files to the S3 bucket.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |
#two_way_rcs_events_enabled ⇒ Array<String>
The list of RCS event types enabled for two-way messaging on the agent.
6249 6250 6251 6252 6253 6254 6255 6256 6257 6258 6259 6260 6261 6262 6263 6264 6265 6266 6267 6268 6269 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6249 class RcsAgentInformation < Struct.new( :rcs_agent_arn, :rcs_agent_id, :status, :created_timestamp, :deletion_protection_enabled, :opt_out_list_name, :self_managed_opt_outs_enabled, :two_way_channel_arn, :two_way_channel_role, :two_way_enabled, :pool_id, :two_way_media_s3_bucket_name, :two_way_media_s3_key_prefix, :two_way_media_s3_role, :two_way_rcs_events_enabled, :testing_agent, :messaging_limits) SENSITIVE = [] include Aws::Structure end |