Class: Aws::PinpointSMSVoiceV2::Types::RcsDialPhoneAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RcsDialPhoneAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
A suggested action that initiates a phone call to a specified number when tapped by the recipient.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#phone_number ⇒ String
The phone number to dial in E.164 format.
-
#postback_data ⇒ String
The postback data sent to your webhook when the user taps this action.
-
#text ⇒ String
The display text of the action.
Instance Attribute Details
#phone_number ⇒ String
The phone number to dial in E.164 format.
6240 6241 6242 6243 6244 6245 6246 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6240 class RcsDialPhoneAction < Struct.new( :text, :postback_data, :phone_number) SENSITIVE = [] include Aws::Structure end |
#postback_data ⇒ String
The postback data sent to your webhook when the user taps this action. Maximum 2048 characters.
6240 6241 6242 6243 6244 6245 6246 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6240 class RcsDialPhoneAction < Struct.new( :text, :postback_data, :phone_number) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
The display text of the action. Maximum 25 characters.
6240 6241 6242 6243 6244 6245 6246 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6240 class RcsDialPhoneAction < Struct.new( :text, :postback_data, :phone_number) SENSITIVE = [] include Aws::Structure end |