Class: Aws::PinpointSMSVoiceV2::Types::RcsFallbackConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RcsFallbackConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Configuration for SMS or MMS fallback when RCS delivery fails or the TimeToLive expires without delivery confirmation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel ⇒ String
The fallback channel to use when RCS delivery fails.
-
#media_urls ⇒ Array<String>
An array of S3 URIs to media files for MMS fallback.
-
#message_body ⇒ String
The text body of the fallback message.
-
#origination_identity ⇒ String
The origination identity to use for the fallback message.
Instance Attribute Details
#channel ⇒ String
The fallback channel to use when RCS delivery fails. Valid values are SMS and MMS. SMS and MMS are mutually exclusive.
6277 6278 6279 6280 6281 6282 6283 6284 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6277 class RcsFallbackConfiguration < Struct.new( :channel, :message_body, :media_urls, :origination_identity) SENSITIVE = [] include Aws::Structure end |
#media_urls ⇒ Array<String>
An array of S3 URIs to media files for MMS fallback. Only valid when Channel is MMS.
6277 6278 6279 6280 6281 6282 6283 6284 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6277 class RcsFallbackConfiguration < Struct.new( :channel, :message_body, :media_urls, :origination_identity) SENSITIVE = [] include Aws::Structure end |
#message_body ⇒ String
The text body of the fallback message. Required for SMS fallback. For MMS fallback, at least one of MessageBody or MediaUrls must be provided.
6277 6278 6279 6280 6281 6282 6283 6284 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6277 class RcsFallbackConfiguration < Struct.new( :channel, :message_body, :media_urls, :origination_identity) SENSITIVE = [] include Aws::Structure end |
#origination_identity ⇒ String
The origination identity to use for the fallback message. This can be a PhoneNumber, PhoneNumberId, PhoneNumberArn, SenderId, or SenderIdArn. Pool IDs and pool ARNs are not accepted. If not specified and the original message was sent via a pool, the service selects a suitable number from the pool.
6277 6278 6279 6280 6281 6282 6283 6284 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6277 class RcsFallbackConfiguration < Struct.new( :channel, :message_body, :media_urls, :origination_identity) SENSITIVE = [] include Aws::Structure end |