Class: Aws::PinpointSMSVoiceV2::Types::RcsReplyAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

A suggested reply action that sends predefined text and postback data when tapped by the recipient.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#postback_dataString

The postback data sent to your webhook when the user taps this reply. Maximum 2048 characters.

Returns:

  • (String)


6385
6386
6387
6388
6389
6390
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6385

class RcsReplyAction < Struct.new(
  :text,
  :postback_data)
  SENSITIVE = []
  include Aws::Structure
end

#textString

The display text of the suggested reply. Maximum 25 characters.

Returns:

  • (String)


6385
6386
6387
6388
6389
6390
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6385

class RcsReplyAction < Struct.new(
  :text,
  :postback_data)
  SENSITIVE = []
  include Aws::Structure
end