Class: Aws::PinpointSMSVoiceV2::Types::RcsShowLocationAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RcsShowLocationAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
A suggested action that shows a location on a map when tapped by the recipient.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#label ⇒ String
An optional label for the location pin.
-
#latitude ⇒ Float
The latitude of the location.
-
#longitude ⇒ Float
The longitude of the location.
-
#postback_data ⇒ String
The postback data sent to your webhook when the user taps this action.
-
#text ⇒ String
The display text of the action.
Instance Attribute Details
#label ⇒ String
An optional label for the location pin. Maximum 100 characters.
6571 6572 6573 6574 6575 6576 6577 6578 6579 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6571 class RcsShowLocationAction < Struct.new( :text, :postback_data, :latitude, :longitude, :label) SENSITIVE = [] include Aws::Structure end |
#latitude ⇒ Float
The latitude of the location. Valid values are -90 to 90.
6571 6572 6573 6574 6575 6576 6577 6578 6579 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6571 class RcsShowLocationAction < Struct.new( :text, :postback_data, :latitude, :longitude, :label) SENSITIVE = [] include Aws::Structure end |
#longitude ⇒ Float
The longitude of the location. Valid values are -180 to 180.
6571 6572 6573 6574 6575 6576 6577 6578 6579 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6571 class RcsShowLocationAction < Struct.new( :text, :postback_data, :latitude, :longitude, :label) SENSITIVE = [] include Aws::Structure end |
#postback_data ⇒ String
The postback data sent to your webhook when the user taps this action. Maximum 2048 characters.
6571 6572 6573 6574 6575 6576 6577 6578 6579 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6571 class RcsShowLocationAction < Struct.new( :text, :postback_data, :latitude, :longitude, :label) SENSITIVE = [] include Aws::Structure end |
#text ⇒ String
The display text of the action. Maximum 25 characters.
6571 6572 6573 6574 6575 6576 6577 6578 6579 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6571 class RcsShowLocationAction < Struct.new( :text, :postback_data, :latitude, :longitude, :label) SENSITIVE = [] include Aws::Structure end |