Class: Aws::PinpointSMSVoiceV2::Types::RegistrationAttachmentsInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RegistrationAttachmentsInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Provides information on the specified registration attachments.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_status ⇒ String
The status of the registration attachment.
-
#attachment_upload_error_reason ⇒ String
A description of why the upload didn’t successfully complete.
-
#attachment_url ⇒ String
The URL to the document that’s associated with the registration attachment.
-
#created_timestamp ⇒ Time
The time when the registration attachment was created, in [UNIX epoch time] format.
-
#registration_attachment_arn ⇒ String
The Amazon Resource Name (ARN) for the registration attachment.
-
#registration_attachment_id ⇒ String
The unique identifier for the registration attachment.
Instance Attribute Details
#attachment_status ⇒ String
The status of the registration attachment.
-
‘UPLOAD_IN_PROGRESS` The attachment is being uploaded.
-
‘UPLOAD_COMPLETE` The attachment has been uploaded.
-
‘UPLOAD_FAILED` The attachment failed to uploaded.
-
‘DELETED` The attachment has been deleted..
6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6047 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |
#attachment_upload_error_reason ⇒ String
A description of why the upload didn’t successfully complete.
6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6047 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |
#attachment_url ⇒ String
The URL to the document that’s associated with the registration attachment.
6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6047 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |
#created_timestamp ⇒ Time
The time when the registration attachment was created, in [UNIX epoch time] format.
[1]: www.epochconverter.com/
6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6047 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |
#registration_attachment_arn ⇒ String
The Amazon Resource Name (ARN) for the registration attachment.
6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6047 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |
#registration_attachment_id ⇒ String
The unique identifier for the registration attachment.
6047 6048 6049 6050 6051 6052 6053 6054 6055 6056 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6047 class RegistrationAttachmentsInformation < Struct.new( :registration_attachment_arn, :registration_attachment_id, :attachment_status, :attachment_upload_error_reason, :created_timestamp, :attachment_url) SENSITIVE = [] include Aws::Structure end |