Class: Aws::PinpointSMSVoiceV2::Types::RegistrationFieldValueInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RegistrationFieldValueInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Provides the values of the specified field.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#denied_reason ⇒ String
A description of why the registration was denied.
-
#feedback ⇒ String
Generative AI feedback information provided for this specific field during the registration review process.
-
#field_path ⇒ String
The path to the registration form field.
-
#registration_attachment_id ⇒ String
The unique identifier for the registration attachment.
-
#select_choices ⇒ Array<String>
An array of values for the form field.
-
#text_value ⇒ String
The text data for a free form field.
Instance Attribute Details
#denied_reason ⇒ String
A description of why the registration was denied.
6218 6219 6220 6221 6222 6223 6224 6225 6226 6227 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6218 class RegistrationFieldValueInformation < Struct.new( :field_path, :select_choices, :text_value, :registration_attachment_id, :denied_reason, :feedback) SENSITIVE = [] include Aws::Structure end |
#feedback ⇒ String
Generative AI feedback information provided for this specific field during the registration review process. This may include validation errors, suggestions for improvement, or additional requirements.
6218 6219 6220 6221 6222 6223 6224 6225 6226 6227 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6218 class RegistrationFieldValueInformation < Struct.new( :field_path, :select_choices, :text_value, :registration_attachment_id, :denied_reason, :feedback) SENSITIVE = [] include Aws::Structure end |
#field_path ⇒ String
The path to the registration form field. You can use DescribeRegistrationFieldDefinitions for a list of FieldPaths.
6218 6219 6220 6221 6222 6223 6224 6225 6226 6227 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6218 class RegistrationFieldValueInformation < Struct.new( :field_path, :select_choices, :text_value, :registration_attachment_id, :denied_reason, :feedback) SENSITIVE = [] include Aws::Structure end |
#registration_attachment_id ⇒ String
The unique identifier for the registration attachment.
6218 6219 6220 6221 6222 6223 6224 6225 6226 6227 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6218 class RegistrationFieldValueInformation < Struct.new( :field_path, :select_choices, :text_value, :registration_attachment_id, :denied_reason, :feedback) SENSITIVE = [] include Aws::Structure end |
#select_choices ⇒ Array<String>
An array of values for the form field.
6218 6219 6220 6221 6222 6223 6224 6225 6226 6227 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6218 class RegistrationFieldValueInformation < Struct.new( :field_path, :select_choices, :text_value, :registration_attachment_id, :denied_reason, :feedback) SENSITIVE = [] include Aws::Structure end |
#text_value ⇒ String
The text data for a free form field.
6218 6219 6220 6221 6222 6223 6224 6225 6226 6227 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 6218 class RegistrationFieldValueInformation < Struct.new( :field_path, :select_choices, :text_value, :registration_attachment_id, :denied_reason, :feedback) SENSITIVE = [] include Aws::Structure end |