Class: Aws::PinpointSMSVoiceV2::Types::RegistrationVersionStatusHistory
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RegistrationVersionStatusHistory
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
The RegistrationVersionStatusHistory object contains the time stamps for when the reservations status changes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approved_timestamp ⇒ Time
The time when the registration was in the approved state, in [UNIX epoch time][1] format.
-
#archived_timestamp ⇒ Time
The time when the registration was in the archived state, in [UNIX epoch time][1] format.
-
#aws_reviewing_timestamp ⇒ Time
The time when the registration was in the AWS reviewing state, in [UNIX epoch time][1] format.
-
#denied_timestamp ⇒ Time
The time when the registration was in the denied state, in [UNIX epoch time][1] format.
-
#discarded_timestamp ⇒ Time
The time when the registration was in the discarded state, in [UNIX epoch time][1] format.
-
#draft_timestamp ⇒ Time
The time when the registration was in the draft state, in [UNIX epoch time][1] format.
-
#requires_authentication_timestamp ⇒ Time
The time when the registration was in the requires authentication state, in [UNIX epoch time][1] format.
-
#reviewing_timestamp ⇒ Time
The time when the registration was in the reviewing state, in [UNIX epoch time][1] format.
-
#revoked_timestamp ⇒ Time
The time when the registration was in the revoked state, in [UNIX epoch time][1] format.
-
#submitted_timestamp ⇒ Time
The time when the registration was in the submitted state, in [UNIX epoch time][1] format.
Instance Attribute Details
#approved_timestamp ⇒ Time
The time when the registration was in the approved state, in UNIX epoch time format.
7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7546 class RegistrationVersionStatusHistory < Struct.new( :draft_timestamp, :submitted_timestamp, :aws_reviewing_timestamp, :reviewing_timestamp, :requires_authentication_timestamp, :approved_timestamp, :discarded_timestamp, :denied_timestamp, :revoked_timestamp, :archived_timestamp) SENSITIVE = [] include Aws::Structure end |
#archived_timestamp ⇒ Time
The time when the registration was in the archived state, in UNIX epoch time format.
7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7546 class RegistrationVersionStatusHistory < Struct.new( :draft_timestamp, :submitted_timestamp, :aws_reviewing_timestamp, :reviewing_timestamp, :requires_authentication_timestamp, :approved_timestamp, :discarded_timestamp, :denied_timestamp, :revoked_timestamp, :archived_timestamp) SENSITIVE = [] include Aws::Structure end |
#aws_reviewing_timestamp ⇒ Time
The time when the registration was in the AWS reviewing state, in UNIX epoch time format.
7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7546 class RegistrationVersionStatusHistory < Struct.new( :draft_timestamp, :submitted_timestamp, :aws_reviewing_timestamp, :reviewing_timestamp, :requires_authentication_timestamp, :approved_timestamp, :discarded_timestamp, :denied_timestamp, :revoked_timestamp, :archived_timestamp) SENSITIVE = [] include Aws::Structure end |
#denied_timestamp ⇒ Time
The time when the registration was in the denied state, in UNIX epoch time format.
7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7546 class RegistrationVersionStatusHistory < Struct.new( :draft_timestamp, :submitted_timestamp, :aws_reviewing_timestamp, :reviewing_timestamp, :requires_authentication_timestamp, :approved_timestamp, :discarded_timestamp, :denied_timestamp, :revoked_timestamp, :archived_timestamp) SENSITIVE = [] include Aws::Structure end |
#discarded_timestamp ⇒ Time
The time when the registration was in the discarded state, in UNIX epoch time format.
7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7546 class RegistrationVersionStatusHistory < Struct.new( :draft_timestamp, :submitted_timestamp, :aws_reviewing_timestamp, :reviewing_timestamp, :requires_authentication_timestamp, :approved_timestamp, :discarded_timestamp, :denied_timestamp, :revoked_timestamp, :archived_timestamp) SENSITIVE = [] include Aws::Structure end |
#draft_timestamp ⇒ Time
The time when the registration was in the draft state, in UNIX epoch time format.
7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7546 class RegistrationVersionStatusHistory < Struct.new( :draft_timestamp, :submitted_timestamp, :aws_reviewing_timestamp, :reviewing_timestamp, :requires_authentication_timestamp, :approved_timestamp, :discarded_timestamp, :denied_timestamp, :revoked_timestamp, :archived_timestamp) SENSITIVE = [] include Aws::Structure end |
#requires_authentication_timestamp ⇒ Time
The time when the registration was in the requires authentication state, in UNIX epoch time format.
7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7546 class RegistrationVersionStatusHistory < Struct.new( :draft_timestamp, :submitted_timestamp, :aws_reviewing_timestamp, :reviewing_timestamp, :requires_authentication_timestamp, :approved_timestamp, :discarded_timestamp, :denied_timestamp, :revoked_timestamp, :archived_timestamp) SENSITIVE = [] include Aws::Structure end |
#reviewing_timestamp ⇒ Time
The time when the registration was in the reviewing state, in UNIX epoch time format.
7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7546 class RegistrationVersionStatusHistory < Struct.new( :draft_timestamp, :submitted_timestamp, :aws_reviewing_timestamp, :reviewing_timestamp, :requires_authentication_timestamp, :approved_timestamp, :discarded_timestamp, :denied_timestamp, :revoked_timestamp, :archived_timestamp) SENSITIVE = [] include Aws::Structure end |
#revoked_timestamp ⇒ Time
The time when the registration was in the revoked state, in UNIX epoch time format.
7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7546 class RegistrationVersionStatusHistory < Struct.new( :draft_timestamp, :submitted_timestamp, :aws_reviewing_timestamp, :reviewing_timestamp, :requires_authentication_timestamp, :approved_timestamp, :discarded_timestamp, :denied_timestamp, :revoked_timestamp, :archived_timestamp) SENSITIVE = [] include Aws::Structure end |
#submitted_timestamp ⇒ Time
The time when the registration was in the submitted state, in UNIX epoch time format.
7546 7547 7548 7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7546 class RegistrationVersionStatusHistory < Struct.new( :draft_timestamp, :submitted_timestamp, :aws_reviewing_timestamp, :reviewing_timestamp, :requires_authentication_timestamp, :approved_timestamp, :discarded_timestamp, :denied_timestamp, :revoked_timestamp, :archived_timestamp) SENSITIVE = [] include Aws::Structure end |