Class: Aws::PinpointSMSVoiceV2::Types::ReleasePhoneNumberResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestampTime

The time when the phone number was created, in UNIX epoch time format.

Returns:

  • (Time)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#iso_country_codeString

The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#message_typeString

The message type that was associated with the phone number.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#monthly_leasing_priceString

The monthly price of the phone number, in US dollars.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#number_capabilitiesArray<String>

Specifies if the number could be used for text messages, voice, or both.

Returns:

  • (Array<String>)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#number_typeString

The type of number that was released.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_nameString

The name of the OptOutList that was associated with the phone number.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_numberString

The phone number that was released.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_arnString

The PhoneNumberArn of the phone number that was released.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_idString

The PhoneNumberId of the phone number that was released.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#registration_idString

The unique identifier for the registration.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_opt_outs_enabledBoolean

By default this is set to false. When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.

Returns:

  • (Boolean)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the request.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_arnString

The Amazon Resource Name (ARN) of the TwoWayChannel.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_roleString

An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.

Returns:

  • (String)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_enabledBoolean

By default this is set to false. When set to true you can receive incoming text messages from your end recipients.

Returns:

  • (Boolean)


7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7378

class ReleasePhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :registration_id,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end