Class: Aws::PinpointSMSVoiceV2::Types::RequestPhoneNumberResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestampTime

The time when the phone number was created, in UNIX epoch time format.

Returns:

  • (Time)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection_enabledBoolean

By default this is set to false. When set to true the phone number can't be deleted.

Returns:

  • (Boolean)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#international_sending_enabledBoolean

By default this is set to false. When set to true the international sending of phone number is Enabled.

Returns:

  • (Boolean)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#iso_country_codeString

The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#message_typeString

The type of message. Valid values are TRANSACTIONAL for messages that are critical or time-sensitive and PROMOTIONAL for messages that aren't critical or time-sensitive.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#monthly_leasing_priceString

The monthly price, in US dollars, to lease the phone number.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#number_capabilitiesArray<String>

Indicates if the phone number will be used for text messages, voice messages or both.

Returns:

  • (Array<String>)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#number_typeString

The type of number that was released.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_nameString

The name of the OptOutList that is associated with the requested phone number.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_numberString

The new phone number that was requested.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_arnString

The Amazon Resource Name (ARN) of the requested phone number.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#phone_number_idString

The unique identifier of the new phone number.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#pool_idString

The unique identifier of the pool associated with the phone number

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#registration_idString

The unique identifier for the registration.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_opt_outs_enabledBoolean

By default this is set to false. When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.

Returns:

  • (Boolean)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the request.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key and value pair tags that are associated with the phone number.

Returns:



7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_arnString

The ARN used to identify the two way channel.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_roleString

An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.

Returns:

  • (String)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_enabledBoolean

By default this is set to false. When set to true you can receive incoming text messages from your end recipients.

Returns:

  • (Boolean)


7793
7794
7795
7796
7797
7798
7799
7800
7801
7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
7815
7816
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7793

class RequestPhoneNumberResult < Struct.new(
  :phone_number_arn,
  :phone_number_id,
  :phone_number,
  :status,
  :iso_country_code,
  :message_type,
  :number_capabilities,
  :number_type,
  :monthly_leasing_price,
  :two_way_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :self_managed_opt_outs_enabled,
  :opt_out_list_name,
  :international_sending_enabled,
  :deletion_protection_enabled,
  :pool_id,
  :registration_id,
  :tags,
  :created_timestamp)
  SENSITIVE = []
  include Aws::Structure
end