Class: Aws::PinpointSMSVoiceV2::Types::RequestPhoneNumberResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::RequestPhoneNumberResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_timestamp ⇒ Time
The time when the phone number was created, in [UNIX epoch time][1] format.
-
#deletion_protection_enabled ⇒ Boolean
By default this is set to false.
-
#international_sending_enabled ⇒ Boolean
By default this is set to false.
-
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
-
#message_type ⇒ String
The type of message.
-
#monthly_leasing_price ⇒ String
The monthly price, in US dollars, to lease the phone number.
-
#number_capabilities ⇒ Array<String>
Indicates if the phone number will be used for text messages, voice messages or both.
-
#number_type ⇒ String
The type of number that was released.
-
#opt_out_list_name ⇒ String
The name of the OptOutList that is associated with the requested phone number.
-
#phone_number ⇒ String
The new phone number that was requested.
-
#phone_number_arn ⇒ String
The Amazon Resource Name (ARN) of the requested phone number.
-
#phone_number_id ⇒ String
The unique identifier of the new phone number.
-
#pool_id ⇒ String
The unique identifier of the pool associated with the phone number.
-
#registration_id ⇒ String
The unique identifier for the registration.
-
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false.
-
#status ⇒ String
The current status of the request.
-
#tags ⇒ Array<Types::Tag>
An array of key and value pair tags that are associated with the phone number.
-
#two_way_channel_arn ⇒ String
The ARN used to identify the two way channel.
-
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
-
#two_way_enabled ⇒ Boolean
By default this is set to false.
Instance Attribute Details
#created_timestamp ⇒ Time
The time when the phone number was created, in UNIX epoch time format.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
By default this is set to false. When set to true the phone number can't be deleted.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#international_sending_enabled ⇒ Boolean
By default this is set to false. When set to true the international sending of phone number is Enabled.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#iso_country_code ⇒ String
The two-character code, in ISO 3166-1 alpha-2 format, for the country or region.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#message_type ⇒ String
The type of message. Valid values are TRANSACTIONAL for messages that are critical or time-sensitive and PROMOTIONAL for messages that aren't critical or time-sensitive.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#monthly_leasing_price ⇒ String
The monthly price, in US dollars, to lease the phone number.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#number_capabilities ⇒ Array<String>
Indicates if the phone number will be used for text messages, voice messages or both.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#number_type ⇒ String
The type of number that was released.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The name of the OptOutList that is associated with the requested phone number.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#phone_number ⇒ String
The new phone number that was requested.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#phone_number_arn ⇒ String
The Amazon Resource Name (ARN) of the requested phone number.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#phone_number_id ⇒ String
The unique identifier of the new phone number.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The unique identifier of the pool associated with the phone number
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#registration_id ⇒ String
The unique identifier for the registration.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false. When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the request.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key and value pair tags that are associated with the phone number.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_arn ⇒ String
The ARN used to identify the two way channel.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_enabled ⇒ Boolean
By default this is set to false. When set to true you can receive incoming text messages from your end recipients.
7652 7653 7654 7655 7656 7657 7658 7659 7660 7661 7662 7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7652 class RequestPhoneNumberResult < Struct.new( :phone_number_arn, :phone_number_id, :phone_number, :status, :iso_country_code, :message_type, :number_capabilities, :number_type, :monthly_leasing_price, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled, :pool_id, :registration_id, :tags, :created_timestamp) SENSITIVE = [] include Aws::Structure end |