Class: Aws::PinpointSMSVoiceV2::Types::SendNotifyVoiceMessageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::SendNotifyVoiceMessageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_set_name ⇒ String
The name of the configuration set to use.
-
#context ⇒ Hash<String,String>
You can specify custom data in this field.
-
#destination_phone_number ⇒ String
The destination phone number in E.164 format.
-
#dry_run ⇒ Boolean
When set to true, the message is checked and validated, but isn't sent to the end recipient.
-
#message_feedback_enabled ⇒ Boolean
Set to true to enable message feedback for the message.
-
#notify_configuration_id ⇒ String
The unique identifier of the notify configuration to use for sending the message.
-
#template_id ⇒ String
The unique identifier of the template to use for the message.
-
#template_variables ⇒ Hash<String,String>
A map of template variable names and their values.
-
#time_to_live ⇒ Integer
How long the voice message is valid for, in seconds.
-
#voice_id ⇒ String
The voice ID to use for the voice message.
Instance Attribute Details
#configuration_set_name ⇒ String
The name of the configuration set to use. This can be either the ConfigurationSetName or ConfigurationSetArn.
8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8160 class SendNotifyVoiceMessageRequest < Struct.new( :notify_configuration_id, :destination_phone_number, :template_id, :template_variables, :voice_id, :time_to_live, :context, :configuration_set_name, :dry_run, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#context ⇒ Hash<String,String>
You can specify custom data in this field. If you do, that data is logged to the event destination.
8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8160 class SendNotifyVoiceMessageRequest < Struct.new( :notify_configuration_id, :destination_phone_number, :template_id, :template_variables, :voice_id, :time_to_live, :context, :configuration_set_name, :dry_run, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#destination_phone_number ⇒ String
The destination phone number in E.164 format.
8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8160 class SendNotifyVoiceMessageRequest < Struct.new( :notify_configuration_id, :destination_phone_number, :template_id, :template_variables, :voice_id, :time_to_live, :context, :configuration_set_name, :dry_run, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
When set to true, the message is checked and validated, but isn't sent to the end recipient.
8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8160 class SendNotifyVoiceMessageRequest < Struct.new( :notify_configuration_id, :destination_phone_number, :template_id, :template_variables, :voice_id, :time_to_live, :context, :configuration_set_name, :dry_run, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#message_feedback_enabled ⇒ Boolean
Set to true to enable message feedback for the message. When a user receives the message you need to update the message status using PutMessageFeedback.
8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8160 class SendNotifyVoiceMessageRequest < Struct.new( :notify_configuration_id, :destination_phone_number, :template_id, :template_variables, :voice_id, :time_to_live, :context, :configuration_set_name, :dry_run, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#notify_configuration_id ⇒ String
The unique identifier of the notify configuration to use for sending the message. This can be either the NotifyConfigurationId or NotifyConfigurationArn.
8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8160 class SendNotifyVoiceMessageRequest < Struct.new( :notify_configuration_id, :destination_phone_number, :template_id, :template_variables, :voice_id, :time_to_live, :context, :configuration_set_name, :dry_run, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#template_id ⇒ String
The unique identifier of the template to use for the message.
8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8160 class SendNotifyVoiceMessageRequest < Struct.new( :notify_configuration_id, :destination_phone_number, :template_id, :template_variables, :voice_id, :time_to_live, :context, :configuration_set_name, :dry_run, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#template_variables ⇒ Hash<String,String>
A map of template variable names and their values. All variable
values are passed as strings regardless of the declared variable
type. For example, pass INTEGER values as "42" and BOOLEAN
values as "true" or "false".
8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8160 class SendNotifyVoiceMessageRequest < Struct.new( :notify_configuration_id, :destination_phone_number, :template_id, :template_variables, :voice_id, :time_to_live, :context, :configuration_set_name, :dry_run, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#time_to_live ⇒ Integer
How long the voice message is valid for, in seconds. By default this is 72 hours.
8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8160 class SendNotifyVoiceMessageRequest < Struct.new( :notify_configuration_id, :destination_phone_number, :template_id, :template_variables, :voice_id, :time_to_live, :context, :configuration_set_name, :dry_run, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |
#voice_id ⇒ String
The voice ID to use for the voice message.
8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8160 class SendNotifyVoiceMessageRequest < Struct.new( :notify_configuration_id, :destination_phone_number, :template_id, :template_variables, :voice_id, :time_to_live, :context, :configuration_set_name, :dry_run, :message_feedback_enabled) SENSITIVE = [] include Aws::Structure end |