Class: Aws::PinpointSMSVoiceV2::Types::SendNotifyVoiceMessageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_set_nameString

The name of the configuration set to use. This can be either the ConfigurationSetName or ConfigurationSetArn.

Returns:

  • (String)


7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7536

class SendNotifyVoiceMessageRequest < Struct.new(
  :notify_configuration_id,
  :destination_phone_number,
  :template_id,
  :template_variables,
  :voice_id,
  :time_to_live,
  :context,
  :configuration_set_name,
  :dry_run,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#contextHash<String,String>

You can specify custom data in this field. If you do, that data is logged to the event destination.

Returns:

  • (Hash<String,String>)


7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7536

class SendNotifyVoiceMessageRequest < Struct.new(
  :notify_configuration_id,
  :destination_phone_number,
  :template_id,
  :template_variables,
  :voice_id,
  :time_to_live,
  :context,
  :configuration_set_name,
  :dry_run,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#destination_phone_numberString

The destination phone number in E.164 format.

Returns:

  • (String)


7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7536

class SendNotifyVoiceMessageRequest < Struct.new(
  :notify_configuration_id,
  :destination_phone_number,
  :template_id,
  :template_variables,
  :voice_id,
  :time_to_live,
  :context,
  :configuration_set_name,
  :dry_run,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

When set to true, the message is checked and validated, but isn’t sent to the end recipient.

Returns:

  • (Boolean)


7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7536

class SendNotifyVoiceMessageRequest < Struct.new(
  :notify_configuration_id,
  :destination_phone_number,
  :template_id,
  :template_variables,
  :voice_id,
  :time_to_live,
  :context,
  :configuration_set_name,
  :dry_run,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#message_feedback_enabledBoolean

Set to true to enable message feedback for the message. When a user receives the message you need to update the message status using PutMessageFeedback.

Returns:

  • (Boolean)


7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7536

class SendNotifyVoiceMessageRequest < Struct.new(
  :notify_configuration_id,
  :destination_phone_number,
  :template_id,
  :template_variables,
  :voice_id,
  :time_to_live,
  :context,
  :configuration_set_name,
  :dry_run,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#notify_configuration_idString

The unique identifier of the notify configuration to use for sending the message. This can be either the NotifyConfigurationId or NotifyConfigurationArn.

Returns:

  • (String)


7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7536

class SendNotifyVoiceMessageRequest < Struct.new(
  :notify_configuration_id,
  :destination_phone_number,
  :template_id,
  :template_variables,
  :voice_id,
  :time_to_live,
  :context,
  :configuration_set_name,
  :dry_run,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#template_idString

The unique identifier of the template to use for the message.

Returns:

  • (String)


7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7536

class SendNotifyVoiceMessageRequest < Struct.new(
  :notify_configuration_id,
  :destination_phone_number,
  :template_id,
  :template_variables,
  :voice_id,
  :time_to_live,
  :context,
  :configuration_set_name,
  :dry_run,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#template_variablesHash<String,String>

A map of template variable names and their values. All variable values are passed as strings regardless of the declared variable type. For example, pass ‘INTEGER` values as `“42”` and `BOOLEAN` values as `“true”` or `“false”`.

Returns:

  • (Hash<String,String>)


7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7536

class SendNotifyVoiceMessageRequest < Struct.new(
  :notify_configuration_id,
  :destination_phone_number,
  :template_id,
  :template_variables,
  :voice_id,
  :time_to_live,
  :context,
  :configuration_set_name,
  :dry_run,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#time_to_liveInteger

How long the voice message is valid for, in seconds. By default this is 72 hours.

Returns:

  • (Integer)


7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7536

class SendNotifyVoiceMessageRequest < Struct.new(
  :notify_configuration_id,
  :destination_phone_number,
  :template_id,
  :template_variables,
  :voice_id,
  :time_to_live,
  :context,
  :configuration_set_name,
  :dry_run,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#voice_idString

The voice ID to use for the voice message.

Returns:

  • (String)


7536
7537
7538
7539
7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 7536

class SendNotifyVoiceMessageRequest < Struct.new(
  :notify_configuration_id,
  :destination_phone_number,
  :template_id,
  :template_variables,
  :voice_id,
  :time_to_live,
  :context,
  :configuration_set_name,
  :dry_run,
  :message_feedback_enabled)
  SENSITIVE = []
  include Aws::Structure
end