Class: Aws::PinpointSMSVoiceV2::Types::SpendLimit

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Describes the current monthly spend limits for sending voice and text messages. For more information on increasing your monthly spend limit, see Requesting a spending quota increase in the End User Messaging SMS User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enforced_limitInteger

The maximum amount of money, in US dollars, that you want to be able to spend sending messages each month. This value has to be less than or equal to the amount in MaxLimit. To use this custom limit, Overridden must be set to true.

Returns:

  • (Integer)


8975
8976
8977
8978
8979
8980
8981
8982
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8975

class SpendLimit < Struct.new(
  :name,
  :enforced_limit,
  :max_limit,
  :overridden)
  SENSITIVE = []
  include Aws::Structure
end

#max_limitInteger

The maximum amount of money that you are able to spend to send messages each month, in US dollars.

Returns:

  • (Integer)


8975
8976
8977
8978
8979
8980
8981
8982
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8975

class SpendLimit < Struct.new(
  :name,
  :enforced_limit,
  :max_limit,
  :overridden)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name for the SpendLimit.

Returns:

  • (String)


8975
8976
8977
8978
8979
8980
8981
8982
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8975

class SpendLimit < Struct.new(
  :name,
  :enforced_limit,
  :max_limit,
  :overridden)
  SENSITIVE = []
  include Aws::Structure
end

#overriddenBoolean

When set to True, the value that has been specified in the EnforcedLimit is used to determine the maximum amount in US dollars that can be spent to send messages each month, in US dollars.

Returns:

  • (Boolean)


8975
8976
8977
8978
8979
8980
8981
8982
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 8975

class SpendLimit < Struct.new(
  :name,
  :enforced_limit,
  :max_limit,
  :overridden)
  SENSITIVE = []
  include Aws::Structure
end