Class: Aws::PinpointSMSVoiceV2::Types::TestingAgentInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::TestingAgentInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Contains details about the testing agent associated with an RCS agent.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#registration_id ⇒ String
The unique identifier of the registration associated with the testing agent.
-
#status ⇒ String
The current status of the testing agent.
-
#testing_agent_id ⇒ String
The unique identifier for the testing agent.
Instance Attribute Details
#registration_id ⇒ String
The unique identifier of the registration associated with the testing agent.
9238 9239 9240 9241 9242 9243 9244 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9238 class TestingAgentInformation < Struct.new( :status, :testing_agent_id, :registration_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the testing agent.
9238 9239 9240 9241 9242 9243 9244 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9238 class TestingAgentInformation < Struct.new( :status, :testing_agent_id, :registration_id) SENSITIVE = [] include Aws::Structure end |
#testing_agent_id ⇒ String
The unique identifier for the testing agent.
9238 9239 9240 9241 9242 9243 9244 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9238 class TestingAgentInformation < Struct.new( :status, :testing_agent_id, :registration_id) SENSITIVE = [] include Aws::Structure end |