Class: Aws::PinpointSMSVoiceV2::Types::UpdateEventDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::UpdateEventDestinationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_logs_destination ⇒ Types::CloudWatchLogsDestination
An object that contains information about an event destination that sends data to CloudWatch Logs.
-
#configuration_set_name ⇒ String
The configuration set to update with the new event destination.
-
#enabled ⇒ Boolean
When set to true logging is enabled.
-
#event_destination_name ⇒ String
The name to use for the event destination.
-
#kinesis_firehose_destination ⇒ Types::KinesisFirehoseDestination
An object that contains information about an event destination for logging to Firehose.
-
#matching_event_types ⇒ Array<String>
An array of event types that determine which events to log.
-
#sns_destination ⇒ Types::SnsDestination
An object that contains information about an event destination that sends data to Amazon SNS.
Instance Attribute Details
#cloud_watch_logs_destination ⇒ Types::CloudWatchLogsDestination
An object that contains information about an event destination that sends data to CloudWatch Logs.
9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9344 class UpdateEventDestinationRequest < Struct.new( :configuration_set_name, :event_destination_name, :enabled, :matching_event_types, :cloud_watch_logs_destination, :kinesis_firehose_destination, :sns_destination) SENSITIVE = [] include Aws::Structure end |
#configuration_set_name ⇒ String
The configuration set to update with the new event destination. Valid values for this can be the ConfigurationSetName or ConfigurationSetArn.
9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9344 class UpdateEventDestinationRequest < Struct.new( :configuration_set_name, :event_destination_name, :enabled, :matching_event_types, :cloud_watch_logs_destination, :kinesis_firehose_destination, :sns_destination) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
When set to true logging is enabled.
9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9344 class UpdateEventDestinationRequest < Struct.new( :configuration_set_name, :event_destination_name, :enabled, :matching_event_types, :cloud_watch_logs_destination, :kinesis_firehose_destination, :sns_destination) SENSITIVE = [] include Aws::Structure end |
#event_destination_name ⇒ String
The name to use for the event destination.
9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9344 class UpdateEventDestinationRequest < Struct.new( :configuration_set_name, :event_destination_name, :enabled, :matching_event_types, :cloud_watch_logs_destination, :kinesis_firehose_destination, :sns_destination) SENSITIVE = [] include Aws::Structure end |
#kinesis_firehose_destination ⇒ Types::KinesisFirehoseDestination
An object that contains information about an event destination for logging to Firehose.
9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9344 class UpdateEventDestinationRequest < Struct.new( :configuration_set_name, :event_destination_name, :enabled, :matching_event_types, :cloud_watch_logs_destination, :kinesis_firehose_destination, :sns_destination) SENSITIVE = [] include Aws::Structure end |
#matching_event_types ⇒ Array<String>
An array of event types that determine which events to log.
TEXT_SENT event type is not supported.
9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9344 class UpdateEventDestinationRequest < Struct.new( :configuration_set_name, :event_destination_name, :enabled, :matching_event_types, :cloud_watch_logs_destination, :kinesis_firehose_destination, :sns_destination) SENSITIVE = [] include Aws::Structure end |
#sns_destination ⇒ Types::SnsDestination
An object that contains information about an event destination that sends data to Amazon SNS.
9344 9345 9346 9347 9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9344 class UpdateEventDestinationRequest < Struct.new( :configuration_set_name, :event_destination_name, :enabled, :matching_event_types, :cloud_watch_logs_destination, :kinesis_firehose_destination, :sns_destination) SENSITIVE = [] include Aws::Structure end |