Class: Aws::PinpointSMSVoiceV2::Types::UpdatePhoneNumberRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::UpdatePhoneNumberRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deletion_protection_enabled ⇒ Boolean
By default this is set to false.
-
#international_sending_enabled ⇒ Boolean
By default this is set to false.
-
#opt_out_list_name ⇒ String
The OptOutList to add the phone number to.
-
#phone_number_id ⇒ String
The unique identifier of the phone number.
-
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false.
-
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
-
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
-
#two_way_enabled ⇒ Boolean
By default this is set to false.
Instance Attribute Details
#deletion_protection_enabled ⇒ Boolean
By default this is set to false. When set to true the phone number can't be deleted.
9563 9564 9565 9566 9567 9568 9569 9570 9571 9572 9573 9574 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9563 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#international_sending_enabled ⇒ Boolean
By default this is set to false. When set to true the international sending of phone number is Enabled.
9563 9564 9565 9566 9567 9568 9569 9570 9571 9572 9573 9574 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9563 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The OptOutList to add the phone number to. You can use either the opt out list name or the opt out list ARN.
9563 9564 9565 9566 9567 9568 9569 9570 9571 9572 9573 9574 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9563 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#phone_number_id ⇒ String
The unique identifier of the phone number. Valid values for this field can be either the PhoneNumberId or PhoneNumberArn.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
9563 9564 9565 9566 9567 9568 9569 9570 9571 9572 9573 9574 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9563 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false. When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.
9563 9564 9565 9566 9567 9568 9569 9570 9571 9572 9573 9574 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9563 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
9563 9564 9565 9566 9567 9568 9569 9570 9571 9572 9573 9574 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9563 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
9563 9564 9565 9566 9567 9568 9569 9570 9571 9572 9573 9574 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9563 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#two_way_enabled ⇒ Boolean
By default this is set to false. When set to true you can receive incoming text messages from your end recipients.
9563 9564 9565 9566 9567 9568 9569 9570 9571 9572 9573 9574 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9563 class UpdatePhoneNumberRequest < Struct.new( :phone_number_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :international_sending_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |