Class: Aws::PinpointSMSVoiceV2::Types::UpdatePoolRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::UpdatePoolRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deletion_protection_enabled ⇒ Boolean
When set to true the pool can't be deleted.
-
#opt_out_list_name ⇒ String
The OptOutList to associate with the pool.
-
#pool_id ⇒ String
The unique identifier of the pool to update.
-
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false.
-
#shared_routes_enabled ⇒ Boolean
Indicates whether shared routes are enabled for the pool.
-
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
-
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
-
#two_way_enabled ⇒ Boolean
By default this is set to false.
Instance Attribute Details
#deletion_protection_enabled ⇒ Boolean
When set to true the pool can't be deleted.
9876 9877 9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9876 class UpdatePoolRequest < Struct.new( :pool_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The OptOutList to associate with the pool. Valid values are either OptOutListName or OptOutListArn.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
9876 9877 9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9876 class UpdatePoolRequest < Struct.new( :pool_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The unique identifier of the pool to update. Valid values are either the PoolId or PoolArn.
If you are using a shared End User Messaging SMS resource then you must use the full Amazon Resource Name(ARN).
9876 9877 9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9876 class UpdatePoolRequest < Struct.new( :pool_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#self_managed_opt_outs_enabled ⇒ Boolean
By default this is set to false. When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.
9876 9877 9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9876 class UpdatePoolRequest < Struct.new( :pool_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#shared_routes_enabled ⇒ Boolean
Indicates whether shared routes are enabled for the pool.
9876 9877 9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9876 class UpdatePoolRequest < Struct.new( :pool_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
9876 9877 9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9876 class UpdatePoolRequest < Struct.new( :pool_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
9876 9877 9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9876 class UpdatePoolRequest < Struct.new( :pool_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#two_way_enabled ⇒ Boolean
By default this is set to false. When set to true you can receive incoming text messages from your end recipients.
9876 9877 9878 9879 9880 9881 9882 9883 9884 9885 9886 9887 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9876 class UpdatePoolRequest < Struct.new( :pool_id, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |