Class: Aws::PinpointSMSVoiceV2::Types::UpdatePoolResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::UpdatePoolResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_timestamp ⇒ Time
The time when the pool was created, in [UNIX epoch time][1] format.
-
#deletion_protection_enabled ⇒ Boolean
When set to true the pool can't be deleted.
-
#message_type ⇒ String
The type of message for the pool to use.
-
#opt_out_list_name ⇒ String
The name of the OptOutList associated with the pool.
-
#pool_arn ⇒ String
The ARN of the pool.
-
#pool_id ⇒ String
The unique identifier of the pool.
-
#self_managed_opt_outs_enabled ⇒ Boolean
When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList.
-
#shared_routes_enabled ⇒ Boolean
Indicates whether shared routes are enabled for the pool.
-
#status ⇒ String
The current status of the pool update request.
-
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
-
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
-
#two_way_enabled ⇒ Boolean
By default this is set to false.
Instance Attribute Details
#created_timestamp ⇒ Time
The time when the pool was created, in UNIX epoch time format.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
When set to true the pool can't be deleted.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#message_type ⇒ String
The type of message for the pool to use.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#opt_out_list_name ⇒ String
The name of the OptOutList associated with the pool.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#pool_arn ⇒ String
The ARN of the pool.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The unique identifier of the pool.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#self_managed_opt_outs_enabled ⇒ Boolean
When set to false and an end recipient sends a message that begins with HELP or STOP to one of your dedicated numbers, End User Messaging SMS automatically replies with a customizable message and adds the end recipient to the OptOutList. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#shared_routes_enabled ⇒ Boolean
Indicates whether shared routes are enabled for the pool.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the pool update request.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the two way channel.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_channel_role ⇒ String
An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#two_way_enabled ⇒ Boolean
By default this is set to false. When set to true you can receive incoming text messages from your end recipients.
9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 9823 9824 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 9809 class UpdatePoolResult < Struct.new( :pool_arn, :pool_id, :status, :message_type, :two_way_enabled, :two_way_channel_arn, :two_way_channel_role, :self_managed_opt_outs_enabled, :opt_out_list_name, :shared_routes_enabled, :deletion_protection_enabled, :created_timestamp) SENSITIVE = [] include Aws::Structure end |