Class: Aws::PinpointSMSVoiceV2::Types::UpdateRcsAgentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pinpointsmsvoicev2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deletion_protection_enabledBoolean

By default this is set to false. When set to true the RCS agent can't be deleted.

Returns:

  • (Boolean)


10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10012

class UpdateRcsAgentRequest < Struct.new(
  :rcs_agent_id,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#opt_out_list_nameString

The OptOutList to associate with the RCS agent. Valid values are either OptOutListName or OptOutListArn.

Returns:

  • (String)


10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10012

class UpdateRcsAgentRequest < Struct.new(
  :rcs_agent_id,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#rcs_agent_idString

The unique identifier of the RCS agent to update. You can use either the RcsAgentId or RcsAgentArn.

Returns:

  • (String)


10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10012

class UpdateRcsAgentRequest < Struct.new(
  :rcs_agent_id,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_opt_outs_enabledBoolean

By default this is set to false. When set to true you're responsible for responding to HELP and STOP requests. You're also responsible for tracking and honoring opt-out requests.

Returns:

  • (Boolean)


10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10012

class UpdateRcsAgentRequest < Struct.new(
  :rcs_agent_id,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_arnString

The Amazon Resource Name (ARN) of the two way channel.

Returns:

  • (String)


10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10012

class UpdateRcsAgentRequest < Struct.new(
  :rcs_agent_id,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_channel_roleString

An optional IAM Role Arn for a service to assume, to be able to post inbound SMS messages.

Returns:

  • (String)


10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10012

class UpdateRcsAgentRequest < Struct.new(
  :rcs_agent_id,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_enabledBoolean

By default this is set to false. When set to true you can receive incoming text messages from your end recipients.

Returns:

  • (Boolean)


10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10012

class UpdateRcsAgentRequest < Struct.new(
  :rcs_agent_id,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_media_s3_bucket_nameString

The name of the S3 bucket where inbound RCS media files are stored. Two-way messaging must be enabled on the agent. To remove the media configuration, pass the sentinel value UNSET_RCS_MEDIA_CONFIGURATION for both this field and TwoWayMediaS3Role.

Returns:

  • (String)


10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10012

class UpdateRcsAgentRequest < Struct.new(
  :rcs_agent_id,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_media_s3_key_prefixString

The key prefix used for inbound RCS media objects in the S3 bucket.

Returns:

  • (String)


10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10012

class UpdateRcsAgentRequest < Struct.new(
  :rcs_agent_id,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_media_s3_roleString

The ARN of the IAM role used to write inbound RCS media files to the S3 bucket. The role must have s3:PutObject permission on the bucket and a trust policy allowing sms-voice.amazonaws.com to assume it. To remove the media configuration, pass the sentinel value UNSET_RCS_MEDIA_CONFIGURATION for both this field and TwoWayMediaS3BucketName.

Returns:

  • (String)


10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10012

class UpdateRcsAgentRequest < Struct.new(
  :rcs_agent_id,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#two_way_rcs_events_enabledArray<String>

The list of RCS event types to enable for two-way messaging. Pass an empty list to disable all event types. The special value ALL enables all current and future event types and must be the sole element if used.

Returns:

  • (Array<String>)


10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
10022
10023
10024
10025
10026
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10012

class UpdateRcsAgentRequest < Struct.new(
  :rcs_agent_id,
  :deletion_protection_enabled,
  :opt_out_list_name,
  :self_managed_opt_outs_enabled,
  :two_way_channel_arn,
  :two_way_channel_role,
  :two_way_enabled,
  :two_way_media_s3_bucket_name,
  :two_way_media_s3_key_prefix,
  :two_way_media_s3_role,
  :two_way_rcs_events_enabled)
  SENSITIVE = []
  include Aws::Structure
end