Class: Aws::PinpointSMSVoiceV2::Types::VerifiedDestinationNumberInformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointSMSVoiceV2::Types::VerifiedDestinationNumberInformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointsmsvoicev2/types.rb
Overview
Provides information about the requested verified destintion phone number.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_timestamp ⇒ Time
The time when the destination phone number was created, in [UNIX epoch time][1] format.
-
#destination_phone_number ⇒ String
The verified destination phone number, in E.164 format.
-
#rcs_agent_id ⇒ String
The unique identifier of the RCS agent associated with the verified destination number.
-
#status ⇒ String
The status of the verified destination phone number.
-
#verified_destination_number_arn ⇒ String
The Amazon Resource Name (ARN) for the verified destination phone number.
-
#verified_destination_number_id ⇒ String
The unique identifier for the verified destination phone number.
Instance Attribute Details
#created_timestamp ⇒ Time
The time when the destination phone number was created, in UNIX epoch time format.
10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10295 class VerifiedDestinationNumberInformation < Struct.new( :verified_destination_number_arn, :verified_destination_number_id, :destination_phone_number, :status, :rcs_agent_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#destination_phone_number ⇒ String
The verified destination phone number, in E.164 format.
10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10295 class VerifiedDestinationNumberInformation < Struct.new( :verified_destination_number_arn, :verified_destination_number_id, :destination_phone_number, :status, :rcs_agent_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#rcs_agent_id ⇒ String
The unique identifier of the RCS agent associated with the verified destination number.
10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10295 class VerifiedDestinationNumberInformation < Struct.new( :verified_destination_number_arn, :verified_destination_number_id, :destination_phone_number, :status, :rcs_agent_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the verified destination phone number.
-
PENDING: The phone number hasn't been verified yet. -
VERIFIED: The phone number is verified and can receive messages.
10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10295 class VerifiedDestinationNumberInformation < Struct.new( :verified_destination_number_arn, :verified_destination_number_id, :destination_phone_number, :status, :rcs_agent_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#verified_destination_number_arn ⇒ String
The Amazon Resource Name (ARN) for the verified destination phone number.
10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10295 class VerifiedDestinationNumberInformation < Struct.new( :verified_destination_number_arn, :verified_destination_number_id, :destination_phone_number, :status, :rcs_agent_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |
#verified_destination_number_id ⇒ String
The unique identifier for the verified destination phone number.
10295 10296 10297 10298 10299 10300 10301 10302 10303 10304 |
# File 'lib/aws-sdk-pinpointsmsvoicev2/types.rb', line 10295 class VerifiedDestinationNumberInformation < Struct.new( :verified_destination_number_arn, :verified_destination_number_id, :destination_phone_number, :status, :rcs_agent_id, :created_timestamp) SENSITIVE = [] include Aws::Structure end |